"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .putintegrationsintegrationidcustomfieldscustomfieldidrequestbody import (
    PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDRequestBody,
    PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDRequestBodyTypedDict,
)
from kombo.types import BaseModel
from kombo.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDRequestTypedDict(TypedDict):
    integration_id: str
    r"""The unique ID of the integration where the custom field mapping should be updated"""
    custom_field_id: str
    r"""The unique ID of the custom field that should be updated"""
    body: PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDRequestBodyTypedDict
    r"""PUT /integrations/:integration_id/custom-fields/:custom_field_id Request body"""


class PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDRequest(BaseModel):
    integration_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The unique ID of the integration where the custom field mapping should be updated"""

    custom_field_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The unique ID of the custom field that should be updated"""

    body: Annotated[
        PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
    r"""PUT /integrations/:integration_id/custom-fields/:custom_field_id Request body"""
