"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel
from kombo.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class DeleteIntegrationsIntegrationIDPositiveResponseDataTypedDict(TypedDict):
    pass


class DeleteIntegrationsIntegrationIDPositiveResponseData(BaseModel):
    pass


class DeleteIntegrationsIntegrationIDPositiveResponseTypedDict(TypedDict):
    data: DeleteIntegrationsIntegrationIDPositiveResponseDataTypedDict
    status: Literal["success"]


class DeleteIntegrationsIntegrationIDPositiveResponse(BaseModel):
    data: DeleteIntegrationsIntegrationIDPositiveResponseData

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"
