"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


PostForceSyncRequestBodyType = Literal[
    "FULL",
    "DELTA",
]
r"""The type of the triggered sync."""


class PostForceSyncRequestBodyTypedDict(TypedDict):
    type: NotRequired[PostForceSyncRequestBodyType]
    r"""The type of the triggered sync."""


class PostForceSyncRequestBody(BaseModel):
    type: Optional[PostForceSyncRequestBodyType] = "FULL"
    r"""The type of the triggered sync."""
