"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel, Nullable, UNSET_SENTINEL
from kombo.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


GetConnectIntegrationByTokenTokenPositiveResponseSetupStatus = Literal[
    "INCOMPLETE",
    "FINAL_SYNC_PENDING",
    "COMPLETED",
]
r"""The setup_status is used in conjunction with the filtering and field mapping features. If these are enabled in the connection flow, the integration will start in an \"INCOMPLETE\" state and move to \"COMPLETE\" once all steps are finished.

- `INCOMPLETE`: Setup is still in progress. Some steps aren’t finished, so no data is available yet. Syncs only run as needed for setup.
- `FINAL_SYNC_PENDING`: Setup is complete, and the final sync is running. Data will be available after this sync is done.
- `COMPLETED`: Setup is fully finished, and the integration is ready to use.
"""


class GetConnectIntegrationByTokenTokenPositiveResponseDataTypedDict(TypedDict):
    tool: str
    id: str
    end_user_origin_id: Nullable[str]
    end_user_organization_name: str
    end_user_email: Nullable[str]
    setup_status: GetConnectIntegrationByTokenTokenPositiveResponseSetupStatus
    r"""The setup_status is used in conjunction with the filtering and field mapping features. If these are enabled in the connection flow, the integration will start in an \"INCOMPLETE\" state and move to \"COMPLETE\" once all steps are finished.

    - `INCOMPLETE`: Setup is still in progress. Some steps aren’t finished, so no data is available yet. Syncs only run as needed for setup.
    - `FINAL_SYNC_PENDING`: Setup is complete, and the final sync is running. Data will be available after this sync is done.
    - `COMPLETED`: Setup is fully finished, and the integration is ready to use.
    """


class GetConnectIntegrationByTokenTokenPositiveResponseData(BaseModel):
    tool: str

    id: str

    end_user_origin_id: Nullable[str]

    end_user_organization_name: str

    end_user_email: Nullable[str]

    setup_status: GetConnectIntegrationByTokenTokenPositiveResponseSetupStatus
    r"""The setup_status is used in conjunction with the filtering and field mapping features. If these are enabled in the connection flow, the integration will start in an \"INCOMPLETE\" state and move to \"COMPLETE\" once all steps are finished.

    - `INCOMPLETE`: Setup is still in progress. Some steps aren’t finished, so no data is available yet. Syncs only run as needed for setup.
    - `FINAL_SYNC_PENDING`: Setup is complete, and the final sync is running. Data will be available after this sync is done.
    - `COMPLETED`: Setup is fully finished, and the integration is ready to use.
    """

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["end_user_origin_id", "end_user_email"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetConnectIntegrationByTokenTokenPositiveResponseTypedDict(TypedDict):
    data: GetConnectIntegrationByTokenTokenPositiveResponseDataTypedDict
    status: Literal["success"]


class GetConnectIntegrationByTokenTokenPositiveResponse(BaseModel):
    data: GetConnectIntegrationByTokenTokenPositiveResponseData

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"
