"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .postintegrationsintegrationidrelinkrequestbody import (
    PostIntegrationsIntegrationIDRelinkRequestBody,
    PostIntegrationsIntegrationIDRelinkRequestBodyTypedDict,
)
from kombo.types import BaseModel
from kombo.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class PostIntegrationsIntegrationIDRelinkRequestTypedDict(TypedDict):
    integration_id: str
    r"""POST /integrations/:integration_id/relink Parameter"""
    body: PostIntegrationsIntegrationIDRelinkRequestBodyTypedDict
    r"""POST /integrations/:integration_id/relink Request body"""


class PostIntegrationsIntegrationIDRelinkRequest(BaseModel):
    integration_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""POST /integrations/:integration_id/relink Parameter"""

    body: Annotated[
        PostIntegrationsIntegrationIDRelinkRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
    r"""POST /integrations/:integration_id/relink Request body"""
