"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .schema1_union_2 import (
    Schema1Array2,
    Schema1Array2TypedDict,
    Schema1Union2,
    Schema1Union2TypedDict,
)
from .schema2_union_1 import (
    Schema2Array1,
    Schema2Array1TypedDict,
    Schema2Checkbox,
    Schema2CheckboxTypedDict,
    Schema2Date,
    Schema2DateTypedDict,
    Schema2Entry1,
    Schema2Entry1TypedDict,
    Schema2Entry2,
    Schema2Entry2TypedDict,
    Schema2File,
    Schema2FileRestrictions,
    Schema2FileRestrictionsTypedDict,
    Schema2FileTypedDict,
    Schema2MultiSelect,
    Schema2MultiSelectTypedDict,
    Schema2Number,
    Schema2NumberTypedDict,
    Schema2Object1,
    Schema2Object1TypedDict,
    Schema2OptionsInline1,
    Schema2OptionsInline1TypedDict,
    Schema2OptionsInline2,
    Schema2OptionsInline2TypedDict,
    Schema2OptionsReferenced1,
    Schema2OptionsReferenced1TypedDict,
    Schema2OptionsReferenced2,
    Schema2OptionsReferenced2TypedDict,
    Schema2OptionsUnion1,
    Schema2OptionsUnion1TypedDict,
    Schema2OptionsUnion2,
    Schema2OptionsUnion2TypedDict,
    Schema2RemoteID1,
    Schema2RemoteID1TypedDict,
    Schema2RemoteID2,
    Schema2RemoteID2TypedDict,
    Schema2SingleSelect,
    Schema2SingleSelectTypedDict,
    Schema2Text,
    Schema2TextTypedDict,
    Schema2UnifiedKey1,
    Schema2UnifiedKey2,
    Schema2UnifiedKey3,
    Schema2UnifiedKey4,
    Schema2UnifiedKey5,
    Schema2UnifiedKey6,
    Schema2UnifiedKey7,
    Schema2UnifiedKey8,
    Schema2Union1,
    Schema2Union1TypedDict,
)
from .schema2_union_2 import (
    Schema2Array2,
    Schema2Array2TypedDict,
    Schema2Object2,
    Schema2Object2TypedDict,
    Schema2Union2,
    Schema2Union2TypedDict,
)
from typing import TYPE_CHECKING
from importlib import import_module
import builtins
import sys

if TYPE_CHECKING:
    from .assessmentorderreceivedwebhookpayload import (
        AssessmentOrderReceivedWebhookPayload,
        AssessmentOrderReceivedWebhookPayloadApplication,
        AssessmentOrderReceivedWebhookPayloadApplicationTypedDict,
        AssessmentOrderReceivedWebhookPayloadCandidate,
        AssessmentOrderReceivedWebhookPayloadCandidateTypedDict,
        AssessmentOrderReceivedWebhookPayloadData,
        AssessmentOrderReceivedWebhookPayloadDataTypedDict,
        AssessmentOrderReceivedWebhookPayloadHiringTeam,
        AssessmentOrderReceivedWebhookPayloadHiringTeamRole,
        AssessmentOrderReceivedWebhookPayloadHiringTeamTypedDict,
        AssessmentOrderReceivedWebhookPayloadJob,
        AssessmentOrderReceivedWebhookPayloadJobTypedDict,
        AssessmentOrderReceivedWebhookPayloadLocation,
        AssessmentOrderReceivedWebhookPayloadLocationTypedDict,
        AssessmentOrderReceivedWebhookPayloadStatus,
        AssessmentOrderReceivedWebhookPayloadType,
        AssessmentOrderReceivedWebhookPayloadTypedDict,
    )
    from .connectionflowfailedwebhookpayload import (
        ConnectionFlowFailedWebhookPayload,
        ConnectionFlowFailedWebhookPayloadData,
        ConnectionFlowFailedWebhookPayloadDataTypedDict,
        ConnectionFlowFailedWebhookPayloadEndUser,
        ConnectionFlowFailedWebhookPayloadEndUserTypedDict,
        ConnectionFlowFailedWebhookPayloadIntegrationCategory,
        ConnectionFlowFailedWebhookPayloadType,
        ConnectionFlowFailedWebhookPayloadTypedDict,
    )
    from .datachangedwebhookpayload import (
        ChangedModel,
        ChangedModelTypedDict,
        DataChangedWebhookPayload,
        DataChangedWebhookPayloadData,
        DataChangedWebhookPayloadDataTypedDict,
        DataChangedWebhookPayloadIntegrationCategory,
        DataChangedWebhookPayloadType,
        DataChangedWebhookPayloadTypedDict,
        Name,
    )
    from .deleteatscandidatescandidateidtagsop import (
        DeleteAtsCandidatesCandidateIDTagsGlobals,
        DeleteAtsCandidatesCandidateIDTagsGlobalsTypedDict,
        DeleteAtsCandidatesCandidateIDTagsRequest,
        DeleteAtsCandidatesCandidateIDTagsRequestTypedDict,
    )
    from .deleteatscandidatescandidateidtagspositiveresponse import (
        DeleteAtsCandidatesCandidateIDTagsPositiveResponse,
        DeleteAtsCandidatesCandidateIDTagsPositiveResponseData,
        DeleteAtsCandidatesCandidateIDTagsPositiveResponseDataTypedDict,
        DeleteAtsCandidatesCandidateIDTagsPositiveResponseTypedDict,
        DeleteAtsCandidatesCandidateIDTagsPositiveResponseWarning,
        DeleteAtsCandidatesCandidateIDTagsPositiveResponseWarningTypedDict,
    )
    from .deleteatscandidatescandidateidtagsrequestbody import (
        DeleteAtsCandidatesCandidateIDTagsRequestBody,
        DeleteAtsCandidatesCandidateIDTagsRequestBodyGreenhouse,
        DeleteAtsCandidatesCandidateIDTagsRequestBodyGreenhouseTypedDict,
        DeleteAtsCandidatesCandidateIDTagsRequestBodyPostHeaders,
        DeleteAtsCandidatesCandidateIDTagsRequestBodyPostHeadersTypedDict,
        DeleteAtsCandidatesCandidateIDTagsRequestBodyRemoteFields,
        DeleteAtsCandidatesCandidateIDTagsRequestBodyRemoteFieldsTypedDict,
        DeleteAtsCandidatesCandidateIDTagsRequestBodyTag,
        DeleteAtsCandidatesCandidateIDTagsRequestBodyTagTypedDict,
        DeleteAtsCandidatesCandidateIDTagsRequestBodyTypedDict,
        DeleteAtsCandidatesCandidateIDTagsRequestBodyWorkable,
        DeleteAtsCandidatesCandidateIDTagsRequestBodyWorkableTypedDict,
    )
    from .deletehrisabsencesabsenceidop import (
        DeleteHrisAbsencesAbsenceIDGlobals,
        DeleteHrisAbsencesAbsenceIDGlobalsTypedDict,
        DeleteHrisAbsencesAbsenceIDRequest,
        DeleteHrisAbsencesAbsenceIDRequestTypedDict,
    )
    from .deletehrisabsencesabsenceidpositiveresponse import (
        DeleteHrisAbsencesAbsenceIDPositiveResponse,
        DeleteHrisAbsencesAbsenceIDPositiveResponseData,
        DeleteHrisAbsencesAbsenceIDPositiveResponseDataTypedDict,
        DeleteHrisAbsencesAbsenceIDPositiveResponseStatus,
        DeleteHrisAbsencesAbsenceIDPositiveResponseTypedDict,
        DeleteHrisAbsencesAbsenceIDPositiveResponseUnit,
        DeleteHrisAbsencesAbsenceIDPositiveResponseWarning,
        DeleteHrisAbsencesAbsenceIDPositiveResponseWarningTypedDict,
    )
    from .deletehrisabsencesabsenceidrequestbody import (
        DeleteHrisAbsencesAbsenceIDRequestBody,
        DeleteHrisAbsencesAbsenceIDRequestBodyAdpworkforcenow,
        DeleteHrisAbsencesAbsenceIDRequestBodyAdpworkforcenowTypedDict,
        DeleteHrisAbsencesAbsenceIDRequestBodyRemoteFields,
        DeleteHrisAbsencesAbsenceIDRequestBodyRemoteFieldsTypedDict,
        DeleteHrisAbsencesAbsenceIDRequestBodyTypedDict,
    )
    from .deleteintegrationsintegrationidop import (
        DeleteIntegrationsIntegrationIDRequest,
        DeleteIntegrationsIntegrationIDRequestTypedDict,
    )
    from .deleteintegrationsintegrationidpositiveresponse import (
        DeleteIntegrationsIntegrationIDPositiveResponse,
        DeleteIntegrationsIntegrationIDPositiveResponseData,
        DeleteIntegrationsIntegrationIDPositiveResponseDataTypedDict,
        DeleteIntegrationsIntegrationIDPositiveResponseTypedDict,
    )
    from .deleteintegrationsintegrationidrequestbody import (
        DeleteIntegrationsIntegrationIDRequestBody,
        DeleteIntegrationsIntegrationIDRequestBodyTypedDict,
    )
    from .getassessmentordersopenop import (
        GetAssessmentOrdersOpenGlobals,
        GetAssessmentOrdersOpenGlobalsTypedDict,
        GetAssessmentOrdersOpenRequest,
        GetAssessmentOrdersOpenRequestTypedDict,
        GetAssessmentOrdersOpenResponse,
        GetAssessmentOrdersOpenResponseTypedDict,
    )
    from .getassessmentordersopenpositiveresponse import (
        GetAssessmentOrdersOpenPositiveResponse,
        GetAssessmentOrdersOpenPositiveResponseApplication,
        GetAssessmentOrdersOpenPositiveResponseApplicationTypedDict,
        GetAssessmentOrdersOpenPositiveResponseCandidate,
        GetAssessmentOrdersOpenPositiveResponseCandidateTypedDict,
        GetAssessmentOrdersOpenPositiveResponseData,
        GetAssessmentOrdersOpenPositiveResponseDataTypedDict,
        GetAssessmentOrdersOpenPositiveResponseHiringTeam,
        GetAssessmentOrdersOpenPositiveResponseHiringTeamRole,
        GetAssessmentOrdersOpenPositiveResponseHiringTeamTypedDict,
        GetAssessmentOrdersOpenPositiveResponseJob,
        GetAssessmentOrdersOpenPositiveResponseJobTypedDict,
        GetAssessmentOrdersOpenPositiveResponseLocation,
        GetAssessmentOrdersOpenPositiveResponseLocationTypedDict,
        GetAssessmentOrdersOpenPositiveResponseResult,
        GetAssessmentOrdersOpenPositiveResponseResultTypedDict,
        GetAssessmentOrdersOpenPositiveResponseTypedDict,
    )
    from .getassessmentpackagesop import (
        GetAssessmentPackagesGlobals,
        GetAssessmentPackagesGlobalsTypedDict,
        GetAssessmentPackagesRequest,
        GetAssessmentPackagesRequestTypedDict,
    )
    from .getassessmentpackagespositiveresponse import (
        GetAssessmentPackagesPositiveResponse,
        GetAssessmentPackagesPositiveResponseData,
        GetAssessmentPackagesPositiveResponseDataTypedDict,
        GetAssessmentPackagesPositiveResponsePackage,
        GetAssessmentPackagesPositiveResponsePackageTypedDict,
        GetAssessmentPackagesPositiveResponseType,
        GetAssessmentPackagesPositiveResponseTypedDict,
    )
    from .getatsapplicationsapplicationidattachmentsop import (
        GetAtsApplicationsApplicationIDAttachmentsGlobals,
        GetAtsApplicationsApplicationIDAttachmentsGlobalsTypedDict,
        GetAtsApplicationsApplicationIDAttachmentsRequest,
        GetAtsApplicationsApplicationIDAttachmentsRequestTypedDict,
    )
    from .getatsapplicationsapplicationidattachmentspositiveresponse import (
        GetAtsApplicationsApplicationIDAttachmentsPositiveResponse,
        GetAtsApplicationsApplicationIDAttachmentsPositiveResponseData,
        GetAtsApplicationsApplicationIDAttachmentsPositiveResponseDataTypedDict,
        GetAtsApplicationsApplicationIDAttachmentsPositiveResponseResult,
        GetAtsApplicationsApplicationIDAttachmentsPositiveResponseResultTypedDict,
        GetAtsApplicationsApplicationIDAttachmentsPositiveResponseType,
        GetAtsApplicationsApplicationIDAttachmentsPositiveResponseTypedDict,
        GetAtsApplicationsApplicationIDAttachmentsPositiveResponseWarning,
        GetAtsApplicationsApplicationIDAttachmentsPositiveResponseWarningTypedDict,
    )
    from .getatsapplicationsop import (
        GetAtsApplicationsGlobals,
        GetAtsApplicationsGlobalsTypedDict,
        GetAtsApplicationsRequest,
        GetAtsApplicationsRequestTypedDict,
        GetAtsApplicationsResponse,
        GetAtsApplicationsResponseTypedDict,
    )
    from .getatsapplicationspositiveresponse import (
        GetAtsApplicationsPositiveResponse,
        GetAtsApplicationsPositiveResponseAnswer1,
        GetAtsApplicationsPositiveResponseAnswer1TypedDict,
        GetAtsApplicationsPositiveResponseAnswer2,
        GetAtsApplicationsPositiveResponseAnswer2TypedDict,
        GetAtsApplicationsPositiveResponseAnswer3,
        GetAtsApplicationsPositiveResponseAnswer3TypedDict,
        GetAtsApplicationsPositiveResponseAnswer4,
        GetAtsApplicationsPositiveResponseAnswer4TypedDict,
        GetAtsApplicationsPositiveResponseAnswer5,
        GetAtsApplicationsPositiveResponseAnswer5TypedDict,
        GetAtsApplicationsPositiveResponseAnswer6,
        GetAtsApplicationsPositiveResponseAnswer6TypedDict,
        GetAtsApplicationsPositiveResponseAnswer7,
        GetAtsApplicationsPositiveResponseAnswer7TypedDict,
        GetAtsApplicationsPositiveResponseCandidate,
        GetAtsApplicationsPositiveResponseCandidateTypedDict,
        GetAtsApplicationsPositiveResponseCurrentStage,
        GetAtsApplicationsPositiveResponseCurrentStageTypedDict,
        GetAtsApplicationsPositiveResponseData,
        GetAtsApplicationsPositiveResponseDataTypedDict,
        GetAtsApplicationsPositiveResponseEmailAddress,
        GetAtsApplicationsPositiveResponseEmailAddressTypedDict,
        GetAtsApplicationsPositiveResponseJob,
        GetAtsApplicationsPositiveResponseJobTypedDict,
        GetAtsApplicationsPositiveResponseLocation,
        GetAtsApplicationsPositiveResponseLocationTypedDict,
        GetAtsApplicationsPositiveResponseOutcome,
        GetAtsApplicationsPositiveResponsePhoneNumber,
        GetAtsApplicationsPositiveResponsePhoneNumberTypedDict,
        GetAtsApplicationsPositiveResponseQuestionBoolean,
        GetAtsApplicationsPositiveResponseQuestionBooleanTypedDict,
        GetAtsApplicationsPositiveResponseQuestionDate,
        GetAtsApplicationsPositiveResponseQuestionDateTypedDict,
        GetAtsApplicationsPositiveResponseQuestionMultiSelect,
        GetAtsApplicationsPositiveResponseQuestionMultiSelectTypedDict,
        GetAtsApplicationsPositiveResponseQuestionNumber,
        GetAtsApplicationsPositiveResponseQuestionNumberTypedDict,
        GetAtsApplicationsPositiveResponseQuestionSingleSelect,
        GetAtsApplicationsPositiveResponseQuestionSingleSelectTypedDict,
        GetAtsApplicationsPositiveResponseQuestionText,
        GetAtsApplicationsPositiveResponseQuestionTextTypedDict,
        GetAtsApplicationsPositiveResponseQuestionUnknown,
        GetAtsApplicationsPositiveResponseQuestionUnknownTypedDict,
        GetAtsApplicationsPositiveResponseResult,
        GetAtsApplicationsPositiveResponseResultTypedDict,
        GetAtsApplicationsPositiveResponseScreeningQuestionAnswer1,
        GetAtsApplicationsPositiveResponseScreeningQuestionAnswer1TypedDict,
        GetAtsApplicationsPositiveResponseScreeningQuestionAnswer2,
        GetAtsApplicationsPositiveResponseScreeningQuestionAnswer2TypedDict,
        GetAtsApplicationsPositiveResponseScreeningQuestionAnswer3,
        GetAtsApplicationsPositiveResponseScreeningQuestionAnswer3TypedDict,
        GetAtsApplicationsPositiveResponseScreeningQuestionAnswer4,
        GetAtsApplicationsPositiveResponseScreeningQuestionAnswer4TypedDict,
        GetAtsApplicationsPositiveResponseScreeningQuestionAnswer5,
        GetAtsApplicationsPositiveResponseScreeningQuestionAnswer5TypedDict,
        GetAtsApplicationsPositiveResponseScreeningQuestionAnswer6,
        GetAtsApplicationsPositiveResponseScreeningQuestionAnswer6TypedDict,
        GetAtsApplicationsPositiveResponseScreeningQuestionAnswer7,
        GetAtsApplicationsPositiveResponseScreeningQuestionAnswer7TypedDict,
        GetAtsApplicationsPositiveResponseScreeningQuestionAnswerUnion,
        GetAtsApplicationsPositiveResponseScreeningQuestionAnswerUnionTypedDict,
        GetAtsApplicationsPositiveResponseSocialMedia,
        GetAtsApplicationsPositiveResponseSocialMediaTypedDict,
        GetAtsApplicationsPositiveResponseStatus,
        GetAtsApplicationsPositiveResponseTag,
        GetAtsApplicationsPositiveResponseTagTypedDict,
        GetAtsApplicationsPositiveResponseTypedDict,
        Interview,
        InterviewTypedDict,
        Offer,
        OfferTypedDict,
    )
    from .getatsapplicationstagesop import (
        GetAtsApplicationStagesGlobals,
        GetAtsApplicationStagesGlobalsTypedDict,
        GetAtsApplicationStagesRequest,
        GetAtsApplicationStagesRequestTypedDict,
        GetAtsApplicationStagesResponse,
        GetAtsApplicationStagesResponseTypedDict,
    )
    from .getatsapplicationstagespositiveresponse import (
        GetAtsApplicationStagesPositiveResponse,
        GetAtsApplicationStagesPositiveResponseData,
        GetAtsApplicationStagesPositiveResponseDataTypedDict,
        GetAtsApplicationStagesPositiveResponseResult,
        GetAtsApplicationStagesPositiveResponseResultTypedDict,
        GetAtsApplicationStagesPositiveResponseTypedDict,
    )
    from .getatscandidatescandidateidattachmentsop import (
        GetAtsCandidatesCandidateIDAttachmentsGlobals,
        GetAtsCandidatesCandidateIDAttachmentsGlobalsTypedDict,
        GetAtsCandidatesCandidateIDAttachmentsRequest,
        GetAtsCandidatesCandidateIDAttachmentsRequestTypedDict,
    )
    from .getatscandidatescandidateidattachmentspositiveresponse import (
        GetAtsCandidatesCandidateIDAttachmentsPositiveResponse,
        GetAtsCandidatesCandidateIDAttachmentsPositiveResponseData,
        GetAtsCandidatesCandidateIDAttachmentsPositiveResponseDataTypedDict,
        GetAtsCandidatesCandidateIDAttachmentsPositiveResponseResult,
        GetAtsCandidatesCandidateIDAttachmentsPositiveResponseResultTypedDict,
        GetAtsCandidatesCandidateIDAttachmentsPositiveResponseType,
        GetAtsCandidatesCandidateIDAttachmentsPositiveResponseTypedDict,
        GetAtsCandidatesCandidateIDAttachmentsPositiveResponseWarning,
        GetAtsCandidatesCandidateIDAttachmentsPositiveResponseWarningTypedDict,
    )
    from .getatscandidatesop import (
        GetAtsCandidatesGlobals,
        GetAtsCandidatesGlobalsTypedDict,
        GetAtsCandidatesRequest,
        GetAtsCandidatesRequestTypedDict,
        GetAtsCandidatesResponse,
        GetAtsCandidatesResponseTypedDict,
    )
    from .getatscandidatespositiveresponse import (
        GetAtsCandidatesPositiveResponse,
        GetAtsCandidatesPositiveResponseApplication,
        GetAtsCandidatesPositiveResponseApplicationTypedDict,
        GetAtsCandidatesPositiveResponseCurrentStage,
        GetAtsCandidatesPositiveResponseCurrentStageTypedDict,
        GetAtsCandidatesPositiveResponseData,
        GetAtsCandidatesPositiveResponseDataTypedDict,
        GetAtsCandidatesPositiveResponseEmailAddress,
        GetAtsCandidatesPositiveResponseEmailAddressTypedDict,
        GetAtsCandidatesPositiveResponseJob,
        GetAtsCandidatesPositiveResponseJobTypedDict,
        GetAtsCandidatesPositiveResponseLocation,
        GetAtsCandidatesPositiveResponseLocationTypedDict,
        GetAtsCandidatesPositiveResponseOutcome,
        GetAtsCandidatesPositiveResponsePhoneNumber,
        GetAtsCandidatesPositiveResponsePhoneNumberTypedDict,
        GetAtsCandidatesPositiveResponseResult,
        GetAtsCandidatesPositiveResponseResultTypedDict,
        GetAtsCandidatesPositiveResponseSocialMedia,
        GetAtsCandidatesPositiveResponseSocialMediaTypedDict,
        GetAtsCandidatesPositiveResponseTag,
        GetAtsCandidatesPositiveResponseTagTypedDict,
        GetAtsCandidatesPositiveResponseTypedDict,
    )
    from .getatsinterviewsop import (
        GetAtsInterviewsGlobals,
        GetAtsInterviewsGlobalsTypedDict,
        GetAtsInterviewsRequest,
        GetAtsInterviewsRequestTypedDict,
        GetAtsInterviewsResponse,
        GetAtsInterviewsResponseTypedDict,
    )
    from .getatsinterviewspositiveresponse import (
        GetAtsInterviewsPositiveResponse,
        GetAtsInterviewsPositiveResponseApplication,
        GetAtsInterviewsPositiveResponseApplicationTypedDict,
        GetAtsInterviewsPositiveResponseCandidate,
        GetAtsInterviewsPositiveResponseCandidateTypedDict,
        GetAtsInterviewsPositiveResponseData,
        GetAtsInterviewsPositiveResponseDataTypedDict,
        GetAtsInterviewsPositiveResponseEmailAddress,
        GetAtsInterviewsPositiveResponseEmailAddressTypedDict,
        GetAtsInterviewsPositiveResponseJob,
        GetAtsInterviewsPositiveResponseJobTypedDict,
        GetAtsInterviewsPositiveResponseLocation,
        GetAtsInterviewsPositiveResponseLocationTypedDict,
        GetAtsInterviewsPositiveResponseOutcome,
        GetAtsInterviewsPositiveResponseResult,
        GetAtsInterviewsPositiveResponseResultTypedDict,
        GetAtsInterviewsPositiveResponseTypedDict,
        User,
        UserTypedDict,
    )
    from .getatsjobsop import (
        GetAtsJobsGlobals,
        GetAtsJobsGlobalsTypedDict,
        GetAtsJobsRequest,
        GetAtsJobsRequestTypedDict,
        GetAtsJobsResponse,
        GetAtsJobsResponseTypedDict,
    )
    from .getatsjobspositiveresponse import (
        DisplayType1,
        DisplayType2,
        DisplayType3,
        Format,
        FormatBoolean,
        FormatBooleanTypedDict,
        FormatDate,
        FormatDateTypedDict,
        FormatFile,
        FormatFileTypedDict,
        FormatInformation,
        FormatInformationTypedDict,
        FormatMultiSelect,
        FormatMultiSelectTypedDict,
        FormatNumber,
        FormatNumberTypedDict,
        FormatSingleSelect,
        FormatSingleSelectTypedDict,
        FormatText,
        FormatTextTypedDict,
        FormatTypedDict,
        FormatUnknown,
        FormatUnknownTypedDict,
        GetAtsJobsPositiveResponse,
        GetAtsJobsPositiveResponseCategory,
        GetAtsJobsPositiveResponseData,
        GetAtsJobsPositiveResponseDataTypedDict,
        GetAtsJobsPositiveResponseEmploymentType,
        GetAtsJobsPositiveResponseHiringTeam,
        GetAtsJobsPositiveResponseHiringTeamRole,
        GetAtsJobsPositiveResponseHiringTeamTypedDict,
        GetAtsJobsPositiveResponseLocation,
        GetAtsJobsPositiveResponseLocationTypedDict,
        GetAtsJobsPositiveResponseResult,
        GetAtsJobsPositiveResponseResultTypedDict,
        GetAtsJobsPositiveResponseStatus,
        GetAtsJobsPositiveResponseTypedDict,
        JobPosting,
        JobPostingStatus,
        JobPostingTypedDict,
        JobPostingVisibility,
        Option1,
        Option1TypedDict,
        Option2,
        Option2TypedDict,
        PreconditionOptions,
        PreconditionOptionsTypedDict,
        RemoteWorkStatus,
        SalaryPeriod,
        ScreeningQuestion,
        ScreeningQuestionTypedDict,
        Stage,
        StageTypedDict,
        Visibility,
    )
    from .getatsoffersop import (
        GetAtsOffersGlobals,
        GetAtsOffersGlobalsTypedDict,
        GetAtsOffersRequest,
        GetAtsOffersRequestTypedDict,
        GetAtsOffersResponse,
        GetAtsOffersResponseTypedDict,
    )
    from .getatsofferspositiveresponse import (
        GetAtsOffersPositiveResponse,
        GetAtsOffersPositiveResponseApplication,
        GetAtsOffersPositiveResponseApplicationTypedDict,
        GetAtsOffersPositiveResponseCandidate,
        GetAtsOffersPositiveResponseCandidateTypedDict,
        GetAtsOffersPositiveResponseData,
        GetAtsOffersPositiveResponseDataTypedDict,
        GetAtsOffersPositiveResponseEmailAddress,
        GetAtsOffersPositiveResponseEmailAddressTypedDict,
        GetAtsOffersPositiveResponseJob,
        GetAtsOffersPositiveResponseJobTypedDict,
        GetAtsOffersPositiveResponseResult,
        GetAtsOffersPositiveResponseResultTypedDict,
        GetAtsOffersPositiveResponseStatus,
        GetAtsOffersPositiveResponseTypedDict,
    )
    from .getatsrejectionreasonsop import (
        GetAtsRejectionReasonsGlobals,
        GetAtsRejectionReasonsGlobalsTypedDict,
        GetAtsRejectionReasonsRequest,
        GetAtsRejectionReasonsRequestTypedDict,
        GetAtsRejectionReasonsResponse,
        GetAtsRejectionReasonsResponseTypedDict,
    )
    from .getatsrejectionreasonspositiveresponse import (
        GetAtsRejectionReasonsPositiveResponse,
        GetAtsRejectionReasonsPositiveResponseData,
        GetAtsRejectionReasonsPositiveResponseDataTypedDict,
        GetAtsRejectionReasonsPositiveResponseResult,
        GetAtsRejectionReasonsPositiveResponseResultTypedDict,
        GetAtsRejectionReasonsPositiveResponseTypedDict,
    )
    from .getatstagsop import (
        GetAtsTagsGlobals,
        GetAtsTagsGlobalsTypedDict,
        GetAtsTagsRequest,
        GetAtsTagsRequestTypedDict,
        GetAtsTagsResponse,
        GetAtsTagsResponseTypedDict,
    )
    from .getatstagspositiveresponse import (
        GetAtsTagsPositiveResponse,
        GetAtsTagsPositiveResponseData,
        GetAtsTagsPositiveResponseDataTypedDict,
        GetAtsTagsPositiveResponseResult,
        GetAtsTagsPositiveResponseResultTypedDict,
        GetAtsTagsPositiveResponseTypedDict,
    )
    from .getatsusersop import (
        GetAtsUsersGlobals,
        GetAtsUsersGlobalsTypedDict,
        GetAtsUsersRequest,
        GetAtsUsersRequestTypedDict,
        GetAtsUsersResponse,
        GetAtsUsersResponseTypedDict,
    )
    from .getatsuserspositiveresponse import (
        GetAtsUsersPositiveResponse,
        GetAtsUsersPositiveResponseData,
        GetAtsUsersPositiveResponseDataTypedDict,
        GetAtsUsersPositiveResponseResult,
        GetAtsUsersPositiveResponseResultTypedDict,
        GetAtsUsersPositiveResponseStatus,
        GetAtsUsersPositiveResponseTypedDict,
    )
    from .getcheckapikeypositiveresponse import (
        GetCheckAPIKeyPositiveResponse,
        GetCheckAPIKeyPositiveResponseData,
        GetCheckAPIKeyPositiveResponseDataTypedDict,
        GetCheckAPIKeyPositiveResponseTypedDict,
    )
    from .getconnectintegrationbytokentokenop import (
        GetConnectIntegrationByTokenTokenRequest,
        GetConnectIntegrationByTokenTokenRequestTypedDict,
    )
    from .getconnectintegrationbytokentokenpositiveresponse import (
        GetConnectIntegrationByTokenTokenPositiveResponse,
        GetConnectIntegrationByTokenTokenPositiveResponseData,
        GetConnectIntegrationByTokenTokenPositiveResponseDataTypedDict,
        GetConnectIntegrationByTokenTokenPositiveResponseSetupStatus,
        GetConnectIntegrationByTokenTokenPositiveResponseTypedDict,
    )
    from .gethrisabsencesop import (
        GetHrisAbsencesGlobals,
        GetHrisAbsencesGlobalsTypedDict,
        GetHrisAbsencesRequest,
        GetHrisAbsencesRequestTypedDict,
        GetHrisAbsencesResponse,
        GetHrisAbsencesResponseTypedDict,
    )
    from .gethrisabsencespositiveresponse import (
        GetHrisAbsencesPositiveResponse,
        GetHrisAbsencesPositiveResponseData,
        GetHrisAbsencesPositiveResponseDataTypedDict,
        GetHrisAbsencesPositiveResponseResult,
        GetHrisAbsencesPositiveResponseResultTypedDict,
        GetHrisAbsencesPositiveResponseStatus,
        GetHrisAbsencesPositiveResponseType,
        GetHrisAbsencesPositiveResponseTypeTypedDict,
        GetHrisAbsencesPositiveResponseTypeUnit,
        GetHrisAbsencesPositiveResponseTypedDict,
        GetHrisAbsencesPositiveResponseUnit,
    )
    from .gethrisabsencetypesop import (
        GetHrisAbsenceTypesGlobals,
        GetHrisAbsenceTypesGlobalsTypedDict,
        GetHrisAbsenceTypesRequest,
        GetHrisAbsenceTypesRequestTypedDict,
        GetHrisAbsenceTypesResponse,
        GetHrisAbsenceTypesResponseTypedDict,
    )
    from .gethrisabsencetypespositiveresponse import (
        GetHrisAbsenceTypesPositiveResponse,
        GetHrisAbsenceTypesPositiveResponseData,
        GetHrisAbsenceTypesPositiveResponseDataTypedDict,
        GetHrisAbsenceTypesPositiveResponseResult,
        GetHrisAbsenceTypesPositiveResponseResultTypedDict,
        GetHrisAbsenceTypesPositiveResponseTypedDict,
        GetHrisAbsenceTypesPositiveResponseUnit,
    )
    from .gethrisemployeedocumentcategoriesop import (
        GetHrisEmployeeDocumentCategoriesGlobals,
        GetHrisEmployeeDocumentCategoriesGlobalsTypedDict,
        GetHrisEmployeeDocumentCategoriesRequest,
        GetHrisEmployeeDocumentCategoriesRequestTypedDict,
        GetHrisEmployeeDocumentCategoriesResponse,
        GetHrisEmployeeDocumentCategoriesResponseTypedDict,
    )
    from .gethrisemployeedocumentcategoriespositiveresponse import (
        GetHrisEmployeeDocumentCategoriesPositiveResponse,
        GetHrisEmployeeDocumentCategoriesPositiveResponseData,
        GetHrisEmployeeDocumentCategoriesPositiveResponseDataTypedDict,
        GetHrisEmployeeDocumentCategoriesPositiveResponseResult,
        GetHrisEmployeeDocumentCategoriesPositiveResponseResultTypedDict,
        GetHrisEmployeeDocumentCategoriesPositiveResponseTypedDict,
    )
    from .gethrisemployeesformop import (
        GetHrisEmployeesFormGlobals,
        GetHrisEmployeesFormGlobalsTypedDict,
        GetHrisEmployeesFormRequest,
        GetHrisEmployeesFormRequestTypedDict,
    )
    from .gethrisemployeesformpositiveresponse import (
        GetHrisEmployeesFormPositiveResponse,
        GetHrisEmployeesFormPositiveResponseData,
        GetHrisEmployeesFormPositiveResponseDataTypedDict,
        GetHrisEmployeesFormPositiveResponseEntry1,
        GetHrisEmployeesFormPositiveResponseEntry1TypedDict,
        GetHrisEmployeesFormPositiveResponseEntry2,
        GetHrisEmployeesFormPositiveResponseEntry2TypedDict,
        GetHrisEmployeesFormPositiveResponseFileRestrictions,
        GetHrisEmployeesFormPositiveResponseFileRestrictionsTypedDict,
        GetHrisEmployeesFormPositiveResponseOptionsInline1,
        GetHrisEmployeesFormPositiveResponseOptionsInline1TypedDict,
        GetHrisEmployeesFormPositiveResponseOptionsInline2,
        GetHrisEmployeesFormPositiveResponseOptionsInline2TypedDict,
        GetHrisEmployeesFormPositiveResponseOptionsReferenced1,
        GetHrisEmployeesFormPositiveResponseOptionsReferenced1TypedDict,
        GetHrisEmployeesFormPositiveResponseOptionsReferenced2,
        GetHrisEmployeesFormPositiveResponseOptionsReferenced2TypedDict,
        GetHrisEmployeesFormPositiveResponseOptionsUnion1,
        GetHrisEmployeesFormPositiveResponseOptionsUnion1TypedDict,
        GetHrisEmployeesFormPositiveResponseOptionsUnion2,
        GetHrisEmployeesFormPositiveResponseOptionsUnion2TypedDict,
        GetHrisEmployeesFormPositiveResponseRemoteID1,
        GetHrisEmployeesFormPositiveResponseRemoteID1TypedDict,
        GetHrisEmployeesFormPositiveResponseRemoteID2,
        GetHrisEmployeesFormPositiveResponseRemoteID2TypedDict,
        GetHrisEmployeesFormPositiveResponseTypedDict,
        GetHrisEmployeesFormPositiveResponseUnifiedKey1,
        GetHrisEmployeesFormPositiveResponseUnifiedKey2,
        GetHrisEmployeesFormPositiveResponseUnifiedKey3,
        GetHrisEmployeesFormPositiveResponseUnifiedKey4,
        GetHrisEmployeesFormPositiveResponseUnifiedKey5,
        GetHrisEmployeesFormPositiveResponseUnifiedKey6,
        GetHrisEmployeesFormPositiveResponseUnifiedKey7,
        GetHrisEmployeesFormPositiveResponseUnifiedKey8,
        GetHrisEmployeesFormPositiveResponseWarning,
        GetHrisEmployeesFormPositiveResponseWarningTypedDict,
        Properties,
        PropertiesArray,
        PropertiesArrayTypedDict,
        PropertiesCheckbox,
        PropertiesCheckboxTypedDict,
        PropertiesDate,
        PropertiesDateTypedDict,
        PropertiesFile,
        PropertiesFileTypedDict,
        PropertiesMultiSelect,
        PropertiesMultiSelectTypedDict,
        PropertiesNumber,
        PropertiesNumberTypedDict,
        PropertiesObject,
        PropertiesObjectTypedDict,
        PropertiesSingleSelect,
        PropertiesSingleSelectTypedDict,
        PropertiesText,
        PropertiesTextTypedDict,
        PropertiesTypedDict,
    )
    from .gethrisemployeesop import (
        GetHrisEmployeesGlobals,
        GetHrisEmployeesGlobalsTypedDict,
        GetHrisEmployeesRequest,
        GetHrisEmployeesRequestTypedDict,
        GetHrisEmployeesResponse,
        GetHrisEmployeesResponseTypedDict,
    )
    from .gethrisemployeespositiveresponse import (
        BankAccount,
        BankAccountTypedDict,
        DomesticBankRouting,
        DomesticBankRoutingType,
        DomesticBankRoutingTypedDict,
        Employment,
        EmploymentEmploymentType,
        EmploymentStatus,
        EmploymentTypedDict,
        Ethnicity,
        GetHrisEmployeesPositiveResponse,
        GetHrisEmployeesPositiveResponseBalanceUnit,
        GetHrisEmployeesPositiveResponseData,
        GetHrisEmployeesPositiveResponseDataTypedDict,
        GetHrisEmployeesPositiveResponseEmploymentType,
        GetHrisEmployeesPositiveResponseGender,
        GetHrisEmployeesPositiveResponsePayFrequency,
        GetHrisEmployeesPositiveResponsePayPeriod,
        GetHrisEmployeesPositiveResponseResult,
        GetHrisEmployeesPositiveResponseResultTypedDict,
        GetHrisEmployeesPositiveResponseTypedDict,
        GetHrisEmployeesPositiveResponseUsedUnit,
        Group,
        GroupType,
        GroupTypedDict,
        HomeAddress,
        HomeAddressTypedDict,
        LegalEntity,
        LegalEntityAddress,
        LegalEntityAddressTypedDict,
        LegalEntityTypedDict,
        Manager,
        ManagerEmploymentStatus,
        ManagerTypedDict,
        MaritalStatus,
        TimeOffBalance,
        TimeOffBalanceTypedDict,
        WorkLocation,
        WorkLocationAddress,
        WorkLocationAddressTypedDict,
        WorkLocationTypedDict,
    )
    from .gethrisemploymentsop import (
        GetHrisEmploymentsGlobals,
        GetHrisEmploymentsGlobalsTypedDict,
        GetHrisEmploymentsRequest,
        GetHrisEmploymentsRequestTypedDict,
        GetHrisEmploymentsResponse,
        GetHrisEmploymentsResponseTypedDict,
    )
    from .gethrisemploymentspositiveresponse import (
        GetHrisEmploymentsPositiveResponse,
        GetHrisEmploymentsPositiveResponseData,
        GetHrisEmploymentsPositiveResponseDataTypedDict,
        GetHrisEmploymentsPositiveResponseEmploymentType,
        GetHrisEmploymentsPositiveResponsePayFrequency,
        GetHrisEmploymentsPositiveResponsePayPeriod,
        GetHrisEmploymentsPositiveResponseResult,
        GetHrisEmploymentsPositiveResponseResultTypedDict,
        GetHrisEmploymentsPositiveResponseTypedDict,
    )
    from .gethrisgroupsop import (
        GetHrisGroupsGlobals,
        GetHrisGroupsGlobalsTypedDict,
        GetHrisGroupsRequest,
        GetHrisGroupsRequestTypedDict,
        GetHrisGroupsResponse,
        GetHrisGroupsResponseTypedDict,
    )
    from .gethrisgroupspositiveresponse import (
        GetHrisGroupsPositiveResponse,
        GetHrisGroupsPositiveResponseData,
        GetHrisGroupsPositiveResponseDataTypedDict,
        GetHrisGroupsPositiveResponseResult,
        GetHrisGroupsPositiveResponseResultTypedDict,
        GetHrisGroupsPositiveResponseType,
        GetHrisGroupsPositiveResponseTypedDict,
    )
    from .gethrislegalentitiesop import (
        GetHrisLegalEntitiesGlobals,
        GetHrisLegalEntitiesGlobalsTypedDict,
        GetHrisLegalEntitiesRequest,
        GetHrisLegalEntitiesRequestTypedDict,
        GetHrisLegalEntitiesResponse,
        GetHrisLegalEntitiesResponseTypedDict,
    )
    from .gethrislegalentitiespositiveresponse import (
        GetHrisLegalEntitiesPositiveResponse,
        GetHrisLegalEntitiesPositiveResponseAddress,
        GetHrisLegalEntitiesPositiveResponseAddressTypedDict,
        GetHrisLegalEntitiesPositiveResponseData,
        GetHrisLegalEntitiesPositiveResponseDataTypedDict,
        GetHrisLegalEntitiesPositiveResponseResult,
        GetHrisLegalEntitiesPositiveResponseResultTypedDict,
        GetHrisLegalEntitiesPositiveResponseTypedDict,
    )
    from .gethrislocationsop import (
        GetHrisLocationsGlobals,
        GetHrisLocationsGlobalsTypedDict,
        GetHrisLocationsRequest,
        GetHrisLocationsRequestTypedDict,
        GetHrisLocationsResponse,
        GetHrisLocationsResponseTypedDict,
    )
    from .gethrislocationspositiveresponse import (
        GetHrisLocationsPositiveResponse,
        GetHrisLocationsPositiveResponseAddress,
        GetHrisLocationsPositiveResponseAddressTypedDict,
        GetHrisLocationsPositiveResponseData,
        GetHrisLocationsPositiveResponseDataTypedDict,
        GetHrisLocationsPositiveResponseResult,
        GetHrisLocationsPositiveResponseResultTypedDict,
        GetHrisLocationsPositiveResponseTypedDict,
    )
    from .gethrisperformancereviewcyclesop import (
        GetHrisPerformanceReviewCyclesGlobals,
        GetHrisPerformanceReviewCyclesGlobalsTypedDict,
        GetHrisPerformanceReviewCyclesRequest,
        GetHrisPerformanceReviewCyclesRequestTypedDict,
        GetHrisPerformanceReviewCyclesResponse,
        GetHrisPerformanceReviewCyclesResponseTypedDict,
    )
    from .gethrisperformancereviewcyclespositiveresponse import (
        GetHrisPerformanceReviewCyclesPositiveResponse,
        GetHrisPerformanceReviewCyclesPositiveResponseData,
        GetHrisPerformanceReviewCyclesPositiveResponseDataTypedDict,
        GetHrisPerformanceReviewCyclesPositiveResponseResult,
        GetHrisPerformanceReviewCyclesPositiveResponseResultTypedDict,
        GetHrisPerformanceReviewCyclesPositiveResponseTypedDict,
    )
    from .gethrisperformancereviewsop import (
        GetHrisPerformanceReviewsGlobals,
        GetHrisPerformanceReviewsGlobalsTypedDict,
        GetHrisPerformanceReviewsRequest,
        GetHrisPerformanceReviewsRequestTypedDict,
        GetHrisPerformanceReviewsResponse,
        GetHrisPerformanceReviewsResponseTypedDict,
    )
    from .gethrisperformancereviewspositiveresponse import (
        GetHrisPerformanceReviewsPositiveResponse,
        GetHrisPerformanceReviewsPositiveResponseData,
        GetHrisPerformanceReviewsPositiveResponseDataTypedDict,
        GetHrisPerformanceReviewsPositiveResponseResult,
        GetHrisPerformanceReviewsPositiveResponseResultTypedDict,
        GetHrisPerformanceReviewsPositiveResponseType,
        GetHrisPerformanceReviewsPositiveResponseTypedDict,
        ReviewCycle,
        ReviewCycleTypedDict,
        Reviewee,
        RevieweeTypedDict,
        Reviewer,
        ReviewerTypedDict,
        SummaryRating,
        SummaryRatingNumeric,
        SummaryRatingNumericTypedDict,
        SummaryRatingSingleSelect,
        SummaryRatingSingleSelectTypedDict,
        SummaryRatingTypedDict,
    )
    from .gethristimeoffbalancesop import (
        GetHrisTimeOffBalancesGlobals,
        GetHrisTimeOffBalancesGlobalsTypedDict,
        GetHrisTimeOffBalancesRequest,
        GetHrisTimeOffBalancesRequestTypedDict,
        GetHrisTimeOffBalancesResponse,
        GetHrisTimeOffBalancesResponseTypedDict,
    )
    from .gethristimeoffbalancespositiveresponse import (
        GetHrisTimeOffBalancesPositiveResponse,
        GetHrisTimeOffBalancesPositiveResponseBalanceUnit,
        GetHrisTimeOffBalancesPositiveResponseData,
        GetHrisTimeOffBalancesPositiveResponseDataTypedDict,
        GetHrisTimeOffBalancesPositiveResponseResult,
        GetHrisTimeOffBalancesPositiveResponseResultTypedDict,
        GetHrisTimeOffBalancesPositiveResponseType,
        GetHrisTimeOffBalancesPositiveResponseTypeTypedDict,
        GetHrisTimeOffBalancesPositiveResponseTypedDict,
        GetHrisTimeOffBalancesPositiveResponseUnit,
        GetHrisTimeOffBalancesPositiveResponseUsedUnit,
    )
    from .gethristimesheetsop import (
        GetHrisTimesheetsGlobals,
        GetHrisTimesheetsGlobalsTypedDict,
        GetHrisTimesheetsRequest,
        GetHrisTimesheetsRequestTypedDict,
        GetHrisTimesheetsResponse,
        GetHrisTimesheetsResponseTypedDict,
    )
    from .gethristimesheetspositiveresponse import (
        Break,
        BreakTypedDict,
        GetHrisTimesheetsPositiveResponse,
        GetHrisTimesheetsPositiveResponseData,
        GetHrisTimesheetsPositiveResponseDataTypedDict,
        GetHrisTimesheetsPositiveResponseResult,
        GetHrisTimesheetsPositiveResponseResultTypedDict,
        GetHrisTimesheetsPositiveResponseTypedDict,
    )
    from .getintegrationsintegrationidcustomfieldsop import (
        GetIntegrationsIntegrationIDCustomFieldsRequest,
        GetIntegrationsIntegrationIDCustomFieldsRequestTypedDict,
        GetIntegrationsIntegrationIDCustomFieldsResponse,
        GetIntegrationsIntegrationIDCustomFieldsResponseTypedDict,
    )
    from .getintegrationsintegrationidcustomfieldspositiveresponse import (
        GetIntegrationsIntegrationIDCustomFieldsPositiveResponse,
        GetIntegrationsIntegrationIDCustomFieldsPositiveResponseData,
        GetIntegrationsIntegrationIDCustomFieldsPositiveResponseDataTypedDict,
        GetIntegrationsIntegrationIDCustomFieldsPositiveResponseIntegrationField,
        GetIntegrationsIntegrationIDCustomFieldsPositiveResponseIntegrationFieldTypedDict,
        GetIntegrationsIntegrationIDCustomFieldsPositiveResponseResult,
        GetIntegrationsIntegrationIDCustomFieldsPositiveResponseResultTypedDict,
        GetIntegrationsIntegrationIDCustomFieldsPositiveResponseType,
        GetIntegrationsIntegrationIDCustomFieldsPositiveResponseTypedDict,
    )
    from .getintegrationsintegrationidintegrationfieldsop import (
        GetIntegrationsIntegrationIDIntegrationFieldsRequest,
        GetIntegrationsIntegrationIDIntegrationFieldsRequestTypedDict,
        GetIntegrationsIntegrationIDIntegrationFieldsResponse,
        GetIntegrationsIntegrationIDIntegrationFieldsResponseTypedDict,
    )
    from .getintegrationsintegrationidintegrationfieldspositiveresponse import (
        GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponse,
        GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseData,
        GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseDataTypedDict,
        GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseResult,
        GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseResultTypedDict,
        GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseType,
        GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseTypedDict,
    )
    from .getintegrationsintegrationidop import (
        GetIntegrationsIntegrationIDRequest,
        GetIntegrationsIntegrationIDRequestTypedDict,
    )
    from .getintegrationsintegrationidpositiveresponse import (
        FieldScopeConfigSetting,
        GetIntegrationsIntegrationIDPositiveResponse,
        GetIntegrationsIntegrationIDPositiveResponseCategory,
        GetIntegrationsIntegrationIDPositiveResponseCoverageStatus,
        GetIntegrationsIntegrationIDPositiveResponseData,
        GetIntegrationsIntegrationIDPositiveResponseDataTypedDict,
        GetIntegrationsIntegrationIDPositiveResponseEndUser,
        GetIntegrationsIntegrationIDPositiveResponseEndUserTypedDict,
        GetIntegrationsIntegrationIDPositiveResponseField,
        GetIntegrationsIntegrationIDPositiveResponseFieldCoverageStatus,
        GetIntegrationsIntegrationIDPositiveResponseFieldTypedDict,
        GetIntegrationsIntegrationIDPositiveResponseReadModel,
        GetIntegrationsIntegrationIDPositiveResponseReadModelTypedDict,
        GetIntegrationsIntegrationIDPositiveResponseSetupStatus,
        GetIntegrationsIntegrationIDPositiveResponseStatus,
        GetIntegrationsIntegrationIDPositiveResponseTool,
        GetIntegrationsIntegrationIDPositiveResponseToolTypedDict,
        GetIntegrationsIntegrationIDPositiveResponseTypedDict,
        ScopeConfig,
        ScopeConfigSetting,
        ScopeConfigTypedDict,
    )
    from .gettoolscategoryop import (
        GetToolsCategoryRequest,
        GetToolsCategoryRequestTypedDict,
    )
    from .gettoolscategoryparametercategory import GetToolsCategoryParameterCategory
    from .gettoolscategorypositiveresponse import (
        Assets,
        AssetsTypedDict,
        Coverage,
        CoverageTypedDict,
        Feature,
        FeatureCoverageStatus,
        FeatureTypedDict,
        GetToolsCategoryPositiveResponse,
        GetToolsCategoryPositiveResponseData,
        GetToolsCategoryPositiveResponseDataTypedDict,
        GetToolsCategoryPositiveResponseField,
        GetToolsCategoryPositiveResponseFieldCoverageStatus,
        GetToolsCategoryPositiveResponseFieldTypedDict,
        GetToolsCategoryPositiveResponseReadModel,
        GetToolsCategoryPositiveResponseReadModelCoverageStatus,
        GetToolsCategoryPositiveResponseReadModelTypedDict,
        GetToolsCategoryPositiveResponseTool,
        GetToolsCategoryPositiveResponseToolTypedDict,
        GetToolsCategoryPositiveResponseTypedDict,
        WriteAction,
        WriteActionCoverageStatus,
        WriteActionTypedDict,
    )
    from .inlineassessmentorderreceivedwebhookpayload import (
        InlineAssessmentOrderReceivedWebhookPayload,
        InlineAssessmentOrderReceivedWebhookPayloadApplication,
        InlineAssessmentOrderReceivedWebhookPayloadApplicationTypedDict,
        InlineAssessmentOrderReceivedWebhookPayloadCandidate,
        InlineAssessmentOrderReceivedWebhookPayloadCandidateTypedDict,
        InlineAssessmentOrderReceivedWebhookPayloadData,
        InlineAssessmentOrderReceivedWebhookPayloadDataTypedDict,
        InlineAssessmentOrderReceivedWebhookPayloadHiringTeam,
        InlineAssessmentOrderReceivedWebhookPayloadHiringTeamRole,
        InlineAssessmentOrderReceivedWebhookPayloadHiringTeamTypedDict,
        InlineAssessmentOrderReceivedWebhookPayloadJob,
        InlineAssessmentOrderReceivedWebhookPayloadJobTypedDict,
        InlineAssessmentOrderReceivedWebhookPayloadLocation,
        InlineAssessmentOrderReceivedWebhookPayloadLocationTypedDict,
        InlineAssessmentOrderReceivedWebhookPayloadStatus,
        InlineAssessmentOrderReceivedWebhookPayloadType,
        InlineAssessmentOrderReceivedWebhookPayloadTypedDict,
    )
    from .integrationcreatedwebhookpayload import (
        IntegrationCreatedWebhookPayload,
        IntegrationCreatedWebhookPayloadCategory,
        IntegrationCreatedWebhookPayloadData,
        IntegrationCreatedWebhookPayloadDataTypedDict,
        IntegrationCreatedWebhookPayloadEndUser,
        IntegrationCreatedWebhookPayloadEndUserTypedDict,
        IntegrationCreatedWebhookPayloadType,
        IntegrationCreatedWebhookPayloadTypedDict,
    )
    from .integrationdeletedwebhookpayload import (
        IntegrationDeletedWebhookPayload,
        IntegrationDeletedWebhookPayloadCategory,
        IntegrationDeletedWebhookPayloadData,
        IntegrationDeletedWebhookPayloadDataTypedDict,
        IntegrationDeletedWebhookPayloadEndUser,
        IntegrationDeletedWebhookPayloadEndUserTypedDict,
        IntegrationDeletedWebhookPayloadType,
        IntegrationDeletedWebhookPayloadTypedDict,
    )
    from .integrationstatechangedwebhookpayload import (
        IntegrationStateChangedWebhookPayload,
        IntegrationStateChangedWebhookPayloadData,
        IntegrationStateChangedWebhookPayloadDataTypedDict,
        IntegrationStateChangedWebhookPayloadEndUser,
        IntegrationStateChangedWebhookPayloadEndUserTypedDict,
        IntegrationStateChangedWebhookPayloadIntegrationCategory,
        IntegrationStateChangedWebhookPayloadType,
        IntegrationStateChangedWebhookPayloadTypedDict,
        QaStatus,
        State,
    )
    from .komboatserror import (
        KomboAtsErrorCode,
        KomboAtsErrorError,
        KomboAtsErrorErrorTypedDict,
        KomboAtsErrorStatus,
    )
    from .kombogeneralerror import (
        KomboGeneralErrorCode,
        KomboGeneralErrorError,
        KomboGeneralErrorErrorTypedDict,
        KomboGeneralErrorStatus,
    )
    from .kombohriserror import (
        KomboHrisErrorCode,
        KomboHrisErrorError,
        KomboHrisErrorErrorTypedDict,
        KomboHrisErrorStatus,
    )
    from .patchintegrationsintegrationidintegrationfieldsintegrationfieldidop import (
        PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDRequest,
        PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDRequestTypedDict,
    )
    from .patchintegrationsintegrationidintegrationfieldsintegrationfieldidpositiveresponse import (
        PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDPositiveResponse,
        PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDPositiveResponseData,
        PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDPositiveResponseDataTypedDict,
        PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDPositiveResponseType,
        PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDPositiveResponseTypedDict,
    )
    from .patchintegrationsintegrationidintegrationfieldsintegrationfieldidrequestbody import (
        PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDRequestBody,
        PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDRequestBodyTypedDict,
    )
    from .postatsapplicationsapplicationidattachmentsop import (
        PostAtsApplicationsApplicationIDAttachmentsGlobals,
        PostAtsApplicationsApplicationIDAttachmentsGlobalsTypedDict,
        PostAtsApplicationsApplicationIDAttachmentsRequest,
        PostAtsApplicationsApplicationIDAttachmentsRequestTypedDict,
    )
    from .postatsapplicationsapplicationidattachmentspositiveresponse import (
        PostAtsApplicationsApplicationIDAttachmentsPositiveResponse,
        PostAtsApplicationsApplicationIDAttachmentsPositiveResponseData,
        PostAtsApplicationsApplicationIDAttachmentsPositiveResponseDataTypedDict,
        PostAtsApplicationsApplicationIDAttachmentsPositiveResponseTypedDict,
        PostAtsApplicationsApplicationIDAttachmentsPositiveResponseWarning,
        PostAtsApplicationsApplicationIDAttachmentsPositiveResponseWarningTypedDict,
    )
    from .postatsapplicationsapplicationidattachmentsrequestbody import (
        PostAtsApplicationsApplicationIDAttachmentsRequestBody,
        PostAtsApplicationsApplicationIDAttachmentsRequestBodyAttachment,
        PostAtsApplicationsApplicationIDAttachmentsRequestBodyAttachmentTypedDict,
        PostAtsApplicationsApplicationIDAttachmentsRequestBodyGreenhouse,
        PostAtsApplicationsApplicationIDAttachmentsRequestBodyGreenhouseTypedDict,
        PostAtsApplicationsApplicationIDAttachmentsRequestBodyOracle,
        PostAtsApplicationsApplicationIDAttachmentsRequestBodyOracleTypedDict,
        PostAtsApplicationsApplicationIDAttachmentsRequestBodyOverrideDocumentCategory,
        PostAtsApplicationsApplicationIDAttachmentsRequestBodyPostHeaders,
        PostAtsApplicationsApplicationIDAttachmentsRequestBodyPostHeadersTypedDict,
        PostAtsApplicationsApplicationIDAttachmentsRequestBodyRemoteFields,
        PostAtsApplicationsApplicationIDAttachmentsRequestBodyRemoteFieldsTypedDict,
        PostAtsApplicationsApplicationIDAttachmentsRequestBodyType,
        PostAtsApplicationsApplicationIDAttachmentsRequestBodyTypedDict,
        PostAtsApplicationsApplicationIDAttachmentsRequestBodyWorkable,
        PostAtsApplicationsApplicationIDAttachmentsRequestBodyWorkableTypedDict,
    )
    from .postatsapplicationsapplicationidnotesop import (
        PostAtsApplicationsApplicationIDNotesGlobals,
        PostAtsApplicationsApplicationIDNotesGlobalsTypedDict,
        PostAtsApplicationsApplicationIDNotesRequest,
        PostAtsApplicationsApplicationIDNotesRequestTypedDict,
    )
    from .postatsapplicationsapplicationidnotespositiveresponse import (
        PostAtsApplicationsApplicationIDNotesPositiveResponse,
        PostAtsApplicationsApplicationIDNotesPositiveResponseData,
        PostAtsApplicationsApplicationIDNotesPositiveResponseDataTypedDict,
        PostAtsApplicationsApplicationIDNotesPositiveResponseTypedDict,
        PostAtsApplicationsApplicationIDNotesPositiveResponseWarning,
        PostAtsApplicationsApplicationIDNotesPositiveResponseWarningTypedDict,
    )
    from .postatsapplicationsapplicationidnotesrequestbody import (
        ContentType,
        PostAtsApplicationsApplicationIDNotesRequestBody,
        PostAtsApplicationsApplicationIDNotesRequestBodyBullhorn,
        PostAtsApplicationsApplicationIDNotesRequestBodyBullhornTypedDict,
        PostAtsApplicationsApplicationIDNotesRequestBodyGreenhouse,
        PostAtsApplicationsApplicationIDNotesRequestBodyGreenhouseTypedDict,
        PostAtsApplicationsApplicationIDNotesRequestBodyPostHeaders,
        PostAtsApplicationsApplicationIDNotesRequestBodyPostHeadersTypedDict,
        PostAtsApplicationsApplicationIDNotesRequestBodyRecruitee,
        PostAtsApplicationsApplicationIDNotesRequestBodyRecruiteeTypedDict,
        PostAtsApplicationsApplicationIDNotesRequestBodyRemoteFields,
        PostAtsApplicationsApplicationIDNotesRequestBodyRemoteFieldsTypedDict,
        PostAtsApplicationsApplicationIDNotesRequestBodyTeamtailor,
        PostAtsApplicationsApplicationIDNotesRequestBodyTeamtailorTypedDict,
        PostAtsApplicationsApplicationIDNotesRequestBodyTypedDict,
        PostAtsApplicationsApplicationIDNotesRequestBodyWorkable,
        PostAtsApplicationsApplicationIDNotesRequestBodyWorkableTypedDict,
    )
    from .postatsapplicationsapplicationidrejectop import (
        PostAtsApplicationsApplicationIDRejectGlobals,
        PostAtsApplicationsApplicationIDRejectGlobalsTypedDict,
        PostAtsApplicationsApplicationIDRejectRequest,
        PostAtsApplicationsApplicationIDRejectRequestTypedDict,
    )
    from .postatsapplicationsapplicationidrejectpositiveresponse import (
        PostAtsApplicationsApplicationIDRejectPositiveResponse,
        PostAtsApplicationsApplicationIDRejectPositiveResponseData,
        PostAtsApplicationsApplicationIDRejectPositiveResponseDataTypedDict,
        PostAtsApplicationsApplicationIDRejectPositiveResponseTypedDict,
        PostAtsApplicationsApplicationIDRejectPositiveResponseWarning,
        PostAtsApplicationsApplicationIDRejectPositiveResponseWarningTypedDict,
    )
    from .postatsapplicationsapplicationidrejectrequestbody import (
        PostAtsApplicationsApplicationIDRejectRequestBody,
        PostAtsApplicationsApplicationIDRejectRequestBodyGreenhouse,
        PostAtsApplicationsApplicationIDRejectRequestBodyGreenhouseTypedDict,
        PostAtsApplicationsApplicationIDRejectRequestBodyPostHeaders,
        PostAtsApplicationsApplicationIDRejectRequestBodyPostHeadersTypedDict,
        PostAtsApplicationsApplicationIDRejectRequestBodyRemoteFields,
        PostAtsApplicationsApplicationIDRejectRequestBodyRemoteFieldsTypedDict,
        PostAtsApplicationsApplicationIDRejectRequestBodyTypedDict,
        PostAtsApplicationsApplicationIDRejectRequestBodyWorkable,
        PostAtsApplicationsApplicationIDRejectRequestBodyWorkableTypedDict,
    )
    from .postatsapplicationsapplicationidresultlinksop import (
        PostAtsApplicationsApplicationIDResultLinksGlobals,
        PostAtsApplicationsApplicationIDResultLinksGlobalsTypedDict,
        PostAtsApplicationsApplicationIDResultLinksRequest,
        PostAtsApplicationsApplicationIDResultLinksRequestTypedDict,
    )
    from .postatsapplicationsapplicationidresultlinkspositiveresponse import (
        PostAtsApplicationsApplicationIDResultLinksPositiveResponse,
        PostAtsApplicationsApplicationIDResultLinksPositiveResponseData,
        PostAtsApplicationsApplicationIDResultLinksPositiveResponseDataTypedDict,
        PostAtsApplicationsApplicationIDResultLinksPositiveResponseTypedDict,
        PostAtsApplicationsApplicationIDResultLinksPositiveResponseWarning,
        PostAtsApplicationsApplicationIDResultLinksPositiveResponseWarningTypedDict,
    )
    from .postatsapplicationsapplicationidresultlinksrequestbody import (
        PostAtsApplicationsApplicationIDResultLinksRequestBody,
        PostAtsApplicationsApplicationIDResultLinksRequestBodyAttribute,
        PostAtsApplicationsApplicationIDResultLinksRequestBodyAttributeTypedDict,
        PostAtsApplicationsApplicationIDResultLinksRequestBodyDetails,
        PostAtsApplicationsApplicationIDResultLinksRequestBodyDetailsTypedDict,
        PostAtsApplicationsApplicationIDResultLinksRequestBodyGreenhouse,
        PostAtsApplicationsApplicationIDResultLinksRequestBodyGreenhouseTypedDict,
        PostAtsApplicationsApplicationIDResultLinksRequestBodyIcims,
        PostAtsApplicationsApplicationIDResultLinksRequestBodyIcimsTypedDict,
        PostAtsApplicationsApplicationIDResultLinksRequestBodyOracle,
        PostAtsApplicationsApplicationIDResultLinksRequestBodyOracleTypedDict,
        PostAtsApplicationsApplicationIDResultLinksRequestBodyOverrideDocumentCategory,
        PostAtsApplicationsApplicationIDResultLinksRequestBodyPostHeaders,
        PostAtsApplicationsApplicationIDResultLinksRequestBodyPostHeadersTypedDict,
        PostAtsApplicationsApplicationIDResultLinksRequestBodyRemoteFields,
        PostAtsApplicationsApplicationIDResultLinksRequestBodyRemoteFieldsTypedDict,
        PostAtsApplicationsApplicationIDResultLinksRequestBodyTypedDict,
        PostAtsApplicationsApplicationIDResultLinksRequestBodyWorkable,
        PostAtsApplicationsApplicationIDResultLinksRequestBodyWorkableTypedDict,
    )
    from .postatscandidatescandidateidattachmentsop import (
        PostAtsCandidatesCandidateIDAttachmentsGlobals,
        PostAtsCandidatesCandidateIDAttachmentsGlobalsTypedDict,
        PostAtsCandidatesCandidateIDAttachmentsRequest,
        PostAtsCandidatesCandidateIDAttachmentsRequestTypedDict,
    )
    from .postatscandidatescandidateidattachmentspositiveresponse import (
        PostAtsCandidatesCandidateIDAttachmentsPositiveResponse,
        PostAtsCandidatesCandidateIDAttachmentsPositiveResponseData,
        PostAtsCandidatesCandidateIDAttachmentsPositiveResponseDataTypedDict,
        PostAtsCandidatesCandidateIDAttachmentsPositiveResponseTypedDict,
        PostAtsCandidatesCandidateIDAttachmentsPositiveResponseWarning,
        PostAtsCandidatesCandidateIDAttachmentsPositiveResponseWarningTypedDict,
    )
    from .postatscandidatescandidateidattachmentsrequestbody import (
        PostAtsCandidatesCandidateIDAttachmentsRequestBody,
        PostAtsCandidatesCandidateIDAttachmentsRequestBodyAttachment,
        PostAtsCandidatesCandidateIDAttachmentsRequestBodyAttachmentTypedDict,
        PostAtsCandidatesCandidateIDAttachmentsRequestBodyGreenhouse,
        PostAtsCandidatesCandidateIDAttachmentsRequestBodyGreenhouseTypedDict,
        PostAtsCandidatesCandidateIDAttachmentsRequestBodyPostHeaders,
        PostAtsCandidatesCandidateIDAttachmentsRequestBodyPostHeadersTypedDict,
        PostAtsCandidatesCandidateIDAttachmentsRequestBodyRemoteFields,
        PostAtsCandidatesCandidateIDAttachmentsRequestBodyRemoteFieldsTypedDict,
        PostAtsCandidatesCandidateIDAttachmentsRequestBodyType,
        PostAtsCandidatesCandidateIDAttachmentsRequestBodyTypedDict,
        PostAtsCandidatesCandidateIDAttachmentsRequestBodyWorkable,
        PostAtsCandidatesCandidateIDAttachmentsRequestBodyWorkableTypedDict,
    )
    from .postatscandidatescandidateidresultlinksop import (
        PostAtsCandidatesCandidateIDResultLinksGlobals,
        PostAtsCandidatesCandidateIDResultLinksGlobalsTypedDict,
        PostAtsCandidatesCandidateIDResultLinksRequest,
        PostAtsCandidatesCandidateIDResultLinksRequestTypedDict,
    )
    from .postatscandidatescandidateidresultlinkspositiveresponse import (
        PostAtsCandidatesCandidateIDResultLinksPositiveResponse,
        PostAtsCandidatesCandidateIDResultLinksPositiveResponseData,
        PostAtsCandidatesCandidateIDResultLinksPositiveResponseDataTypedDict,
        PostAtsCandidatesCandidateIDResultLinksPositiveResponseTypedDict,
        PostAtsCandidatesCandidateIDResultLinksPositiveResponseWarning,
        PostAtsCandidatesCandidateIDResultLinksPositiveResponseWarningTypedDict,
    )
    from .postatscandidatescandidateidresultlinksrequestbody import (
        PostAtsCandidatesCandidateIDResultLinksRequestBody,
        PostAtsCandidatesCandidateIDResultLinksRequestBodyAttribute,
        PostAtsCandidatesCandidateIDResultLinksRequestBodyAttributeTypedDict,
        PostAtsCandidatesCandidateIDResultLinksRequestBodyDetails,
        PostAtsCandidatesCandidateIDResultLinksRequestBodyDetailsTypedDict,
        PostAtsCandidatesCandidateIDResultLinksRequestBodyGreenhouse,
        PostAtsCandidatesCandidateIDResultLinksRequestBodyGreenhouseTypedDict,
        PostAtsCandidatesCandidateIDResultLinksRequestBodyIcims,
        PostAtsCandidatesCandidateIDResultLinksRequestBodyIcimsTypedDict,
        PostAtsCandidatesCandidateIDResultLinksRequestBodyOracle,
        PostAtsCandidatesCandidateIDResultLinksRequestBodyOracleTypedDict,
        PostAtsCandidatesCandidateIDResultLinksRequestBodyOverrideDocumentCategory,
        PostAtsCandidatesCandidateIDResultLinksRequestBodyPostHeaders,
        PostAtsCandidatesCandidateIDResultLinksRequestBodyPostHeadersTypedDict,
        PostAtsCandidatesCandidateIDResultLinksRequestBodyRemoteFields,
        PostAtsCandidatesCandidateIDResultLinksRequestBodyRemoteFieldsTypedDict,
        PostAtsCandidatesCandidateIDResultLinksRequestBodyTypedDict,
        PostAtsCandidatesCandidateIDResultLinksRequestBodyWorkable,
        PostAtsCandidatesCandidateIDResultLinksRequestBodyWorkableTypedDict,
    )
    from .postatscandidatescandidateidtagsop import (
        PostAtsCandidatesCandidateIDTagsGlobals,
        PostAtsCandidatesCandidateIDTagsGlobalsTypedDict,
        PostAtsCandidatesCandidateIDTagsRequest,
        PostAtsCandidatesCandidateIDTagsRequestTypedDict,
    )
    from .postatscandidatescandidateidtagspositiveresponse import (
        PostAtsCandidatesCandidateIDTagsPositiveResponse,
        PostAtsCandidatesCandidateIDTagsPositiveResponseData,
        PostAtsCandidatesCandidateIDTagsPositiveResponseDataTypedDict,
        PostAtsCandidatesCandidateIDTagsPositiveResponseTypedDict,
        PostAtsCandidatesCandidateIDTagsPositiveResponseWarning,
        PostAtsCandidatesCandidateIDTagsPositiveResponseWarningTypedDict,
    )
    from .postatscandidatescandidateidtagsrequestbody import (
        PostAtsCandidatesCandidateIDTagsRequestBody,
        PostAtsCandidatesCandidateIDTagsRequestBodyGreenhouse,
        PostAtsCandidatesCandidateIDTagsRequestBodyGreenhouseTypedDict,
        PostAtsCandidatesCandidateIDTagsRequestBodyPostHeaders,
        PostAtsCandidatesCandidateIDTagsRequestBodyPostHeadersTypedDict,
        PostAtsCandidatesCandidateIDTagsRequestBodyRemoteFields,
        PostAtsCandidatesCandidateIDTagsRequestBodyRemoteFieldsTypedDict,
        PostAtsCandidatesCandidateIDTagsRequestBodyTag,
        PostAtsCandidatesCandidateIDTagsRequestBodyTagTypedDict,
        PostAtsCandidatesCandidateIDTagsRequestBodyTypedDict,
        PostAtsCandidatesCandidateIDTagsRequestBodyWorkable,
        PostAtsCandidatesCandidateIDTagsRequestBodyWorkableTypedDict,
    )
    from .postatscandidatesop import (
        PostAtsCandidatesGlobals,
        PostAtsCandidatesGlobalsTypedDict,
    )
    from .postatscandidatespositiveresponse import (
        PostAtsCandidatesPositiveResponse,
        PostAtsCandidatesPositiveResponseApplication,
        PostAtsCandidatesPositiveResponseApplicationTypedDict,
        PostAtsCandidatesPositiveResponseCurrentStage,
        PostAtsCandidatesPositiveResponseCurrentStageTypedDict,
        PostAtsCandidatesPositiveResponseData,
        PostAtsCandidatesPositiveResponseDataTypedDict,
        PostAtsCandidatesPositiveResponseEmailAddress,
        PostAtsCandidatesPositiveResponseEmailAddressTypedDict,
        PostAtsCandidatesPositiveResponseJob,
        PostAtsCandidatesPositiveResponseJobTypedDict,
        PostAtsCandidatesPositiveResponseLocation,
        PostAtsCandidatesPositiveResponseLocationTypedDict,
        PostAtsCandidatesPositiveResponseOutcome,
        PostAtsCandidatesPositiveResponsePhoneNumber,
        PostAtsCandidatesPositiveResponsePhoneNumberTypedDict,
        PostAtsCandidatesPositiveResponseSocialMedia,
        PostAtsCandidatesPositiveResponseSocialMediaTypedDict,
        PostAtsCandidatesPositiveResponseTag,
        PostAtsCandidatesPositiveResponseTagTypedDict,
        PostAtsCandidatesPositiveResponseTypedDict,
        PostAtsCandidatesPositiveResponseWarning,
        PostAtsCandidatesPositiveResponseWarningTypedDict,
    )
    from .postatscandidatesrequestbody import (
        PostAtsCandidatesRequestBody,
        PostAtsCandidatesRequestBodyAdditionalEmailAddress,
        PostAtsCandidatesRequestBodyAdditionalEmailAddressType,
        PostAtsCandidatesRequestBodyAdditionalEmailAddressTypedDict,
        PostAtsCandidatesRequestBodyAdditionalPhoneNumber,
        PostAtsCandidatesRequestBodyAdditionalPhoneNumberType,
        PostAtsCandidatesRequestBodyAdditionalPhoneNumberTypedDict,
        PostAtsCandidatesRequestBodyAnswer,
        PostAtsCandidatesRequestBodyAnswerTypedDict,
        PostAtsCandidatesRequestBodyAnswerUnion,
        PostAtsCandidatesRequestBodyAnswerUnionTypedDict,
        PostAtsCandidatesRequestBodyApplication,
        PostAtsCandidatesRequestBodyApplicationTypedDict,
        PostAtsCandidatesRequestBodyAttachment,
        PostAtsCandidatesRequestBodyAttachmentType,
        PostAtsCandidatesRequestBodyAttachmentTypedDict,
        PostAtsCandidatesRequestBodyAvature,
        PostAtsCandidatesRequestBodyAvatureTypedDict,
        PostAtsCandidatesRequestBodyBullhorn,
        PostAtsCandidatesRequestBodyBullhornTypedDict,
        PostAtsCandidatesRequestBodyCandidate,
        PostAtsCandidatesRequestBodyCandidateData,
        PostAtsCandidatesRequestBodyCandidateDataTypedDict,
        PostAtsCandidatesRequestBodyCandidateTypedDict,
        PostAtsCandidatesRequestBodyContactData,
        PostAtsCandidatesRequestBodyContactDataTypedDict,
        PostAtsCandidatesRequestBodyCountryCityReference,
        PostAtsCandidatesRequestBodyCountryCityReferenceTypedDict,
        PostAtsCandidatesRequestBodyCountryRegionReference,
        PostAtsCandidatesRequestBodyCountryRegionReferenceTypedDict,
        PostAtsCandidatesRequestBodyDegreeReference,
        PostAtsCandidatesRequestBodyDegreeReferenceTypedDict,
        PostAtsCandidatesRequestBodyDvinci,
        PostAtsCandidatesRequestBodyDvinciTypedDict,
        PostAtsCandidatesRequestBodyEducationDatum,
        PostAtsCandidatesRequestBodyEducationDatumTypedDict,
        PostAtsCandidatesRequestBodyExperienceDatum,
        PostAtsCandidatesRequestBodyExperienceDatumTypedDict,
        PostAtsCandidatesRequestBodyFieldOfStudyReference,
        PostAtsCandidatesRequestBodyFieldOfStudyReferenceTypedDict,
        PostAtsCandidatesRequestBodyGdprConsent,
        PostAtsCandidatesRequestBodyGdprConsentTypedDict,
        PostAtsCandidatesRequestBodyGender,
        PostAtsCandidatesRequestBodyGlobalPersonalInformationData,
        PostAtsCandidatesRequestBodyGlobalPersonalInformationDataTypedDict,
        PostAtsCandidatesRequestBodyGreenhouse,
        PostAtsCandidatesRequestBodyGreenhouseTypedDict,
        PostAtsCandidatesRequestBodyGuidecom,
        PostAtsCandidatesRequestBodyGuidecomTypedDict,
        PostAtsCandidatesRequestBodyHrworks,
        PostAtsCandidatesRequestBodyHrworksTypedDict,
        PostAtsCandidatesRequestBodyJobApplicationData,
        PostAtsCandidatesRequestBodyJobApplicationDataTypedDict,
        PostAtsCandidatesRequestBodyJobAppliedToData,
        PostAtsCandidatesRequestBodyJobAppliedToDataTypedDict,
        PostAtsCandidatesRequestBodyJobylon,
        PostAtsCandidatesRequestBodyJobylonApplication,
        PostAtsCandidatesRequestBodyJobylonApplicationTypedDict,
        PostAtsCandidatesRequestBodyJobylonTypedDict,
        PostAtsCandidatesRequestBodyLanguage,
        PostAtsCandidatesRequestBodyLanguageAbility,
        PostAtsCandidatesRequestBodyLanguageAbilityData,
        PostAtsCandidatesRequestBodyLanguageAbilityDataTypedDict,
        PostAtsCandidatesRequestBodyLanguageAbilityTypeReference,
        PostAtsCandidatesRequestBodyLanguageAbilityTypeReferenceTypedDict,
        PostAtsCandidatesRequestBodyLanguageAbilityTypedDict,
        PostAtsCandidatesRequestBodyLanguageDatum,
        PostAtsCandidatesRequestBodyLanguageDatumLanguageReference,
        PostAtsCandidatesRequestBodyLanguageDatumLanguageReferenceTypedDict,
        PostAtsCandidatesRequestBodyLanguageDatumTypedDict,
        PostAtsCandidatesRequestBodyLanguageProficiencyReference,
        PostAtsCandidatesRequestBodyLanguageProficiencyReferenceTypedDict,
        PostAtsCandidatesRequestBodyLanguageReference,
        PostAtsCandidatesRequestBodyLanguageReferenceTypedDict,
        PostAtsCandidatesRequestBodyLanguageTypedDict,
        PostAtsCandidatesRequestBodyLever,
        PostAtsCandidatesRequestBodyLeverTypedDict,
        PostAtsCandidatesRequestBodyLocation,
        PostAtsCandidatesRequestBodyLocationData,
        PostAtsCandidatesRequestBodyLocationDataTypedDict,
        PostAtsCandidatesRequestBodyLocationTypedDict,
        PostAtsCandidatesRequestBodyNameDetailData,
        PostAtsCandidatesRequestBodyNameDetailDataTypedDict,
        PostAtsCandidatesRequestBodyPeriod,
        PostAtsCandidatesRequestBodyPersonio,
        PostAtsCandidatesRequestBodyPersonioTypedDict,
        PostAtsCandidatesRequestBodyPiloga,
        PostAtsCandidatesRequestBodyPilogaCandidate,
        PostAtsCandidatesRequestBodyPilogaCandidateTypedDict,
        PostAtsCandidatesRequestBodyPilogaTypedDict,
        PostAtsCandidatesRequestBodyPostHeaders,
        PostAtsCandidatesRequestBodyPostHeadersTypedDict,
        PostAtsCandidatesRequestBodyRecruitee,
        PostAtsCandidatesRequestBodyRecruiteeCandidate,
        PostAtsCandidatesRequestBodyRecruiteeCandidateTypedDict,
        PostAtsCandidatesRequestBodyRecruiteeTypedDict,
        PostAtsCandidatesRequestBodyRemoteFields,
        PostAtsCandidatesRequestBodyRemoteFieldsTypedDict,
        PostAtsCandidatesRequestBodyResumeData,
        PostAtsCandidatesRequestBodyResumeDataTypedDict,
        PostAtsCandidatesRequestBodySalaryExpectations,
        PostAtsCandidatesRequestBodySalaryExpectationsTypedDict,
        PostAtsCandidatesRequestBodyScreeningQuestionAnswer,
        PostAtsCandidatesRequestBodyScreeningQuestionAnswerTypedDict,
        PostAtsCandidatesRequestBodySkillDatum,
        PostAtsCandidatesRequestBodySkillDatumTypedDict,
        PostAtsCandidatesRequestBodySmartrecruiters,
        PostAtsCandidatesRequestBodySmartrecruitersTypedDict,
        PostAtsCandidatesRequestBodySocialLink,
        PostAtsCandidatesRequestBodySocialLinkTypedDict,
        PostAtsCandidatesRequestBodySocialSuffixReference,
        PostAtsCandidatesRequestBodySocialSuffixReferenceTypedDict,
        PostAtsCandidatesRequestBodySource,
        PostAtsCandidatesRequestBodySourceTypedDict,
        PostAtsCandidatesRequestBodySourcedBy,
        PostAtsCandidatesRequestBodySourcedByTypedDict,
        PostAtsCandidatesRequestBodyStep,
        PostAtsCandidatesRequestBodyStepTypedDict,
        PostAtsCandidatesRequestBodySuccessfactors,
        PostAtsCandidatesRequestBodySuccessfactorsTypedDict,
        PostAtsCandidatesRequestBodyTalentadore,
        PostAtsCandidatesRequestBodyTalentadoreTypedDict,
        PostAtsCandidatesRequestBodyTalentsoft,
        PostAtsCandidatesRequestBodyTalentsoftTypedDict,
        PostAtsCandidatesRequestBodyTeamtailor,
        PostAtsCandidatesRequestBodyTeamtailorApplication,
        PostAtsCandidatesRequestBodyTeamtailorApplicationTypedDict,
        PostAtsCandidatesRequestBodyTeamtailorTypedDict,
        PostAtsCandidatesRequestBodyTypedDict,
        PostAtsCandidatesRequestBodyUmantis,
        PostAtsCandidatesRequestBodyUmantisTypedDict,
        PostAtsCandidatesRequestBodyWorkable,
        PostAtsCandidatesRequestBodyWorkableTypedDict,
        PostAtsCandidatesRequestBodyWorkday,
        PostAtsCandidatesRequestBodyWorkdayTypedDict,
        PostAtsCandidatesRequestBodyWorkerReference,
        PostAtsCandidatesRequestBodyWorkerReferenceTypedDict,
        PostAtsCandidatesRequestBodyWorkflow,
        PostAtsCandidatesRequestBodyWorkflowTypedDict,
        PostAtsCandidatesRequestBodyZohorecruit,
        PostAtsCandidatesRequestBodyZohorecruitTypedDict,
    )
    from .postatsimporttrackedapplicationop import (
        PostAtsImportTrackedApplicationGlobals,
        PostAtsImportTrackedApplicationGlobalsTypedDict,
    )
    from .postatsimporttrackedapplicationpositiveresponse import (
        ImportedID,
        ImportedIDTypedDict,
        PostAtsImportTrackedApplicationPositiveResponse,
        PostAtsImportTrackedApplicationPositiveResponseData,
        PostAtsImportTrackedApplicationPositiveResponseDataTypedDict,
        PostAtsImportTrackedApplicationPositiveResponseErecruiterApplicationAndCandidateRemoteIds,
        PostAtsImportTrackedApplicationPositiveResponseErecruiterApplicationAndCandidateRemoteIdsTypedDict,
        PostAtsImportTrackedApplicationPositiveResponseErecruiterApplicationAndJobRemoteIds,
        PostAtsImportTrackedApplicationPositiveResponseErecruiterApplicationAndJobRemoteIdsTypedDict,
        PostAtsImportTrackedApplicationPositiveResponseErecruiterUnion,
        PostAtsImportTrackedApplicationPositiveResponseErecruiterUnionTypedDict,
        PostAtsImportTrackedApplicationPositiveResponseGreenhouseApplicationID,
        PostAtsImportTrackedApplicationPositiveResponseGreenhouseApplicationIDTypedDict,
        PostAtsImportTrackedApplicationPositiveResponseGreenhouseUnion,
        PostAtsImportTrackedApplicationPositiveResponseGreenhouseUnionTypedDict,
        PostAtsImportTrackedApplicationPositiveResponseOnlyfyApplicationID,
        PostAtsImportTrackedApplicationPositiveResponseOnlyfyApplicationIDTypedDict,
        PostAtsImportTrackedApplicationPositiveResponseOnlyfyUnion,
        PostAtsImportTrackedApplicationPositiveResponseOnlyfyUnionTypedDict,
        PostAtsImportTrackedApplicationPositiveResponseRecruiteePlacementID,
        PostAtsImportTrackedApplicationPositiveResponseRecruiteePlacementIDTypedDict,
        PostAtsImportTrackedApplicationPositiveResponseRecruiteeUnion,
        PostAtsImportTrackedApplicationPositiveResponseRecruiteeUnionTypedDict,
        PostAtsImportTrackedApplicationPositiveResponseSmartrecruitersCandidateAndJobRemoteIds,
        PostAtsImportTrackedApplicationPositiveResponseSmartrecruitersCandidateAndJobRemoteIdsTypedDict,
        PostAtsImportTrackedApplicationPositiveResponseSmartrecruitersUnion,
        PostAtsImportTrackedApplicationPositiveResponseSmartrecruitersUnionTypedDict,
        PostAtsImportTrackedApplicationPositiveResponseSuccessfactorsApplicationRemoteID,
        PostAtsImportTrackedApplicationPositiveResponseSuccessfactorsApplicationRemoteIDTypedDict,
        PostAtsImportTrackedApplicationPositiveResponseSuccessfactorsUnion,
        PostAtsImportTrackedApplicationPositiveResponseSuccessfactorsUnionTypedDict,
        PostAtsImportTrackedApplicationPositiveResponseTypedDict,
        PostAtsImportTrackedApplicationPositiveResponseWarning,
        PostAtsImportTrackedApplicationPositiveResponseWarningTypedDict,
    )
    from .postatsimporttrackedapplicationrequestbody import (
        PostAtsImportTrackedApplicationRequestBody,
        PostAtsImportTrackedApplicationRequestBodyErecruiterApplicationAndCandidateRemoteIds,
        PostAtsImportTrackedApplicationRequestBodyErecruiterApplicationAndCandidateRemoteIdsTypedDict,
        PostAtsImportTrackedApplicationRequestBodyErecruiterApplicationAndJobRemoteIds,
        PostAtsImportTrackedApplicationRequestBodyErecruiterApplicationAndJobRemoteIdsTypedDict,
        PostAtsImportTrackedApplicationRequestBodyErecruiterUnion,
        PostAtsImportTrackedApplicationRequestBodyErecruiterUnionTypedDict,
        PostAtsImportTrackedApplicationRequestBodyGreenhouseApplicationID,
        PostAtsImportTrackedApplicationRequestBodyGreenhouseApplicationIDTypedDict,
        PostAtsImportTrackedApplicationRequestBodyGreenhouseUnion,
        PostAtsImportTrackedApplicationRequestBodyGreenhouseUnionTypedDict,
        PostAtsImportTrackedApplicationRequestBodyOnlyfyApplicationID,
        PostAtsImportTrackedApplicationRequestBodyOnlyfyApplicationIDTypedDict,
        PostAtsImportTrackedApplicationRequestBodyOnlyfyUnion,
        PostAtsImportTrackedApplicationRequestBodyOnlyfyUnionTypedDict,
        PostAtsImportTrackedApplicationRequestBodyRecruiteePlacementID,
        PostAtsImportTrackedApplicationRequestBodyRecruiteePlacementIDTypedDict,
        PostAtsImportTrackedApplicationRequestBodyRecruiteeUnion,
        PostAtsImportTrackedApplicationRequestBodyRecruiteeUnionTypedDict,
        PostAtsImportTrackedApplicationRequestBodySmartrecruitersCandidateAndJobRemoteIds,
        PostAtsImportTrackedApplicationRequestBodySmartrecruitersCandidateAndJobRemoteIdsTypedDict,
        PostAtsImportTrackedApplicationRequestBodySmartrecruitersUnion,
        PostAtsImportTrackedApplicationRequestBodySmartrecruitersUnionTypedDict,
        PostAtsImportTrackedApplicationRequestBodySuccessfactorsApplicationRemoteID,
        PostAtsImportTrackedApplicationRequestBodySuccessfactorsApplicationRemoteIDTypedDict,
        PostAtsImportTrackedApplicationRequestBodySuccessfactorsUnion,
        PostAtsImportTrackedApplicationRequestBodySuccessfactorsUnionTypedDict,
        PostAtsImportTrackedApplicationRequestBodyTypedDict,
    )
    from .postatsjobsjobidapplicationsop import (
        PostAtsJobsJobIDApplicationsGlobals,
        PostAtsJobsJobIDApplicationsGlobalsTypedDict,
        PostAtsJobsJobIDApplicationsRequest,
        PostAtsJobsJobIDApplicationsRequestTypedDict,
    )
    from .postatsjobsjobidapplicationspositiveresponse import (
        PostAtsJobsJobIDApplicationsPositiveResponse,
        PostAtsJobsJobIDApplicationsPositiveResponseAnswer1,
        PostAtsJobsJobIDApplicationsPositiveResponseAnswer1TypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseAnswer2,
        PostAtsJobsJobIDApplicationsPositiveResponseAnswer2TypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseAnswer3,
        PostAtsJobsJobIDApplicationsPositiveResponseAnswer3TypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseAnswer4,
        PostAtsJobsJobIDApplicationsPositiveResponseAnswer4TypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseAnswer5,
        PostAtsJobsJobIDApplicationsPositiveResponseAnswer5TypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseAnswer6,
        PostAtsJobsJobIDApplicationsPositiveResponseAnswer6TypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseAnswer7,
        PostAtsJobsJobIDApplicationsPositiveResponseAnswer7TypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseCandidate,
        PostAtsJobsJobIDApplicationsPositiveResponseCandidateTypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseCurrentStage,
        PostAtsJobsJobIDApplicationsPositiveResponseCurrentStageTypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseData,
        PostAtsJobsJobIDApplicationsPositiveResponseDataTypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseEmailAddress,
        PostAtsJobsJobIDApplicationsPositiveResponseEmailAddressTypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseJob,
        PostAtsJobsJobIDApplicationsPositiveResponseJobTypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseLocation,
        PostAtsJobsJobIDApplicationsPositiveResponseLocationTypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseOutcome,
        PostAtsJobsJobIDApplicationsPositiveResponsePhoneNumber,
        PostAtsJobsJobIDApplicationsPositiveResponsePhoneNumberTypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseQuestionBoolean,
        PostAtsJobsJobIDApplicationsPositiveResponseQuestionBooleanTypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseQuestionDate,
        PostAtsJobsJobIDApplicationsPositiveResponseQuestionDateTypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseQuestionMultiSelect,
        PostAtsJobsJobIDApplicationsPositiveResponseQuestionMultiSelectTypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseQuestionNumber,
        PostAtsJobsJobIDApplicationsPositiveResponseQuestionNumberTypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseQuestionSingleSelect,
        PostAtsJobsJobIDApplicationsPositiveResponseQuestionSingleSelectTypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseQuestionText,
        PostAtsJobsJobIDApplicationsPositiveResponseQuestionTextTypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseQuestionUnknown,
        PostAtsJobsJobIDApplicationsPositiveResponseQuestionUnknownTypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer1,
        PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer1TypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer2,
        PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer2TypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer3,
        PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer3TypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer4,
        PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer4TypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer5,
        PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer5TypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer6,
        PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer6TypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer7,
        PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer7TypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswerUnion,
        PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswerUnionTypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseSocialMedia,
        PostAtsJobsJobIDApplicationsPositiveResponseSocialMediaTypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseTag,
        PostAtsJobsJobIDApplicationsPositiveResponseTagTypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseTypedDict,
        PostAtsJobsJobIDApplicationsPositiveResponseWarning,
        PostAtsJobsJobIDApplicationsPositiveResponseWarningTypedDict,
    )
    from .postatsjobsjobidapplicationsrequestbody import (
        PostAtsJobsJobIDApplicationsRequestBody,
        PostAtsJobsJobIDApplicationsRequestBodyAdditionalEmailAddress,
        PostAtsJobsJobIDApplicationsRequestBodyAdditionalEmailAddressType,
        PostAtsJobsJobIDApplicationsRequestBodyAdditionalEmailAddressTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyAdditionalPhoneNumber,
        PostAtsJobsJobIDApplicationsRequestBodyAdditionalPhoneNumberType,
        PostAtsJobsJobIDApplicationsRequestBodyAdditionalPhoneNumberTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyAnswer,
        PostAtsJobsJobIDApplicationsRequestBodyAnswerTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyAnswerUnion,
        PostAtsJobsJobIDApplicationsRequestBodyAnswerUnionTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyAttachment,
        PostAtsJobsJobIDApplicationsRequestBodyAttachmentType,
        PostAtsJobsJobIDApplicationsRequestBodyAttachmentTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyAvature,
        PostAtsJobsJobIDApplicationsRequestBodyAvatureTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyBullhorn,
        PostAtsJobsJobIDApplicationsRequestBodyBullhornTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyCandidate,
        PostAtsJobsJobIDApplicationsRequestBodyCandidateData,
        PostAtsJobsJobIDApplicationsRequestBodyCandidateDataTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyCandidateTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyContactData,
        PostAtsJobsJobIDApplicationsRequestBodyContactDataTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyCountryCityReference,
        PostAtsJobsJobIDApplicationsRequestBodyCountryCityReferenceTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyCountryRegionReference,
        PostAtsJobsJobIDApplicationsRequestBodyCountryRegionReferenceTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyDegreeReference,
        PostAtsJobsJobIDApplicationsRequestBodyDegreeReferenceTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyDvinci,
        PostAtsJobsJobIDApplicationsRequestBodyDvinciTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyEducationDatum,
        PostAtsJobsJobIDApplicationsRequestBodyEducationDatumTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyExperienceDatum,
        PostAtsJobsJobIDApplicationsRequestBodyExperienceDatumTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyFieldOfStudyReference,
        PostAtsJobsJobIDApplicationsRequestBodyFieldOfStudyReferenceTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyGdprConsent,
        PostAtsJobsJobIDApplicationsRequestBodyGdprConsentTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyGender,
        PostAtsJobsJobIDApplicationsRequestBodyGlobalPersonalInformationData,
        PostAtsJobsJobIDApplicationsRequestBodyGlobalPersonalInformationDataTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyGreenhouse,
        PostAtsJobsJobIDApplicationsRequestBodyGreenhouseTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyGuidecom,
        PostAtsJobsJobIDApplicationsRequestBodyGuidecomTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyHrworks,
        PostAtsJobsJobIDApplicationsRequestBodyHrworksTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyJobApplicationData,
        PostAtsJobsJobIDApplicationsRequestBodyJobApplicationDataTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyJobAppliedToData,
        PostAtsJobsJobIDApplicationsRequestBodyJobAppliedToDataTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyJobylon,
        PostAtsJobsJobIDApplicationsRequestBodyJobylonApplication,
        PostAtsJobsJobIDApplicationsRequestBodyJobylonApplicationTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyJobylonTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyLanguage,
        PostAtsJobsJobIDApplicationsRequestBodyLanguageAbility,
        PostAtsJobsJobIDApplicationsRequestBodyLanguageAbilityData,
        PostAtsJobsJobIDApplicationsRequestBodyLanguageAbilityDataTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyLanguageAbilityTypeReference,
        PostAtsJobsJobIDApplicationsRequestBodyLanguageAbilityTypeReferenceTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyLanguageAbilityTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyLanguageDatum,
        PostAtsJobsJobIDApplicationsRequestBodyLanguageDatumLanguageReference,
        PostAtsJobsJobIDApplicationsRequestBodyLanguageDatumLanguageReferenceTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyLanguageDatumTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyLanguageProficiencyReference,
        PostAtsJobsJobIDApplicationsRequestBodyLanguageProficiencyReferenceTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyLanguageReference,
        PostAtsJobsJobIDApplicationsRequestBodyLanguageReferenceTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyLanguageTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyLever,
        PostAtsJobsJobIDApplicationsRequestBodyLeverTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyLocation,
        PostAtsJobsJobIDApplicationsRequestBodyLocationData,
        PostAtsJobsJobIDApplicationsRequestBodyLocationDataTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyLocationTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyNameDetailData,
        PostAtsJobsJobIDApplicationsRequestBodyNameDetailDataTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyPeriod,
        PostAtsJobsJobIDApplicationsRequestBodyPersonio,
        PostAtsJobsJobIDApplicationsRequestBodyPersonioTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyPiloga,
        PostAtsJobsJobIDApplicationsRequestBodyPilogaCandidate,
        PostAtsJobsJobIDApplicationsRequestBodyPilogaCandidateTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyPilogaTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyPostHeaders,
        PostAtsJobsJobIDApplicationsRequestBodyPostHeadersTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyRecruitee,
        PostAtsJobsJobIDApplicationsRequestBodyRecruiteeCandidate,
        PostAtsJobsJobIDApplicationsRequestBodyRecruiteeCandidateTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyRecruiteeTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyRemoteFields,
        PostAtsJobsJobIDApplicationsRequestBodyRemoteFieldsTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyResumeData,
        PostAtsJobsJobIDApplicationsRequestBodyResumeDataTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodySalaryExpectations,
        PostAtsJobsJobIDApplicationsRequestBodySalaryExpectationsTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyScreeningQuestionAnswer,
        PostAtsJobsJobIDApplicationsRequestBodyScreeningQuestionAnswerTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodySkillDatum,
        PostAtsJobsJobIDApplicationsRequestBodySkillDatumTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodySmartrecruiters,
        PostAtsJobsJobIDApplicationsRequestBodySmartrecruitersTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodySocialLink,
        PostAtsJobsJobIDApplicationsRequestBodySocialLinkTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodySocialSuffixReference,
        PostAtsJobsJobIDApplicationsRequestBodySocialSuffixReferenceTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodySource,
        PostAtsJobsJobIDApplicationsRequestBodySourceTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodySourcedBy,
        PostAtsJobsJobIDApplicationsRequestBodySourcedByTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyStep,
        PostAtsJobsJobIDApplicationsRequestBodyStepTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodySuccessfactors,
        PostAtsJobsJobIDApplicationsRequestBodySuccessfactorsTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyTalentadore,
        PostAtsJobsJobIDApplicationsRequestBodyTalentadoreTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyTalentsoft,
        PostAtsJobsJobIDApplicationsRequestBodyTalentsoftTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyTeamtailor,
        PostAtsJobsJobIDApplicationsRequestBodyTeamtailorApplication,
        PostAtsJobsJobIDApplicationsRequestBodyTeamtailorApplicationTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyTeamtailorTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyUmantis,
        PostAtsJobsJobIDApplicationsRequestBodyUmantisTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyWorkable,
        PostAtsJobsJobIDApplicationsRequestBodyWorkableTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyWorkday,
        PostAtsJobsJobIDApplicationsRequestBodyWorkdayTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyWorkerReference,
        PostAtsJobsJobIDApplicationsRequestBodyWorkerReferenceTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyWorkflow,
        PostAtsJobsJobIDApplicationsRequestBodyWorkflowTypedDict,
        PostAtsJobsJobIDApplicationsRequestBodyZohorecruit,
        PostAtsJobsJobIDApplicationsRequestBodyZohorecruitTypedDict,
    )
    from .postconnectcreatelinkpositiveresponse import (
        PostConnectCreateLinkPositiveResponse,
        PostConnectCreateLinkPositiveResponseData,
        PostConnectCreateLinkPositiveResponseDataTypedDict,
        PostConnectCreateLinkPositiveResponseTypedDict,
    )
    from .postconnectcreatelinkrequestbody import (
        IntegrationTool,
        PostConnectCreateLinkRequestBody,
        PostConnectCreateLinkRequestBodyIntegrationCategory,
        PostConnectCreateLinkRequestBodyLanguage,
        PostConnectCreateLinkRequestBodyLinkType,
        PostConnectCreateLinkRequestBodyTypedDict,
    )
    from .postforcesyncop import PostForceSyncGlobals, PostForceSyncGlobalsTypedDict
    from .postforcesyncpositiveresponse import (
        PostForceSyncPositiveResponse,
        PostForceSyncPositiveResponseData,
        PostForceSyncPositiveResponseDataTypedDict,
        PostForceSyncPositiveResponseType,
        PostForceSyncPositiveResponseTypedDict,
    )
    from .postforcesyncrequestbody import (
        PostForceSyncRequestBody,
        PostForceSyncRequestBodyType,
        PostForceSyncRequestBodyTypedDict,
    )
    from .posthrisabsencesop import (
        PostHrisAbsencesGlobals,
        PostHrisAbsencesGlobalsTypedDict,
    )
    from .posthrisabsencespositiveresponse import (
        PostHrisAbsencesPositiveResponse,
        PostHrisAbsencesPositiveResponseData,
        PostHrisAbsencesPositiveResponseDataTypedDict,
        PostHrisAbsencesPositiveResponseStatus,
        PostHrisAbsencesPositiveResponseTypedDict,
        PostHrisAbsencesPositiveResponseUnit,
        PostHrisAbsencesPositiveResponseWarning,
        PostHrisAbsencesPositiveResponseWarningTypedDict,
    )
    from .posthrisabsencesrequestbody import (
        PostHrisAbsencesRequestBody,
        PostHrisAbsencesRequestBodyAdpworkforcenow,
        PostHrisAbsencesRequestBodyAdpworkforcenowTypedDict,
        PostHrisAbsencesRequestBodyRemoteFields,
        PostHrisAbsencesRequestBodyRemoteFieldsTypedDict,
        PostHrisAbsencesRequestBodyStatus,
        PostHrisAbsencesRequestBodyTypedDict,
        PostHrisAbsencesRequestBodyUnit,
    )
    from .posthrisemployeesemployeeiddocumentsop import (
        PostHrisEmployeesEmployeeIDDocumentsGlobals,
        PostHrisEmployeesEmployeeIDDocumentsGlobalsTypedDict,
        PostHrisEmployeesEmployeeIDDocumentsRequest,
        PostHrisEmployeesEmployeeIDDocumentsRequestTypedDict,
    )
    from .posthrisemployeesemployeeiddocumentspositiveresponse import (
        PostHrisEmployeesEmployeeIDDocumentsPositiveResponse,
        PostHrisEmployeesEmployeeIDDocumentsPositiveResponseData,
        PostHrisEmployeesEmployeeIDDocumentsPositiveResponseDataTypedDict,
        PostHrisEmployeesEmployeeIDDocumentsPositiveResponseTypedDict,
        PostHrisEmployeesEmployeeIDDocumentsPositiveResponseWarning,
        PostHrisEmployeesEmployeeIDDocumentsPositiveResponseWarningTypedDict,
    )
    from .posthrisemployeesemployeeiddocumentsrequestbody import (
        Document,
        DocumentTypedDict,
        PostHrisEmployeesEmployeeIDDocumentsRequestBody,
        PostHrisEmployeesEmployeeIDDocumentsRequestBodyTypedDict,
    )
    from .posthrisemployeesformop import (
        PostHrisEmployeesFormGlobals,
        PostHrisEmployeesFormGlobalsTypedDict,
    )
    from .posthrisemployeesformpositiveresponse import (
        PostHrisEmployeesFormPositiveResponse,
        PostHrisEmployeesFormPositiveResponseData,
        PostHrisEmployeesFormPositiveResponseDataTypedDict,
        PostHrisEmployeesFormPositiveResponseTypedDict,
        PostHrisEmployeesFormPositiveResponseWarning,
        PostHrisEmployeesFormPositiveResponseWarningTypedDict,
    )
    from .posthrisemployeesformrequestbody import (
        PostHrisEmployeesFormRequestBody,
        PostHrisEmployeesFormRequestBodyTypedDict,
    )
    from .postintegrationsintegrationidrelinkop import (
        PostIntegrationsIntegrationIDRelinkRequest,
        PostIntegrationsIntegrationIDRelinkRequestTypedDict,
    )
    from .postintegrationsintegrationidrelinkpositiveresponse import (
        PostIntegrationsIntegrationIDRelinkPositiveResponse,
        PostIntegrationsIntegrationIDRelinkPositiveResponseData,
        PostIntegrationsIntegrationIDRelinkPositiveResponseDataTypedDict,
        PostIntegrationsIntegrationIDRelinkPositiveResponseTypedDict,
    )
    from .postintegrationsintegrationidrelinkrequestbody import (
        PostIntegrationsIntegrationIDRelinkRequestBody,
        PostIntegrationsIntegrationIDRelinkRequestBodyLanguage,
        PostIntegrationsIntegrationIDRelinkRequestBodyLinkType,
        PostIntegrationsIntegrationIDRelinkRequestBodyTypedDict,
    )
    from .postpassthroughtoolapiop import (
        PostPassthroughToolAPIGlobals,
        PostPassthroughToolAPIGlobalsTypedDict,
        PostPassthroughToolAPIRequest,
        PostPassthroughToolAPIRequestTypedDict,
    )
    from .postpassthroughtoolapipositiveresponse import (
        Headers,
        HeadersTypedDict,
        PostPassthroughToolAPIPositiveResponse,
        PostPassthroughToolAPIPositiveResponseData,
        PostPassthroughToolAPIPositiveResponseDataTypedDict,
        PostPassthroughToolAPIPositiveResponseTypedDict,
        PostPassthroughToolAPIPositiveResponseWarning,
        PostPassthroughToolAPIPositiveResponseWarningTypedDict,
    )
    from .postpassthroughtoolapirequestbody import (
        Method,
        MultipartFormDatum,
        MultipartFormDatumTypedDict,
        PostPassthroughToolAPIRequestBody,
        PostPassthroughToolAPIRequestBodyTypedDict,
        Value,
        ValueTypedDict,
        ValueUnion,
        ValueUnionTypedDict,
    )
    from .putassessmentordersassessmentorderidresultop import (
        PutAssessmentOrdersAssessmentOrderIDResultGlobals,
        PutAssessmentOrdersAssessmentOrderIDResultGlobalsTypedDict,
        PutAssessmentOrdersAssessmentOrderIDResultRequest,
        PutAssessmentOrdersAssessmentOrderIDResultRequestTypedDict,
    )
    from .putassessmentordersassessmentorderidresultpositiveresponse import (
        PutAssessmentOrdersAssessmentOrderIDResultPositiveResponse,
        PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseData,
        PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseDataTypedDict,
        PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseTypedDict,
        PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseWarning,
        PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseWarningTypedDict,
    )
    from .putassessmentordersassessmentorderidresultrequestbody import (
        Attribute,
        AttributeStatus,
        AttributeSubResult,
        AttributeSubResultTypedDict,
        AttributeText,
        AttributeTextTypedDict,
        AttributeTypedDict,
        PutAssessmentOrdersAssessmentOrderIDResultRequestBody,
        PutAssessmentOrdersAssessmentOrderIDResultRequestBodyAttachment,
        PutAssessmentOrdersAssessmentOrderIDResultRequestBodyAttachmentTypedDict,
        PutAssessmentOrdersAssessmentOrderIDResultRequestBodyRemoteFields,
        PutAssessmentOrdersAssessmentOrderIDResultRequestBodyRemoteFieldsTypedDict,
        PutAssessmentOrdersAssessmentOrderIDResultRequestBodySmartrecruiters,
        PutAssessmentOrdersAssessmentOrderIDResultRequestBodySmartrecruitersTypedDict,
        PutAssessmentOrdersAssessmentOrderIDResultRequestBodyStatus,
        PutAssessmentOrdersAssessmentOrderIDResultRequestBodyTypedDict,
        Score,
        ScoreTypedDict,
    )
    from .putassessmentpackagesop import (
        PutAssessmentPackagesGlobals,
        PutAssessmentPackagesGlobalsTypedDict,
    )
    from .putassessmentpackagespositiveresponse import (
        PutAssessmentPackagesPositiveResponse,
        PutAssessmentPackagesPositiveResponseData,
        PutAssessmentPackagesPositiveResponseDataTypedDict,
        PutAssessmentPackagesPositiveResponseTypedDict,
        PutAssessmentPackagesPositiveResponseWarning,
        PutAssessmentPackagesPositiveResponseWarningTypedDict,
    )
    from .putassessmentpackagesrequestbody import (
        PutAssessmentPackagesRequestBody,
        PutAssessmentPackagesRequestBodyPackage,
        PutAssessmentPackagesRequestBodyPackageTypedDict,
        PutAssessmentPackagesRequestBodyType,
        PutAssessmentPackagesRequestBodyTypedDict,
    )
    from .putatsapplicationsapplicationidstageop import (
        PutAtsApplicationsApplicationIDStageGlobals,
        PutAtsApplicationsApplicationIDStageGlobalsTypedDict,
        PutAtsApplicationsApplicationIDStageRequest,
        PutAtsApplicationsApplicationIDStageRequestTypedDict,
    )
    from .putatsapplicationsapplicationidstagepositiveresponse import (
        PutAtsApplicationsApplicationIDStagePositiveResponse,
        PutAtsApplicationsApplicationIDStagePositiveResponseData,
        PutAtsApplicationsApplicationIDStagePositiveResponseDataTypedDict,
        PutAtsApplicationsApplicationIDStagePositiveResponseTypedDict,
        PutAtsApplicationsApplicationIDStagePositiveResponseWarning,
        PutAtsApplicationsApplicationIDStagePositiveResponseWarningTypedDict,
    )
    from .putatsapplicationsapplicationidstagerequestbody import (
        PutAtsApplicationsApplicationIDStageRequestBody,
        PutAtsApplicationsApplicationIDStageRequestBodyGreenhouse,
        PutAtsApplicationsApplicationIDStageRequestBodyGreenhouseTypedDict,
        PutAtsApplicationsApplicationIDStageRequestBodyPostHeaders,
        PutAtsApplicationsApplicationIDStageRequestBodyPostHeadersTypedDict,
        PutAtsApplicationsApplicationIDStageRequestBodyRemoteFields,
        PutAtsApplicationsApplicationIDStageRequestBodyRemoteFieldsTypedDict,
        PutAtsApplicationsApplicationIDStageRequestBodyTypedDict,
        PutAtsApplicationsApplicationIDStageRequestBodyWorkable,
        PutAtsApplicationsApplicationIDStageRequestBodyWorkableTypedDict,
    )
    from .putintegrationsintegrationidcustomfieldscustomfieldidop import (
        PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDRequest,
        PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDRequestTypedDict,
    )
    from .putintegrationsintegrationidcustomfieldscustomfieldidpositiveresponse import (
        PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDPositiveResponse,
        PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDPositiveResponseData,
        PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDPositiveResponseDataTypedDict,
        PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDPositiveResponseIntegrationField,
        PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDPositiveResponseIntegrationFieldTypedDict,
        PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDPositiveResponseType,
        PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDPositiveResponseTypedDict,
    )
    from .putintegrationsintegrationidcustomfieldscustomfieldidrequestbody import (
        PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDRequestBody,
        PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDRequestBodyTypedDict,
    )
    from .schema1 import Schema1, Schema1TypedDict
    from .schema1_union_1 import (
        Schema1Array1,
        Schema1Array1TypedDict,
        Schema1Checkbox,
        Schema1CheckboxTypedDict,
        Schema1Date,
        Schema1DateTypedDict,
        Schema1Entry1,
        Schema1Entry1TypedDict,
        Schema1Entry2,
        Schema1Entry2TypedDict,
        Schema1File,
        Schema1FileRestrictions,
        Schema1FileRestrictionsTypedDict,
        Schema1FileTypedDict,
        Schema1MultiSelect,
        Schema1MultiSelectTypedDict,
        Schema1Number,
        Schema1NumberTypedDict,
        Schema1Object,
        Schema1ObjectTypedDict,
        Schema1OptionsInline1,
        Schema1OptionsInline1TypedDict,
        Schema1OptionsInline2,
        Schema1OptionsInline2TypedDict,
        Schema1OptionsReferenced1,
        Schema1OptionsReferenced1TypedDict,
        Schema1OptionsReferenced2,
        Schema1OptionsReferenced2TypedDict,
        Schema1OptionsUnion1,
        Schema1OptionsUnion1TypedDict,
        Schema1OptionsUnion2,
        Schema1OptionsUnion2TypedDict,
        Schema1RemoteID1,
        Schema1RemoteID1TypedDict,
        Schema1RemoteID2,
        Schema1RemoteID2TypedDict,
        Schema1SingleSelect,
        Schema1SingleSelectTypedDict,
        Schema1Text,
        Schema1TextTypedDict,
        Schema1UnifiedKey1,
        Schema1UnifiedKey2,
        Schema1UnifiedKey3,
        Schema1UnifiedKey4,
        Schema1UnifiedKey5,
        Schema1UnifiedKey6,
        Schema1UnifiedKey7,
        Schema1UnifiedKey8,
        Schema1Union1,
        Schema1Union1TypedDict,
    )
    from .schema4 import Schema4, Schema4TypedDict
    from .security import Security, SecurityTypedDict
    from .syncfinishedwebhookpayload import (
        SyncFinishedWebhookPayload,
        SyncFinishedWebhookPayloadData,
        SyncFinishedWebhookPayloadDataTypedDict,
        SyncFinishedWebhookPayloadEndUser,
        SyncFinishedWebhookPayloadEndUserTypedDict,
        SyncFinishedWebhookPayloadIntegrationCategory,
        SyncFinishedWebhookPayloadType,
        SyncFinishedWebhookPayloadTypedDict,
    )
    from .webhookassessmentorderreceivedwebhookpayloadop import (
        WebhookAssessmentOrderReceivedWebhookPayloadRequest,
        WebhookAssessmentOrderReceivedWebhookPayloadRequestTypedDict,
    )
    from .webhookconnectionflowfailedwebhookpayloadop import (
        WebhookConnectionFlowFailedWebhookPayloadRequest,
        WebhookConnectionFlowFailedWebhookPayloadRequestTypedDict,
    )
    from .webhookdatachangedwebhookpayloadop import (
        WebhookDataChangedWebhookPayloadRequest,
        WebhookDataChangedWebhookPayloadRequestTypedDict,
    )
    from .webhookinlineassessmentorderreceivedwebhookpayloadop import (
        WebhookInlineAssessmentOrderReceivedWebhookPayloadRequest,
        WebhookInlineAssessmentOrderReceivedWebhookPayloadRequestTypedDict,
    )
    from .webhookintegrationcreatedwebhookpayloadop import (
        WebhookIntegrationCreatedWebhookPayloadRequest,
        WebhookIntegrationCreatedWebhookPayloadRequestTypedDict,
    )
    from .webhookintegrationdeletedwebhookpayloadop import (
        WebhookIntegrationDeletedWebhookPayloadRequest,
        WebhookIntegrationDeletedWebhookPayloadRequestTypedDict,
    )
    from .webhookintegrationstatechangedwebhookpayloadop import (
        WebhookIntegrationStateChangedWebhookPayloadRequest,
        WebhookIntegrationStateChangedWebhookPayloadRequestTypedDict,
    )
    from .webhooksyncfinishedwebhookpayloadop import (
        WebhookSyncFinishedWebhookPayloadRequest,
        WebhookSyncFinishedWebhookPayloadRequestTypedDict,
    )  # Pydantic models with forward references
Schema2Array1.model_rebuild()
Schema2Array2.model_rebuild()
Schema2Object2.model_rebuild()
Schema1Array2.model_rebuild()


__all__ = [
    "AssessmentOrderReceivedWebhookPayload",
    "AssessmentOrderReceivedWebhookPayloadApplication",
    "AssessmentOrderReceivedWebhookPayloadApplicationTypedDict",
    "AssessmentOrderReceivedWebhookPayloadCandidate",
    "AssessmentOrderReceivedWebhookPayloadCandidateTypedDict",
    "AssessmentOrderReceivedWebhookPayloadData",
    "AssessmentOrderReceivedWebhookPayloadDataTypedDict",
    "AssessmentOrderReceivedWebhookPayloadHiringTeam",
    "AssessmentOrderReceivedWebhookPayloadHiringTeamRole",
    "AssessmentOrderReceivedWebhookPayloadHiringTeamTypedDict",
    "AssessmentOrderReceivedWebhookPayloadJob",
    "AssessmentOrderReceivedWebhookPayloadJobTypedDict",
    "AssessmentOrderReceivedWebhookPayloadLocation",
    "AssessmentOrderReceivedWebhookPayloadLocationTypedDict",
    "AssessmentOrderReceivedWebhookPayloadStatus",
    "AssessmentOrderReceivedWebhookPayloadType",
    "AssessmentOrderReceivedWebhookPayloadTypedDict",
    "Assets",
    "AssetsTypedDict",
    "Attribute",
    "AttributeStatus",
    "AttributeSubResult",
    "AttributeSubResultTypedDict",
    "AttributeText",
    "AttributeTextTypedDict",
    "AttributeTypedDict",
    "BankAccount",
    "BankAccountTypedDict",
    "Break",
    "BreakTypedDict",
    "ChangedModel",
    "ChangedModelTypedDict",
    "ConnectionFlowFailedWebhookPayload",
    "ConnectionFlowFailedWebhookPayloadData",
    "ConnectionFlowFailedWebhookPayloadDataTypedDict",
    "ConnectionFlowFailedWebhookPayloadEndUser",
    "ConnectionFlowFailedWebhookPayloadEndUserTypedDict",
    "ConnectionFlowFailedWebhookPayloadIntegrationCategory",
    "ConnectionFlowFailedWebhookPayloadType",
    "ConnectionFlowFailedWebhookPayloadTypedDict",
    "ContentType",
    "Coverage",
    "CoverageTypedDict",
    "DataChangedWebhookPayload",
    "DataChangedWebhookPayloadData",
    "DataChangedWebhookPayloadDataTypedDict",
    "DataChangedWebhookPayloadIntegrationCategory",
    "DataChangedWebhookPayloadType",
    "DataChangedWebhookPayloadTypedDict",
    "DeleteAtsCandidatesCandidateIDTagsGlobals",
    "DeleteAtsCandidatesCandidateIDTagsGlobalsTypedDict",
    "DeleteAtsCandidatesCandidateIDTagsPositiveResponse",
    "DeleteAtsCandidatesCandidateIDTagsPositiveResponseData",
    "DeleteAtsCandidatesCandidateIDTagsPositiveResponseDataTypedDict",
    "DeleteAtsCandidatesCandidateIDTagsPositiveResponseTypedDict",
    "DeleteAtsCandidatesCandidateIDTagsPositiveResponseWarning",
    "DeleteAtsCandidatesCandidateIDTagsPositiveResponseWarningTypedDict",
    "DeleteAtsCandidatesCandidateIDTagsRequest",
    "DeleteAtsCandidatesCandidateIDTagsRequestBody",
    "DeleteAtsCandidatesCandidateIDTagsRequestBodyGreenhouse",
    "DeleteAtsCandidatesCandidateIDTagsRequestBodyGreenhouseTypedDict",
    "DeleteAtsCandidatesCandidateIDTagsRequestBodyPostHeaders",
    "DeleteAtsCandidatesCandidateIDTagsRequestBodyPostHeadersTypedDict",
    "DeleteAtsCandidatesCandidateIDTagsRequestBodyRemoteFields",
    "DeleteAtsCandidatesCandidateIDTagsRequestBodyRemoteFieldsTypedDict",
    "DeleteAtsCandidatesCandidateIDTagsRequestBodyTag",
    "DeleteAtsCandidatesCandidateIDTagsRequestBodyTagTypedDict",
    "DeleteAtsCandidatesCandidateIDTagsRequestBodyTypedDict",
    "DeleteAtsCandidatesCandidateIDTagsRequestBodyWorkable",
    "DeleteAtsCandidatesCandidateIDTagsRequestBodyWorkableTypedDict",
    "DeleteAtsCandidatesCandidateIDTagsRequestTypedDict",
    "DeleteHrisAbsencesAbsenceIDGlobals",
    "DeleteHrisAbsencesAbsenceIDGlobalsTypedDict",
    "DeleteHrisAbsencesAbsenceIDPositiveResponse",
    "DeleteHrisAbsencesAbsenceIDPositiveResponseData",
    "DeleteHrisAbsencesAbsenceIDPositiveResponseDataTypedDict",
    "DeleteHrisAbsencesAbsenceIDPositiveResponseStatus",
    "DeleteHrisAbsencesAbsenceIDPositiveResponseTypedDict",
    "DeleteHrisAbsencesAbsenceIDPositiveResponseUnit",
    "DeleteHrisAbsencesAbsenceIDPositiveResponseWarning",
    "DeleteHrisAbsencesAbsenceIDPositiveResponseWarningTypedDict",
    "DeleteHrisAbsencesAbsenceIDRequest",
    "DeleteHrisAbsencesAbsenceIDRequestBody",
    "DeleteHrisAbsencesAbsenceIDRequestBodyAdpworkforcenow",
    "DeleteHrisAbsencesAbsenceIDRequestBodyAdpworkforcenowTypedDict",
    "DeleteHrisAbsencesAbsenceIDRequestBodyRemoteFields",
    "DeleteHrisAbsencesAbsenceIDRequestBodyRemoteFieldsTypedDict",
    "DeleteHrisAbsencesAbsenceIDRequestBodyTypedDict",
    "DeleteHrisAbsencesAbsenceIDRequestTypedDict",
    "DeleteIntegrationsIntegrationIDPositiveResponse",
    "DeleteIntegrationsIntegrationIDPositiveResponseData",
    "DeleteIntegrationsIntegrationIDPositiveResponseDataTypedDict",
    "DeleteIntegrationsIntegrationIDPositiveResponseTypedDict",
    "DeleteIntegrationsIntegrationIDRequest",
    "DeleteIntegrationsIntegrationIDRequestBody",
    "DeleteIntegrationsIntegrationIDRequestBodyTypedDict",
    "DeleteIntegrationsIntegrationIDRequestTypedDict",
    "DisplayType1",
    "DisplayType2",
    "DisplayType3",
    "Document",
    "DocumentTypedDict",
    "DomesticBankRouting",
    "DomesticBankRoutingType",
    "DomesticBankRoutingTypedDict",
    "Employment",
    "EmploymentEmploymentType",
    "EmploymentStatus",
    "EmploymentTypedDict",
    "Ethnicity",
    "Feature",
    "FeatureCoverageStatus",
    "FeatureTypedDict",
    "FieldScopeConfigSetting",
    "Format",
    "FormatBoolean",
    "FormatBooleanTypedDict",
    "FormatDate",
    "FormatDateTypedDict",
    "FormatFile",
    "FormatFileTypedDict",
    "FormatInformation",
    "FormatInformationTypedDict",
    "FormatMultiSelect",
    "FormatMultiSelectTypedDict",
    "FormatNumber",
    "FormatNumberTypedDict",
    "FormatSingleSelect",
    "FormatSingleSelectTypedDict",
    "FormatText",
    "FormatTextTypedDict",
    "FormatTypedDict",
    "FormatUnknown",
    "FormatUnknownTypedDict",
    "GetAssessmentOrdersOpenGlobals",
    "GetAssessmentOrdersOpenGlobalsTypedDict",
    "GetAssessmentOrdersOpenPositiveResponse",
    "GetAssessmentOrdersOpenPositiveResponseApplication",
    "GetAssessmentOrdersOpenPositiveResponseApplicationTypedDict",
    "GetAssessmentOrdersOpenPositiveResponseCandidate",
    "GetAssessmentOrdersOpenPositiveResponseCandidateTypedDict",
    "GetAssessmentOrdersOpenPositiveResponseData",
    "GetAssessmentOrdersOpenPositiveResponseDataTypedDict",
    "GetAssessmentOrdersOpenPositiveResponseHiringTeam",
    "GetAssessmentOrdersOpenPositiveResponseHiringTeamRole",
    "GetAssessmentOrdersOpenPositiveResponseHiringTeamTypedDict",
    "GetAssessmentOrdersOpenPositiveResponseJob",
    "GetAssessmentOrdersOpenPositiveResponseJobTypedDict",
    "GetAssessmentOrdersOpenPositiveResponseLocation",
    "GetAssessmentOrdersOpenPositiveResponseLocationTypedDict",
    "GetAssessmentOrdersOpenPositiveResponseResult",
    "GetAssessmentOrdersOpenPositiveResponseResultTypedDict",
    "GetAssessmentOrdersOpenPositiveResponseTypedDict",
    "GetAssessmentOrdersOpenRequest",
    "GetAssessmentOrdersOpenRequestTypedDict",
    "GetAssessmentOrdersOpenResponse",
    "GetAssessmentOrdersOpenResponseTypedDict",
    "GetAssessmentPackagesGlobals",
    "GetAssessmentPackagesGlobalsTypedDict",
    "GetAssessmentPackagesPositiveResponse",
    "GetAssessmentPackagesPositiveResponseData",
    "GetAssessmentPackagesPositiveResponseDataTypedDict",
    "GetAssessmentPackagesPositiveResponsePackage",
    "GetAssessmentPackagesPositiveResponsePackageTypedDict",
    "GetAssessmentPackagesPositiveResponseType",
    "GetAssessmentPackagesPositiveResponseTypedDict",
    "GetAssessmentPackagesRequest",
    "GetAssessmentPackagesRequestTypedDict",
    "GetAtsApplicationStagesGlobals",
    "GetAtsApplicationStagesGlobalsTypedDict",
    "GetAtsApplicationStagesPositiveResponse",
    "GetAtsApplicationStagesPositiveResponseData",
    "GetAtsApplicationStagesPositiveResponseDataTypedDict",
    "GetAtsApplicationStagesPositiveResponseResult",
    "GetAtsApplicationStagesPositiveResponseResultTypedDict",
    "GetAtsApplicationStagesPositiveResponseTypedDict",
    "GetAtsApplicationStagesRequest",
    "GetAtsApplicationStagesRequestTypedDict",
    "GetAtsApplicationStagesResponse",
    "GetAtsApplicationStagesResponseTypedDict",
    "GetAtsApplicationsApplicationIDAttachmentsGlobals",
    "GetAtsApplicationsApplicationIDAttachmentsGlobalsTypedDict",
    "GetAtsApplicationsApplicationIDAttachmentsPositiveResponse",
    "GetAtsApplicationsApplicationIDAttachmentsPositiveResponseData",
    "GetAtsApplicationsApplicationIDAttachmentsPositiveResponseDataTypedDict",
    "GetAtsApplicationsApplicationIDAttachmentsPositiveResponseResult",
    "GetAtsApplicationsApplicationIDAttachmentsPositiveResponseResultTypedDict",
    "GetAtsApplicationsApplicationIDAttachmentsPositiveResponseType",
    "GetAtsApplicationsApplicationIDAttachmentsPositiveResponseTypedDict",
    "GetAtsApplicationsApplicationIDAttachmentsPositiveResponseWarning",
    "GetAtsApplicationsApplicationIDAttachmentsPositiveResponseWarningTypedDict",
    "GetAtsApplicationsApplicationIDAttachmentsRequest",
    "GetAtsApplicationsApplicationIDAttachmentsRequestTypedDict",
    "GetAtsApplicationsGlobals",
    "GetAtsApplicationsGlobalsTypedDict",
    "GetAtsApplicationsPositiveResponse",
    "GetAtsApplicationsPositiveResponseAnswer1",
    "GetAtsApplicationsPositiveResponseAnswer1TypedDict",
    "GetAtsApplicationsPositiveResponseAnswer2",
    "GetAtsApplicationsPositiveResponseAnswer2TypedDict",
    "GetAtsApplicationsPositiveResponseAnswer3",
    "GetAtsApplicationsPositiveResponseAnswer3TypedDict",
    "GetAtsApplicationsPositiveResponseAnswer4",
    "GetAtsApplicationsPositiveResponseAnswer4TypedDict",
    "GetAtsApplicationsPositiveResponseAnswer5",
    "GetAtsApplicationsPositiveResponseAnswer5TypedDict",
    "GetAtsApplicationsPositiveResponseAnswer6",
    "GetAtsApplicationsPositiveResponseAnswer6TypedDict",
    "GetAtsApplicationsPositiveResponseAnswer7",
    "GetAtsApplicationsPositiveResponseAnswer7TypedDict",
    "GetAtsApplicationsPositiveResponseCandidate",
    "GetAtsApplicationsPositiveResponseCandidateTypedDict",
    "GetAtsApplicationsPositiveResponseCurrentStage",
    "GetAtsApplicationsPositiveResponseCurrentStageTypedDict",
    "GetAtsApplicationsPositiveResponseData",
    "GetAtsApplicationsPositiveResponseDataTypedDict",
    "GetAtsApplicationsPositiveResponseEmailAddress",
    "GetAtsApplicationsPositiveResponseEmailAddressTypedDict",
    "GetAtsApplicationsPositiveResponseJob",
    "GetAtsApplicationsPositiveResponseJobTypedDict",
    "GetAtsApplicationsPositiveResponseLocation",
    "GetAtsApplicationsPositiveResponseLocationTypedDict",
    "GetAtsApplicationsPositiveResponseOutcome",
    "GetAtsApplicationsPositiveResponsePhoneNumber",
    "GetAtsApplicationsPositiveResponsePhoneNumberTypedDict",
    "GetAtsApplicationsPositiveResponseQuestionBoolean",
    "GetAtsApplicationsPositiveResponseQuestionBooleanTypedDict",
    "GetAtsApplicationsPositiveResponseQuestionDate",
    "GetAtsApplicationsPositiveResponseQuestionDateTypedDict",
    "GetAtsApplicationsPositiveResponseQuestionMultiSelect",
    "GetAtsApplicationsPositiveResponseQuestionMultiSelectTypedDict",
    "GetAtsApplicationsPositiveResponseQuestionNumber",
    "GetAtsApplicationsPositiveResponseQuestionNumberTypedDict",
    "GetAtsApplicationsPositiveResponseQuestionSingleSelect",
    "GetAtsApplicationsPositiveResponseQuestionSingleSelectTypedDict",
    "GetAtsApplicationsPositiveResponseQuestionText",
    "GetAtsApplicationsPositiveResponseQuestionTextTypedDict",
    "GetAtsApplicationsPositiveResponseQuestionUnknown",
    "GetAtsApplicationsPositiveResponseQuestionUnknownTypedDict",
    "GetAtsApplicationsPositiveResponseResult",
    "GetAtsApplicationsPositiveResponseResultTypedDict",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer1",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer1TypedDict",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer2",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer2TypedDict",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer3",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer3TypedDict",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer4",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer4TypedDict",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer5",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer5TypedDict",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer6",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer6TypedDict",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer7",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer7TypedDict",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswerUnion",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswerUnionTypedDict",
    "GetAtsApplicationsPositiveResponseSocialMedia",
    "GetAtsApplicationsPositiveResponseSocialMediaTypedDict",
    "GetAtsApplicationsPositiveResponseStatus",
    "GetAtsApplicationsPositiveResponseTag",
    "GetAtsApplicationsPositiveResponseTagTypedDict",
    "GetAtsApplicationsPositiveResponseTypedDict",
    "GetAtsApplicationsRequest",
    "GetAtsApplicationsRequestTypedDict",
    "GetAtsApplicationsResponse",
    "GetAtsApplicationsResponseTypedDict",
    "GetAtsCandidatesCandidateIDAttachmentsGlobals",
    "GetAtsCandidatesCandidateIDAttachmentsGlobalsTypedDict",
    "GetAtsCandidatesCandidateIDAttachmentsPositiveResponse",
    "GetAtsCandidatesCandidateIDAttachmentsPositiveResponseData",
    "GetAtsCandidatesCandidateIDAttachmentsPositiveResponseDataTypedDict",
    "GetAtsCandidatesCandidateIDAttachmentsPositiveResponseResult",
    "GetAtsCandidatesCandidateIDAttachmentsPositiveResponseResultTypedDict",
    "GetAtsCandidatesCandidateIDAttachmentsPositiveResponseType",
    "GetAtsCandidatesCandidateIDAttachmentsPositiveResponseTypedDict",
    "GetAtsCandidatesCandidateIDAttachmentsPositiveResponseWarning",
    "GetAtsCandidatesCandidateIDAttachmentsPositiveResponseWarningTypedDict",
    "GetAtsCandidatesCandidateIDAttachmentsRequest",
    "GetAtsCandidatesCandidateIDAttachmentsRequestTypedDict",
    "GetAtsCandidatesGlobals",
    "GetAtsCandidatesGlobalsTypedDict",
    "GetAtsCandidatesPositiveResponse",
    "GetAtsCandidatesPositiveResponseApplication",
    "GetAtsCandidatesPositiveResponseApplicationTypedDict",
    "GetAtsCandidatesPositiveResponseCurrentStage",
    "GetAtsCandidatesPositiveResponseCurrentStageTypedDict",
    "GetAtsCandidatesPositiveResponseData",
    "GetAtsCandidatesPositiveResponseDataTypedDict",
    "GetAtsCandidatesPositiveResponseEmailAddress",
    "GetAtsCandidatesPositiveResponseEmailAddressTypedDict",
    "GetAtsCandidatesPositiveResponseJob",
    "GetAtsCandidatesPositiveResponseJobTypedDict",
    "GetAtsCandidatesPositiveResponseLocation",
    "GetAtsCandidatesPositiveResponseLocationTypedDict",
    "GetAtsCandidatesPositiveResponseOutcome",
    "GetAtsCandidatesPositiveResponsePhoneNumber",
    "GetAtsCandidatesPositiveResponsePhoneNumberTypedDict",
    "GetAtsCandidatesPositiveResponseResult",
    "GetAtsCandidatesPositiveResponseResultTypedDict",
    "GetAtsCandidatesPositiveResponseSocialMedia",
    "GetAtsCandidatesPositiveResponseSocialMediaTypedDict",
    "GetAtsCandidatesPositiveResponseTag",
    "GetAtsCandidatesPositiveResponseTagTypedDict",
    "GetAtsCandidatesPositiveResponseTypedDict",
    "GetAtsCandidatesRequest",
    "GetAtsCandidatesRequestTypedDict",
    "GetAtsCandidatesResponse",
    "GetAtsCandidatesResponseTypedDict",
    "GetAtsInterviewsGlobals",
    "GetAtsInterviewsGlobalsTypedDict",
    "GetAtsInterviewsPositiveResponse",
    "GetAtsInterviewsPositiveResponseApplication",
    "GetAtsInterviewsPositiveResponseApplicationTypedDict",
    "GetAtsInterviewsPositiveResponseCandidate",
    "GetAtsInterviewsPositiveResponseCandidateTypedDict",
    "GetAtsInterviewsPositiveResponseData",
    "GetAtsInterviewsPositiveResponseDataTypedDict",
    "GetAtsInterviewsPositiveResponseEmailAddress",
    "GetAtsInterviewsPositiveResponseEmailAddressTypedDict",
    "GetAtsInterviewsPositiveResponseJob",
    "GetAtsInterviewsPositiveResponseJobTypedDict",
    "GetAtsInterviewsPositiveResponseLocation",
    "GetAtsInterviewsPositiveResponseLocationTypedDict",
    "GetAtsInterviewsPositiveResponseOutcome",
    "GetAtsInterviewsPositiveResponseResult",
    "GetAtsInterviewsPositiveResponseResultTypedDict",
    "GetAtsInterviewsPositiveResponseTypedDict",
    "GetAtsInterviewsRequest",
    "GetAtsInterviewsRequestTypedDict",
    "GetAtsInterviewsResponse",
    "GetAtsInterviewsResponseTypedDict",
    "GetAtsJobsGlobals",
    "GetAtsJobsGlobalsTypedDict",
    "GetAtsJobsPositiveResponse",
    "GetAtsJobsPositiveResponseCategory",
    "GetAtsJobsPositiveResponseData",
    "GetAtsJobsPositiveResponseDataTypedDict",
    "GetAtsJobsPositiveResponseEmploymentType",
    "GetAtsJobsPositiveResponseHiringTeam",
    "GetAtsJobsPositiveResponseHiringTeamRole",
    "GetAtsJobsPositiveResponseHiringTeamTypedDict",
    "GetAtsJobsPositiveResponseLocation",
    "GetAtsJobsPositiveResponseLocationTypedDict",
    "GetAtsJobsPositiveResponseResult",
    "GetAtsJobsPositiveResponseResultTypedDict",
    "GetAtsJobsPositiveResponseStatus",
    "GetAtsJobsPositiveResponseTypedDict",
    "GetAtsJobsRequest",
    "GetAtsJobsRequestTypedDict",
    "GetAtsJobsResponse",
    "GetAtsJobsResponseTypedDict",
    "GetAtsOffersGlobals",
    "GetAtsOffersGlobalsTypedDict",
    "GetAtsOffersPositiveResponse",
    "GetAtsOffersPositiveResponseApplication",
    "GetAtsOffersPositiveResponseApplicationTypedDict",
    "GetAtsOffersPositiveResponseCandidate",
    "GetAtsOffersPositiveResponseCandidateTypedDict",
    "GetAtsOffersPositiveResponseData",
    "GetAtsOffersPositiveResponseDataTypedDict",
    "GetAtsOffersPositiveResponseEmailAddress",
    "GetAtsOffersPositiveResponseEmailAddressTypedDict",
    "GetAtsOffersPositiveResponseJob",
    "GetAtsOffersPositiveResponseJobTypedDict",
    "GetAtsOffersPositiveResponseResult",
    "GetAtsOffersPositiveResponseResultTypedDict",
    "GetAtsOffersPositiveResponseStatus",
    "GetAtsOffersPositiveResponseTypedDict",
    "GetAtsOffersRequest",
    "GetAtsOffersRequestTypedDict",
    "GetAtsOffersResponse",
    "GetAtsOffersResponseTypedDict",
    "GetAtsRejectionReasonsGlobals",
    "GetAtsRejectionReasonsGlobalsTypedDict",
    "GetAtsRejectionReasonsPositiveResponse",
    "GetAtsRejectionReasonsPositiveResponseData",
    "GetAtsRejectionReasonsPositiveResponseDataTypedDict",
    "GetAtsRejectionReasonsPositiveResponseResult",
    "GetAtsRejectionReasonsPositiveResponseResultTypedDict",
    "GetAtsRejectionReasonsPositiveResponseTypedDict",
    "GetAtsRejectionReasonsRequest",
    "GetAtsRejectionReasonsRequestTypedDict",
    "GetAtsRejectionReasonsResponse",
    "GetAtsRejectionReasonsResponseTypedDict",
    "GetAtsTagsGlobals",
    "GetAtsTagsGlobalsTypedDict",
    "GetAtsTagsPositiveResponse",
    "GetAtsTagsPositiveResponseData",
    "GetAtsTagsPositiveResponseDataTypedDict",
    "GetAtsTagsPositiveResponseResult",
    "GetAtsTagsPositiveResponseResultTypedDict",
    "GetAtsTagsPositiveResponseTypedDict",
    "GetAtsTagsRequest",
    "GetAtsTagsRequestTypedDict",
    "GetAtsTagsResponse",
    "GetAtsTagsResponseTypedDict",
    "GetAtsUsersGlobals",
    "GetAtsUsersGlobalsTypedDict",
    "GetAtsUsersPositiveResponse",
    "GetAtsUsersPositiveResponseData",
    "GetAtsUsersPositiveResponseDataTypedDict",
    "GetAtsUsersPositiveResponseResult",
    "GetAtsUsersPositiveResponseResultTypedDict",
    "GetAtsUsersPositiveResponseStatus",
    "GetAtsUsersPositiveResponseTypedDict",
    "GetAtsUsersRequest",
    "GetAtsUsersRequestTypedDict",
    "GetAtsUsersResponse",
    "GetAtsUsersResponseTypedDict",
    "GetCheckAPIKeyPositiveResponse",
    "GetCheckAPIKeyPositiveResponseData",
    "GetCheckAPIKeyPositiveResponseDataTypedDict",
    "GetCheckAPIKeyPositiveResponseTypedDict",
    "GetConnectIntegrationByTokenTokenPositiveResponse",
    "GetConnectIntegrationByTokenTokenPositiveResponseData",
    "GetConnectIntegrationByTokenTokenPositiveResponseDataTypedDict",
    "GetConnectIntegrationByTokenTokenPositiveResponseSetupStatus",
    "GetConnectIntegrationByTokenTokenPositiveResponseTypedDict",
    "GetConnectIntegrationByTokenTokenRequest",
    "GetConnectIntegrationByTokenTokenRequestTypedDict",
    "GetHrisAbsenceTypesGlobals",
    "GetHrisAbsenceTypesGlobalsTypedDict",
    "GetHrisAbsenceTypesPositiveResponse",
    "GetHrisAbsenceTypesPositiveResponseData",
    "GetHrisAbsenceTypesPositiveResponseDataTypedDict",
    "GetHrisAbsenceTypesPositiveResponseResult",
    "GetHrisAbsenceTypesPositiveResponseResultTypedDict",
    "GetHrisAbsenceTypesPositiveResponseTypedDict",
    "GetHrisAbsenceTypesPositiveResponseUnit",
    "GetHrisAbsenceTypesRequest",
    "GetHrisAbsenceTypesRequestTypedDict",
    "GetHrisAbsenceTypesResponse",
    "GetHrisAbsenceTypesResponseTypedDict",
    "GetHrisAbsencesGlobals",
    "GetHrisAbsencesGlobalsTypedDict",
    "GetHrisAbsencesPositiveResponse",
    "GetHrisAbsencesPositiveResponseData",
    "GetHrisAbsencesPositiveResponseDataTypedDict",
    "GetHrisAbsencesPositiveResponseResult",
    "GetHrisAbsencesPositiveResponseResultTypedDict",
    "GetHrisAbsencesPositiveResponseStatus",
    "GetHrisAbsencesPositiveResponseType",
    "GetHrisAbsencesPositiveResponseTypeTypedDict",
    "GetHrisAbsencesPositiveResponseTypeUnit",
    "GetHrisAbsencesPositiveResponseTypedDict",
    "GetHrisAbsencesPositiveResponseUnit",
    "GetHrisAbsencesRequest",
    "GetHrisAbsencesRequestTypedDict",
    "GetHrisAbsencesResponse",
    "GetHrisAbsencesResponseTypedDict",
    "GetHrisEmployeeDocumentCategoriesGlobals",
    "GetHrisEmployeeDocumentCategoriesGlobalsTypedDict",
    "GetHrisEmployeeDocumentCategoriesPositiveResponse",
    "GetHrisEmployeeDocumentCategoriesPositiveResponseData",
    "GetHrisEmployeeDocumentCategoriesPositiveResponseDataTypedDict",
    "GetHrisEmployeeDocumentCategoriesPositiveResponseResult",
    "GetHrisEmployeeDocumentCategoriesPositiveResponseResultTypedDict",
    "GetHrisEmployeeDocumentCategoriesPositiveResponseTypedDict",
    "GetHrisEmployeeDocumentCategoriesRequest",
    "GetHrisEmployeeDocumentCategoriesRequestTypedDict",
    "GetHrisEmployeeDocumentCategoriesResponse",
    "GetHrisEmployeeDocumentCategoriesResponseTypedDict",
    "GetHrisEmployeesFormGlobals",
    "GetHrisEmployeesFormGlobalsTypedDict",
    "GetHrisEmployeesFormPositiveResponse",
    "GetHrisEmployeesFormPositiveResponseData",
    "GetHrisEmployeesFormPositiveResponseDataTypedDict",
    "GetHrisEmployeesFormPositiveResponseEntry1",
    "GetHrisEmployeesFormPositiveResponseEntry1TypedDict",
    "GetHrisEmployeesFormPositiveResponseEntry2",
    "GetHrisEmployeesFormPositiveResponseEntry2TypedDict",
    "GetHrisEmployeesFormPositiveResponseFileRestrictions",
    "GetHrisEmployeesFormPositiveResponseFileRestrictionsTypedDict",
    "GetHrisEmployeesFormPositiveResponseOptionsInline1",
    "GetHrisEmployeesFormPositiveResponseOptionsInline1TypedDict",
    "GetHrisEmployeesFormPositiveResponseOptionsInline2",
    "GetHrisEmployeesFormPositiveResponseOptionsInline2TypedDict",
    "GetHrisEmployeesFormPositiveResponseOptionsReferenced1",
    "GetHrisEmployeesFormPositiveResponseOptionsReferenced1TypedDict",
    "GetHrisEmployeesFormPositiveResponseOptionsReferenced2",
    "GetHrisEmployeesFormPositiveResponseOptionsReferenced2TypedDict",
    "GetHrisEmployeesFormPositiveResponseOptionsUnion1",
    "GetHrisEmployeesFormPositiveResponseOptionsUnion1TypedDict",
    "GetHrisEmployeesFormPositiveResponseOptionsUnion2",
    "GetHrisEmployeesFormPositiveResponseOptionsUnion2TypedDict",
    "GetHrisEmployeesFormPositiveResponseRemoteID1",
    "GetHrisEmployeesFormPositiveResponseRemoteID1TypedDict",
    "GetHrisEmployeesFormPositiveResponseRemoteID2",
    "GetHrisEmployeesFormPositiveResponseRemoteID2TypedDict",
    "GetHrisEmployeesFormPositiveResponseTypedDict",
    "GetHrisEmployeesFormPositiveResponseUnifiedKey1",
    "GetHrisEmployeesFormPositiveResponseUnifiedKey2",
    "GetHrisEmployeesFormPositiveResponseUnifiedKey3",
    "GetHrisEmployeesFormPositiveResponseUnifiedKey4",
    "GetHrisEmployeesFormPositiveResponseUnifiedKey5",
    "GetHrisEmployeesFormPositiveResponseUnifiedKey6",
    "GetHrisEmployeesFormPositiveResponseUnifiedKey7",
    "GetHrisEmployeesFormPositiveResponseUnifiedKey8",
    "GetHrisEmployeesFormPositiveResponseWarning",
    "GetHrisEmployeesFormPositiveResponseWarningTypedDict",
    "GetHrisEmployeesFormRequest",
    "GetHrisEmployeesFormRequestTypedDict",
    "GetHrisEmployeesGlobals",
    "GetHrisEmployeesGlobalsTypedDict",
    "GetHrisEmployeesPositiveResponse",
    "GetHrisEmployeesPositiveResponseBalanceUnit",
    "GetHrisEmployeesPositiveResponseData",
    "GetHrisEmployeesPositiveResponseDataTypedDict",
    "GetHrisEmployeesPositiveResponseEmploymentType",
    "GetHrisEmployeesPositiveResponseGender",
    "GetHrisEmployeesPositiveResponsePayFrequency",
    "GetHrisEmployeesPositiveResponsePayPeriod",
    "GetHrisEmployeesPositiveResponseResult",
    "GetHrisEmployeesPositiveResponseResultTypedDict",
    "GetHrisEmployeesPositiveResponseTypedDict",
    "GetHrisEmployeesPositiveResponseUsedUnit",
    "GetHrisEmployeesRequest",
    "GetHrisEmployeesRequestTypedDict",
    "GetHrisEmployeesResponse",
    "GetHrisEmployeesResponseTypedDict",
    "GetHrisEmploymentsGlobals",
    "GetHrisEmploymentsGlobalsTypedDict",
    "GetHrisEmploymentsPositiveResponse",
    "GetHrisEmploymentsPositiveResponseData",
    "GetHrisEmploymentsPositiveResponseDataTypedDict",
    "GetHrisEmploymentsPositiveResponseEmploymentType",
    "GetHrisEmploymentsPositiveResponsePayFrequency",
    "GetHrisEmploymentsPositiveResponsePayPeriod",
    "GetHrisEmploymentsPositiveResponseResult",
    "GetHrisEmploymentsPositiveResponseResultTypedDict",
    "GetHrisEmploymentsPositiveResponseTypedDict",
    "GetHrisEmploymentsRequest",
    "GetHrisEmploymentsRequestTypedDict",
    "GetHrisEmploymentsResponse",
    "GetHrisEmploymentsResponseTypedDict",
    "GetHrisGroupsGlobals",
    "GetHrisGroupsGlobalsTypedDict",
    "GetHrisGroupsPositiveResponse",
    "GetHrisGroupsPositiveResponseData",
    "GetHrisGroupsPositiveResponseDataTypedDict",
    "GetHrisGroupsPositiveResponseResult",
    "GetHrisGroupsPositiveResponseResultTypedDict",
    "GetHrisGroupsPositiveResponseType",
    "GetHrisGroupsPositiveResponseTypedDict",
    "GetHrisGroupsRequest",
    "GetHrisGroupsRequestTypedDict",
    "GetHrisGroupsResponse",
    "GetHrisGroupsResponseTypedDict",
    "GetHrisLegalEntitiesGlobals",
    "GetHrisLegalEntitiesGlobalsTypedDict",
    "GetHrisLegalEntitiesPositiveResponse",
    "GetHrisLegalEntitiesPositiveResponseAddress",
    "GetHrisLegalEntitiesPositiveResponseAddressTypedDict",
    "GetHrisLegalEntitiesPositiveResponseData",
    "GetHrisLegalEntitiesPositiveResponseDataTypedDict",
    "GetHrisLegalEntitiesPositiveResponseResult",
    "GetHrisLegalEntitiesPositiveResponseResultTypedDict",
    "GetHrisLegalEntitiesPositiveResponseTypedDict",
    "GetHrisLegalEntitiesRequest",
    "GetHrisLegalEntitiesRequestTypedDict",
    "GetHrisLegalEntitiesResponse",
    "GetHrisLegalEntitiesResponseTypedDict",
    "GetHrisLocationsGlobals",
    "GetHrisLocationsGlobalsTypedDict",
    "GetHrisLocationsPositiveResponse",
    "GetHrisLocationsPositiveResponseAddress",
    "GetHrisLocationsPositiveResponseAddressTypedDict",
    "GetHrisLocationsPositiveResponseData",
    "GetHrisLocationsPositiveResponseDataTypedDict",
    "GetHrisLocationsPositiveResponseResult",
    "GetHrisLocationsPositiveResponseResultTypedDict",
    "GetHrisLocationsPositiveResponseTypedDict",
    "GetHrisLocationsRequest",
    "GetHrisLocationsRequestTypedDict",
    "GetHrisLocationsResponse",
    "GetHrisLocationsResponseTypedDict",
    "GetHrisPerformanceReviewCyclesGlobals",
    "GetHrisPerformanceReviewCyclesGlobalsTypedDict",
    "GetHrisPerformanceReviewCyclesPositiveResponse",
    "GetHrisPerformanceReviewCyclesPositiveResponseData",
    "GetHrisPerformanceReviewCyclesPositiveResponseDataTypedDict",
    "GetHrisPerformanceReviewCyclesPositiveResponseResult",
    "GetHrisPerformanceReviewCyclesPositiveResponseResultTypedDict",
    "GetHrisPerformanceReviewCyclesPositiveResponseTypedDict",
    "GetHrisPerformanceReviewCyclesRequest",
    "GetHrisPerformanceReviewCyclesRequestTypedDict",
    "GetHrisPerformanceReviewCyclesResponse",
    "GetHrisPerformanceReviewCyclesResponseTypedDict",
    "GetHrisPerformanceReviewsGlobals",
    "GetHrisPerformanceReviewsGlobalsTypedDict",
    "GetHrisPerformanceReviewsPositiveResponse",
    "GetHrisPerformanceReviewsPositiveResponseData",
    "GetHrisPerformanceReviewsPositiveResponseDataTypedDict",
    "GetHrisPerformanceReviewsPositiveResponseResult",
    "GetHrisPerformanceReviewsPositiveResponseResultTypedDict",
    "GetHrisPerformanceReviewsPositiveResponseType",
    "GetHrisPerformanceReviewsPositiveResponseTypedDict",
    "GetHrisPerformanceReviewsRequest",
    "GetHrisPerformanceReviewsRequestTypedDict",
    "GetHrisPerformanceReviewsResponse",
    "GetHrisPerformanceReviewsResponseTypedDict",
    "GetHrisTimeOffBalancesGlobals",
    "GetHrisTimeOffBalancesGlobalsTypedDict",
    "GetHrisTimeOffBalancesPositiveResponse",
    "GetHrisTimeOffBalancesPositiveResponseBalanceUnit",
    "GetHrisTimeOffBalancesPositiveResponseData",
    "GetHrisTimeOffBalancesPositiveResponseDataTypedDict",
    "GetHrisTimeOffBalancesPositiveResponseResult",
    "GetHrisTimeOffBalancesPositiveResponseResultTypedDict",
    "GetHrisTimeOffBalancesPositiveResponseType",
    "GetHrisTimeOffBalancesPositiveResponseTypeTypedDict",
    "GetHrisTimeOffBalancesPositiveResponseTypedDict",
    "GetHrisTimeOffBalancesPositiveResponseUnit",
    "GetHrisTimeOffBalancesPositiveResponseUsedUnit",
    "GetHrisTimeOffBalancesRequest",
    "GetHrisTimeOffBalancesRequestTypedDict",
    "GetHrisTimeOffBalancesResponse",
    "GetHrisTimeOffBalancesResponseTypedDict",
    "GetHrisTimesheetsGlobals",
    "GetHrisTimesheetsGlobalsTypedDict",
    "GetHrisTimesheetsPositiveResponse",
    "GetHrisTimesheetsPositiveResponseData",
    "GetHrisTimesheetsPositiveResponseDataTypedDict",
    "GetHrisTimesheetsPositiveResponseResult",
    "GetHrisTimesheetsPositiveResponseResultTypedDict",
    "GetHrisTimesheetsPositiveResponseTypedDict",
    "GetHrisTimesheetsRequest",
    "GetHrisTimesheetsRequestTypedDict",
    "GetHrisTimesheetsResponse",
    "GetHrisTimesheetsResponseTypedDict",
    "GetIntegrationsIntegrationIDCustomFieldsPositiveResponse",
    "GetIntegrationsIntegrationIDCustomFieldsPositiveResponseData",
    "GetIntegrationsIntegrationIDCustomFieldsPositiveResponseDataTypedDict",
    "GetIntegrationsIntegrationIDCustomFieldsPositiveResponseIntegrationField",
    "GetIntegrationsIntegrationIDCustomFieldsPositiveResponseIntegrationFieldTypedDict",
    "GetIntegrationsIntegrationIDCustomFieldsPositiveResponseResult",
    "GetIntegrationsIntegrationIDCustomFieldsPositiveResponseResultTypedDict",
    "GetIntegrationsIntegrationIDCustomFieldsPositiveResponseType",
    "GetIntegrationsIntegrationIDCustomFieldsPositiveResponseTypedDict",
    "GetIntegrationsIntegrationIDCustomFieldsRequest",
    "GetIntegrationsIntegrationIDCustomFieldsRequestTypedDict",
    "GetIntegrationsIntegrationIDCustomFieldsResponse",
    "GetIntegrationsIntegrationIDCustomFieldsResponseTypedDict",
    "GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponse",
    "GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseData",
    "GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseDataTypedDict",
    "GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseResult",
    "GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseResultTypedDict",
    "GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseType",
    "GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseTypedDict",
    "GetIntegrationsIntegrationIDIntegrationFieldsRequest",
    "GetIntegrationsIntegrationIDIntegrationFieldsRequestTypedDict",
    "GetIntegrationsIntegrationIDIntegrationFieldsResponse",
    "GetIntegrationsIntegrationIDIntegrationFieldsResponseTypedDict",
    "GetIntegrationsIntegrationIDPositiveResponse",
    "GetIntegrationsIntegrationIDPositiveResponseCategory",
    "GetIntegrationsIntegrationIDPositiveResponseCoverageStatus",
    "GetIntegrationsIntegrationIDPositiveResponseData",
    "GetIntegrationsIntegrationIDPositiveResponseDataTypedDict",
    "GetIntegrationsIntegrationIDPositiveResponseEndUser",
    "GetIntegrationsIntegrationIDPositiveResponseEndUserTypedDict",
    "GetIntegrationsIntegrationIDPositiveResponseField",
    "GetIntegrationsIntegrationIDPositiveResponseFieldCoverageStatus",
    "GetIntegrationsIntegrationIDPositiveResponseFieldTypedDict",
    "GetIntegrationsIntegrationIDPositiveResponseReadModel",
    "GetIntegrationsIntegrationIDPositiveResponseReadModelTypedDict",
    "GetIntegrationsIntegrationIDPositiveResponseSetupStatus",
    "GetIntegrationsIntegrationIDPositiveResponseStatus",
    "GetIntegrationsIntegrationIDPositiveResponseTool",
    "GetIntegrationsIntegrationIDPositiveResponseToolTypedDict",
    "GetIntegrationsIntegrationIDPositiveResponseTypedDict",
    "GetIntegrationsIntegrationIDRequest",
    "GetIntegrationsIntegrationIDRequestTypedDict",
    "GetToolsCategoryParameterCategory",
    "GetToolsCategoryPositiveResponse",
    "GetToolsCategoryPositiveResponseData",
    "GetToolsCategoryPositiveResponseDataTypedDict",
    "GetToolsCategoryPositiveResponseField",
    "GetToolsCategoryPositiveResponseFieldCoverageStatus",
    "GetToolsCategoryPositiveResponseFieldTypedDict",
    "GetToolsCategoryPositiveResponseReadModel",
    "GetToolsCategoryPositiveResponseReadModelCoverageStatus",
    "GetToolsCategoryPositiveResponseReadModelTypedDict",
    "GetToolsCategoryPositiveResponseTool",
    "GetToolsCategoryPositiveResponseToolTypedDict",
    "GetToolsCategoryPositiveResponseTypedDict",
    "GetToolsCategoryRequest",
    "GetToolsCategoryRequestTypedDict",
    "Group",
    "GroupType",
    "GroupTypedDict",
    "Headers",
    "HeadersTypedDict",
    "HomeAddress",
    "HomeAddressTypedDict",
    "ImportedID",
    "ImportedIDTypedDict",
    "InlineAssessmentOrderReceivedWebhookPayload",
    "InlineAssessmentOrderReceivedWebhookPayloadApplication",
    "InlineAssessmentOrderReceivedWebhookPayloadApplicationTypedDict",
    "InlineAssessmentOrderReceivedWebhookPayloadCandidate",
    "InlineAssessmentOrderReceivedWebhookPayloadCandidateTypedDict",
    "InlineAssessmentOrderReceivedWebhookPayloadData",
    "InlineAssessmentOrderReceivedWebhookPayloadDataTypedDict",
    "InlineAssessmentOrderReceivedWebhookPayloadHiringTeam",
    "InlineAssessmentOrderReceivedWebhookPayloadHiringTeamRole",
    "InlineAssessmentOrderReceivedWebhookPayloadHiringTeamTypedDict",
    "InlineAssessmentOrderReceivedWebhookPayloadJob",
    "InlineAssessmentOrderReceivedWebhookPayloadJobTypedDict",
    "InlineAssessmentOrderReceivedWebhookPayloadLocation",
    "InlineAssessmentOrderReceivedWebhookPayloadLocationTypedDict",
    "InlineAssessmentOrderReceivedWebhookPayloadStatus",
    "InlineAssessmentOrderReceivedWebhookPayloadType",
    "InlineAssessmentOrderReceivedWebhookPayloadTypedDict",
    "IntegrationCreatedWebhookPayload",
    "IntegrationCreatedWebhookPayloadCategory",
    "IntegrationCreatedWebhookPayloadData",
    "IntegrationCreatedWebhookPayloadDataTypedDict",
    "IntegrationCreatedWebhookPayloadEndUser",
    "IntegrationCreatedWebhookPayloadEndUserTypedDict",
    "IntegrationCreatedWebhookPayloadType",
    "IntegrationCreatedWebhookPayloadTypedDict",
    "IntegrationDeletedWebhookPayload",
    "IntegrationDeletedWebhookPayloadCategory",
    "IntegrationDeletedWebhookPayloadData",
    "IntegrationDeletedWebhookPayloadDataTypedDict",
    "IntegrationDeletedWebhookPayloadEndUser",
    "IntegrationDeletedWebhookPayloadEndUserTypedDict",
    "IntegrationDeletedWebhookPayloadType",
    "IntegrationDeletedWebhookPayloadTypedDict",
    "IntegrationStateChangedWebhookPayload",
    "IntegrationStateChangedWebhookPayloadData",
    "IntegrationStateChangedWebhookPayloadDataTypedDict",
    "IntegrationStateChangedWebhookPayloadEndUser",
    "IntegrationStateChangedWebhookPayloadEndUserTypedDict",
    "IntegrationStateChangedWebhookPayloadIntegrationCategory",
    "IntegrationStateChangedWebhookPayloadType",
    "IntegrationStateChangedWebhookPayloadTypedDict",
    "IntegrationTool",
    "Interview",
    "InterviewTypedDict",
    "JobPosting",
    "JobPostingStatus",
    "JobPostingTypedDict",
    "JobPostingVisibility",
    "KomboAtsErrorCode",
    "KomboAtsErrorError",
    "KomboAtsErrorErrorTypedDict",
    "KomboAtsErrorStatus",
    "KomboGeneralErrorCode",
    "KomboGeneralErrorError",
    "KomboGeneralErrorErrorTypedDict",
    "KomboGeneralErrorStatus",
    "KomboHrisErrorCode",
    "KomboHrisErrorError",
    "KomboHrisErrorErrorTypedDict",
    "KomboHrisErrorStatus",
    "LegalEntity",
    "LegalEntityAddress",
    "LegalEntityAddressTypedDict",
    "LegalEntityTypedDict",
    "Manager",
    "ManagerEmploymentStatus",
    "ManagerTypedDict",
    "MaritalStatus",
    "Method",
    "MultipartFormDatum",
    "MultipartFormDatumTypedDict",
    "Name",
    "Offer",
    "OfferTypedDict",
    "Option1",
    "Option1TypedDict",
    "Option2",
    "Option2TypedDict",
    "PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDPositiveResponse",
    "PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDPositiveResponseData",
    "PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDPositiveResponseDataTypedDict",
    "PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDPositiveResponseType",
    "PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDPositiveResponseTypedDict",
    "PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDRequest",
    "PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDRequestBody",
    "PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDRequestBodyTypedDict",
    "PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDRequestTypedDict",
    "PostAtsApplicationsApplicationIDAttachmentsGlobals",
    "PostAtsApplicationsApplicationIDAttachmentsGlobalsTypedDict",
    "PostAtsApplicationsApplicationIDAttachmentsPositiveResponse",
    "PostAtsApplicationsApplicationIDAttachmentsPositiveResponseData",
    "PostAtsApplicationsApplicationIDAttachmentsPositiveResponseDataTypedDict",
    "PostAtsApplicationsApplicationIDAttachmentsPositiveResponseTypedDict",
    "PostAtsApplicationsApplicationIDAttachmentsPositiveResponseWarning",
    "PostAtsApplicationsApplicationIDAttachmentsPositiveResponseWarningTypedDict",
    "PostAtsApplicationsApplicationIDAttachmentsRequest",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBody",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyAttachment",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyAttachmentTypedDict",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyGreenhouse",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyGreenhouseTypedDict",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyOracle",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyOracleTypedDict",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyOverrideDocumentCategory",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyPostHeaders",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyPostHeadersTypedDict",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyRemoteFields",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyRemoteFieldsTypedDict",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyType",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyTypedDict",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyWorkable",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyWorkableTypedDict",
    "PostAtsApplicationsApplicationIDAttachmentsRequestTypedDict",
    "PostAtsApplicationsApplicationIDNotesGlobals",
    "PostAtsApplicationsApplicationIDNotesGlobalsTypedDict",
    "PostAtsApplicationsApplicationIDNotesPositiveResponse",
    "PostAtsApplicationsApplicationIDNotesPositiveResponseData",
    "PostAtsApplicationsApplicationIDNotesPositiveResponseDataTypedDict",
    "PostAtsApplicationsApplicationIDNotesPositiveResponseTypedDict",
    "PostAtsApplicationsApplicationIDNotesPositiveResponseWarning",
    "PostAtsApplicationsApplicationIDNotesPositiveResponseWarningTypedDict",
    "PostAtsApplicationsApplicationIDNotesRequest",
    "PostAtsApplicationsApplicationIDNotesRequestBody",
    "PostAtsApplicationsApplicationIDNotesRequestBodyBullhorn",
    "PostAtsApplicationsApplicationIDNotesRequestBodyBullhornTypedDict",
    "PostAtsApplicationsApplicationIDNotesRequestBodyGreenhouse",
    "PostAtsApplicationsApplicationIDNotesRequestBodyGreenhouseTypedDict",
    "PostAtsApplicationsApplicationIDNotesRequestBodyPostHeaders",
    "PostAtsApplicationsApplicationIDNotesRequestBodyPostHeadersTypedDict",
    "PostAtsApplicationsApplicationIDNotesRequestBodyRecruitee",
    "PostAtsApplicationsApplicationIDNotesRequestBodyRecruiteeTypedDict",
    "PostAtsApplicationsApplicationIDNotesRequestBodyRemoteFields",
    "PostAtsApplicationsApplicationIDNotesRequestBodyRemoteFieldsTypedDict",
    "PostAtsApplicationsApplicationIDNotesRequestBodyTeamtailor",
    "PostAtsApplicationsApplicationIDNotesRequestBodyTeamtailorTypedDict",
    "PostAtsApplicationsApplicationIDNotesRequestBodyTypedDict",
    "PostAtsApplicationsApplicationIDNotesRequestBodyWorkable",
    "PostAtsApplicationsApplicationIDNotesRequestBodyWorkableTypedDict",
    "PostAtsApplicationsApplicationIDNotesRequestTypedDict",
    "PostAtsApplicationsApplicationIDRejectGlobals",
    "PostAtsApplicationsApplicationIDRejectGlobalsTypedDict",
    "PostAtsApplicationsApplicationIDRejectPositiveResponse",
    "PostAtsApplicationsApplicationIDRejectPositiveResponseData",
    "PostAtsApplicationsApplicationIDRejectPositiveResponseDataTypedDict",
    "PostAtsApplicationsApplicationIDRejectPositiveResponseTypedDict",
    "PostAtsApplicationsApplicationIDRejectPositiveResponseWarning",
    "PostAtsApplicationsApplicationIDRejectPositiveResponseWarningTypedDict",
    "PostAtsApplicationsApplicationIDRejectRequest",
    "PostAtsApplicationsApplicationIDRejectRequestBody",
    "PostAtsApplicationsApplicationIDRejectRequestBodyGreenhouse",
    "PostAtsApplicationsApplicationIDRejectRequestBodyGreenhouseTypedDict",
    "PostAtsApplicationsApplicationIDRejectRequestBodyPostHeaders",
    "PostAtsApplicationsApplicationIDRejectRequestBodyPostHeadersTypedDict",
    "PostAtsApplicationsApplicationIDRejectRequestBodyRemoteFields",
    "PostAtsApplicationsApplicationIDRejectRequestBodyRemoteFieldsTypedDict",
    "PostAtsApplicationsApplicationIDRejectRequestBodyTypedDict",
    "PostAtsApplicationsApplicationIDRejectRequestBodyWorkable",
    "PostAtsApplicationsApplicationIDRejectRequestBodyWorkableTypedDict",
    "PostAtsApplicationsApplicationIDRejectRequestTypedDict",
    "PostAtsApplicationsApplicationIDResultLinksGlobals",
    "PostAtsApplicationsApplicationIDResultLinksGlobalsTypedDict",
    "PostAtsApplicationsApplicationIDResultLinksPositiveResponse",
    "PostAtsApplicationsApplicationIDResultLinksPositiveResponseData",
    "PostAtsApplicationsApplicationIDResultLinksPositiveResponseDataTypedDict",
    "PostAtsApplicationsApplicationIDResultLinksPositiveResponseTypedDict",
    "PostAtsApplicationsApplicationIDResultLinksPositiveResponseWarning",
    "PostAtsApplicationsApplicationIDResultLinksPositiveResponseWarningTypedDict",
    "PostAtsApplicationsApplicationIDResultLinksRequest",
    "PostAtsApplicationsApplicationIDResultLinksRequestBody",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyAttribute",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyAttributeTypedDict",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyDetails",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyDetailsTypedDict",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyGreenhouse",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyGreenhouseTypedDict",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyIcims",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyIcimsTypedDict",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyOracle",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyOracleTypedDict",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyOverrideDocumentCategory",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyPostHeaders",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyPostHeadersTypedDict",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyRemoteFields",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyRemoteFieldsTypedDict",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyTypedDict",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyWorkable",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyWorkableTypedDict",
    "PostAtsApplicationsApplicationIDResultLinksRequestTypedDict",
    "PostAtsCandidatesCandidateIDAttachmentsGlobals",
    "PostAtsCandidatesCandidateIDAttachmentsGlobalsTypedDict",
    "PostAtsCandidatesCandidateIDAttachmentsPositiveResponse",
    "PostAtsCandidatesCandidateIDAttachmentsPositiveResponseData",
    "PostAtsCandidatesCandidateIDAttachmentsPositiveResponseDataTypedDict",
    "PostAtsCandidatesCandidateIDAttachmentsPositiveResponseTypedDict",
    "PostAtsCandidatesCandidateIDAttachmentsPositiveResponseWarning",
    "PostAtsCandidatesCandidateIDAttachmentsPositiveResponseWarningTypedDict",
    "PostAtsCandidatesCandidateIDAttachmentsRequest",
    "PostAtsCandidatesCandidateIDAttachmentsRequestBody",
    "PostAtsCandidatesCandidateIDAttachmentsRequestBodyAttachment",
    "PostAtsCandidatesCandidateIDAttachmentsRequestBodyAttachmentTypedDict",
    "PostAtsCandidatesCandidateIDAttachmentsRequestBodyGreenhouse",
    "PostAtsCandidatesCandidateIDAttachmentsRequestBodyGreenhouseTypedDict",
    "PostAtsCandidatesCandidateIDAttachmentsRequestBodyPostHeaders",
    "PostAtsCandidatesCandidateIDAttachmentsRequestBodyPostHeadersTypedDict",
    "PostAtsCandidatesCandidateIDAttachmentsRequestBodyRemoteFields",
    "PostAtsCandidatesCandidateIDAttachmentsRequestBodyRemoteFieldsTypedDict",
    "PostAtsCandidatesCandidateIDAttachmentsRequestBodyType",
    "PostAtsCandidatesCandidateIDAttachmentsRequestBodyTypedDict",
    "PostAtsCandidatesCandidateIDAttachmentsRequestBodyWorkable",
    "PostAtsCandidatesCandidateIDAttachmentsRequestBodyWorkableTypedDict",
    "PostAtsCandidatesCandidateIDAttachmentsRequestTypedDict",
    "PostAtsCandidatesCandidateIDResultLinksGlobals",
    "PostAtsCandidatesCandidateIDResultLinksGlobalsTypedDict",
    "PostAtsCandidatesCandidateIDResultLinksPositiveResponse",
    "PostAtsCandidatesCandidateIDResultLinksPositiveResponseData",
    "PostAtsCandidatesCandidateIDResultLinksPositiveResponseDataTypedDict",
    "PostAtsCandidatesCandidateIDResultLinksPositiveResponseTypedDict",
    "PostAtsCandidatesCandidateIDResultLinksPositiveResponseWarning",
    "PostAtsCandidatesCandidateIDResultLinksPositiveResponseWarningTypedDict",
    "PostAtsCandidatesCandidateIDResultLinksRequest",
    "PostAtsCandidatesCandidateIDResultLinksRequestBody",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyAttribute",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyAttributeTypedDict",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyDetails",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyDetailsTypedDict",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyGreenhouse",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyGreenhouseTypedDict",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyIcims",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyIcimsTypedDict",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyOracle",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyOracleTypedDict",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyOverrideDocumentCategory",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyPostHeaders",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyPostHeadersTypedDict",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyRemoteFields",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyRemoteFieldsTypedDict",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyTypedDict",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyWorkable",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyWorkableTypedDict",
    "PostAtsCandidatesCandidateIDResultLinksRequestTypedDict",
    "PostAtsCandidatesCandidateIDTagsGlobals",
    "PostAtsCandidatesCandidateIDTagsGlobalsTypedDict",
    "PostAtsCandidatesCandidateIDTagsPositiveResponse",
    "PostAtsCandidatesCandidateIDTagsPositiveResponseData",
    "PostAtsCandidatesCandidateIDTagsPositiveResponseDataTypedDict",
    "PostAtsCandidatesCandidateIDTagsPositiveResponseTypedDict",
    "PostAtsCandidatesCandidateIDTagsPositiveResponseWarning",
    "PostAtsCandidatesCandidateIDTagsPositiveResponseWarningTypedDict",
    "PostAtsCandidatesCandidateIDTagsRequest",
    "PostAtsCandidatesCandidateIDTagsRequestBody",
    "PostAtsCandidatesCandidateIDTagsRequestBodyGreenhouse",
    "PostAtsCandidatesCandidateIDTagsRequestBodyGreenhouseTypedDict",
    "PostAtsCandidatesCandidateIDTagsRequestBodyPostHeaders",
    "PostAtsCandidatesCandidateIDTagsRequestBodyPostHeadersTypedDict",
    "PostAtsCandidatesCandidateIDTagsRequestBodyRemoteFields",
    "PostAtsCandidatesCandidateIDTagsRequestBodyRemoteFieldsTypedDict",
    "PostAtsCandidatesCandidateIDTagsRequestBodyTag",
    "PostAtsCandidatesCandidateIDTagsRequestBodyTagTypedDict",
    "PostAtsCandidatesCandidateIDTagsRequestBodyTypedDict",
    "PostAtsCandidatesCandidateIDTagsRequestBodyWorkable",
    "PostAtsCandidatesCandidateIDTagsRequestBodyWorkableTypedDict",
    "PostAtsCandidatesCandidateIDTagsRequestTypedDict",
    "PostAtsCandidatesGlobals",
    "PostAtsCandidatesGlobalsTypedDict",
    "PostAtsCandidatesPositiveResponse",
    "PostAtsCandidatesPositiveResponseApplication",
    "PostAtsCandidatesPositiveResponseApplicationTypedDict",
    "PostAtsCandidatesPositiveResponseCurrentStage",
    "PostAtsCandidatesPositiveResponseCurrentStageTypedDict",
    "PostAtsCandidatesPositiveResponseData",
    "PostAtsCandidatesPositiveResponseDataTypedDict",
    "PostAtsCandidatesPositiveResponseEmailAddress",
    "PostAtsCandidatesPositiveResponseEmailAddressTypedDict",
    "PostAtsCandidatesPositiveResponseJob",
    "PostAtsCandidatesPositiveResponseJobTypedDict",
    "PostAtsCandidatesPositiveResponseLocation",
    "PostAtsCandidatesPositiveResponseLocationTypedDict",
    "PostAtsCandidatesPositiveResponseOutcome",
    "PostAtsCandidatesPositiveResponsePhoneNumber",
    "PostAtsCandidatesPositiveResponsePhoneNumberTypedDict",
    "PostAtsCandidatesPositiveResponseSocialMedia",
    "PostAtsCandidatesPositiveResponseSocialMediaTypedDict",
    "PostAtsCandidatesPositiveResponseTag",
    "PostAtsCandidatesPositiveResponseTagTypedDict",
    "PostAtsCandidatesPositiveResponseTypedDict",
    "PostAtsCandidatesPositiveResponseWarning",
    "PostAtsCandidatesPositiveResponseWarningTypedDict",
    "PostAtsCandidatesRequestBody",
    "PostAtsCandidatesRequestBodyAdditionalEmailAddress",
    "PostAtsCandidatesRequestBodyAdditionalEmailAddressType",
    "PostAtsCandidatesRequestBodyAdditionalEmailAddressTypedDict",
    "PostAtsCandidatesRequestBodyAdditionalPhoneNumber",
    "PostAtsCandidatesRequestBodyAdditionalPhoneNumberType",
    "PostAtsCandidatesRequestBodyAdditionalPhoneNumberTypedDict",
    "PostAtsCandidatesRequestBodyAnswer",
    "PostAtsCandidatesRequestBodyAnswerTypedDict",
    "PostAtsCandidatesRequestBodyAnswerUnion",
    "PostAtsCandidatesRequestBodyAnswerUnionTypedDict",
    "PostAtsCandidatesRequestBodyApplication",
    "PostAtsCandidatesRequestBodyApplicationTypedDict",
    "PostAtsCandidatesRequestBodyAttachment",
    "PostAtsCandidatesRequestBodyAttachmentType",
    "PostAtsCandidatesRequestBodyAttachmentTypedDict",
    "PostAtsCandidatesRequestBodyAvature",
    "PostAtsCandidatesRequestBodyAvatureTypedDict",
    "PostAtsCandidatesRequestBodyBullhorn",
    "PostAtsCandidatesRequestBodyBullhornTypedDict",
    "PostAtsCandidatesRequestBodyCandidate",
    "PostAtsCandidatesRequestBodyCandidateData",
    "PostAtsCandidatesRequestBodyCandidateDataTypedDict",
    "PostAtsCandidatesRequestBodyCandidateTypedDict",
    "PostAtsCandidatesRequestBodyContactData",
    "PostAtsCandidatesRequestBodyContactDataTypedDict",
    "PostAtsCandidatesRequestBodyCountryCityReference",
    "PostAtsCandidatesRequestBodyCountryCityReferenceTypedDict",
    "PostAtsCandidatesRequestBodyCountryRegionReference",
    "PostAtsCandidatesRequestBodyCountryRegionReferenceTypedDict",
    "PostAtsCandidatesRequestBodyDegreeReference",
    "PostAtsCandidatesRequestBodyDegreeReferenceTypedDict",
    "PostAtsCandidatesRequestBodyDvinci",
    "PostAtsCandidatesRequestBodyDvinciTypedDict",
    "PostAtsCandidatesRequestBodyEducationDatum",
    "PostAtsCandidatesRequestBodyEducationDatumTypedDict",
    "PostAtsCandidatesRequestBodyExperienceDatum",
    "PostAtsCandidatesRequestBodyExperienceDatumTypedDict",
    "PostAtsCandidatesRequestBodyFieldOfStudyReference",
    "PostAtsCandidatesRequestBodyFieldOfStudyReferenceTypedDict",
    "PostAtsCandidatesRequestBodyGdprConsent",
    "PostAtsCandidatesRequestBodyGdprConsentTypedDict",
    "PostAtsCandidatesRequestBodyGender",
    "PostAtsCandidatesRequestBodyGlobalPersonalInformationData",
    "PostAtsCandidatesRequestBodyGlobalPersonalInformationDataTypedDict",
    "PostAtsCandidatesRequestBodyGreenhouse",
    "PostAtsCandidatesRequestBodyGreenhouseTypedDict",
    "PostAtsCandidatesRequestBodyGuidecom",
    "PostAtsCandidatesRequestBodyGuidecomTypedDict",
    "PostAtsCandidatesRequestBodyHrworks",
    "PostAtsCandidatesRequestBodyHrworksTypedDict",
    "PostAtsCandidatesRequestBodyJobApplicationData",
    "PostAtsCandidatesRequestBodyJobApplicationDataTypedDict",
    "PostAtsCandidatesRequestBodyJobAppliedToData",
    "PostAtsCandidatesRequestBodyJobAppliedToDataTypedDict",
    "PostAtsCandidatesRequestBodyJobylon",
    "PostAtsCandidatesRequestBodyJobylonApplication",
    "PostAtsCandidatesRequestBodyJobylonApplicationTypedDict",
    "PostAtsCandidatesRequestBodyJobylonTypedDict",
    "PostAtsCandidatesRequestBodyLanguage",
    "PostAtsCandidatesRequestBodyLanguageAbility",
    "PostAtsCandidatesRequestBodyLanguageAbilityData",
    "PostAtsCandidatesRequestBodyLanguageAbilityDataTypedDict",
    "PostAtsCandidatesRequestBodyLanguageAbilityTypeReference",
    "PostAtsCandidatesRequestBodyLanguageAbilityTypeReferenceTypedDict",
    "PostAtsCandidatesRequestBodyLanguageAbilityTypedDict",
    "PostAtsCandidatesRequestBodyLanguageDatum",
    "PostAtsCandidatesRequestBodyLanguageDatumLanguageReference",
    "PostAtsCandidatesRequestBodyLanguageDatumLanguageReferenceTypedDict",
    "PostAtsCandidatesRequestBodyLanguageDatumTypedDict",
    "PostAtsCandidatesRequestBodyLanguageProficiencyReference",
    "PostAtsCandidatesRequestBodyLanguageProficiencyReferenceTypedDict",
    "PostAtsCandidatesRequestBodyLanguageReference",
    "PostAtsCandidatesRequestBodyLanguageReferenceTypedDict",
    "PostAtsCandidatesRequestBodyLanguageTypedDict",
    "PostAtsCandidatesRequestBodyLever",
    "PostAtsCandidatesRequestBodyLeverTypedDict",
    "PostAtsCandidatesRequestBodyLocation",
    "PostAtsCandidatesRequestBodyLocationData",
    "PostAtsCandidatesRequestBodyLocationDataTypedDict",
    "PostAtsCandidatesRequestBodyLocationTypedDict",
    "PostAtsCandidatesRequestBodyNameDetailData",
    "PostAtsCandidatesRequestBodyNameDetailDataTypedDict",
    "PostAtsCandidatesRequestBodyPeriod",
    "PostAtsCandidatesRequestBodyPersonio",
    "PostAtsCandidatesRequestBodyPersonioTypedDict",
    "PostAtsCandidatesRequestBodyPiloga",
    "PostAtsCandidatesRequestBodyPilogaCandidate",
    "PostAtsCandidatesRequestBodyPilogaCandidateTypedDict",
    "PostAtsCandidatesRequestBodyPilogaTypedDict",
    "PostAtsCandidatesRequestBodyPostHeaders",
    "PostAtsCandidatesRequestBodyPostHeadersTypedDict",
    "PostAtsCandidatesRequestBodyRecruitee",
    "PostAtsCandidatesRequestBodyRecruiteeCandidate",
    "PostAtsCandidatesRequestBodyRecruiteeCandidateTypedDict",
    "PostAtsCandidatesRequestBodyRecruiteeTypedDict",
    "PostAtsCandidatesRequestBodyRemoteFields",
    "PostAtsCandidatesRequestBodyRemoteFieldsTypedDict",
    "PostAtsCandidatesRequestBodyResumeData",
    "PostAtsCandidatesRequestBodyResumeDataTypedDict",
    "PostAtsCandidatesRequestBodySalaryExpectations",
    "PostAtsCandidatesRequestBodySalaryExpectationsTypedDict",
    "PostAtsCandidatesRequestBodyScreeningQuestionAnswer",
    "PostAtsCandidatesRequestBodyScreeningQuestionAnswerTypedDict",
    "PostAtsCandidatesRequestBodySkillDatum",
    "PostAtsCandidatesRequestBodySkillDatumTypedDict",
    "PostAtsCandidatesRequestBodySmartrecruiters",
    "PostAtsCandidatesRequestBodySmartrecruitersTypedDict",
    "PostAtsCandidatesRequestBodySocialLink",
    "PostAtsCandidatesRequestBodySocialLinkTypedDict",
    "PostAtsCandidatesRequestBodySocialSuffixReference",
    "PostAtsCandidatesRequestBodySocialSuffixReferenceTypedDict",
    "PostAtsCandidatesRequestBodySource",
    "PostAtsCandidatesRequestBodySourceTypedDict",
    "PostAtsCandidatesRequestBodySourcedBy",
    "PostAtsCandidatesRequestBodySourcedByTypedDict",
    "PostAtsCandidatesRequestBodyStep",
    "PostAtsCandidatesRequestBodyStepTypedDict",
    "PostAtsCandidatesRequestBodySuccessfactors",
    "PostAtsCandidatesRequestBodySuccessfactorsTypedDict",
    "PostAtsCandidatesRequestBodyTalentadore",
    "PostAtsCandidatesRequestBodyTalentadoreTypedDict",
    "PostAtsCandidatesRequestBodyTalentsoft",
    "PostAtsCandidatesRequestBodyTalentsoftTypedDict",
    "PostAtsCandidatesRequestBodyTeamtailor",
    "PostAtsCandidatesRequestBodyTeamtailorApplication",
    "PostAtsCandidatesRequestBodyTeamtailorApplicationTypedDict",
    "PostAtsCandidatesRequestBodyTeamtailorTypedDict",
    "PostAtsCandidatesRequestBodyTypedDict",
    "PostAtsCandidatesRequestBodyUmantis",
    "PostAtsCandidatesRequestBodyUmantisTypedDict",
    "PostAtsCandidatesRequestBodyWorkable",
    "PostAtsCandidatesRequestBodyWorkableTypedDict",
    "PostAtsCandidatesRequestBodyWorkday",
    "PostAtsCandidatesRequestBodyWorkdayTypedDict",
    "PostAtsCandidatesRequestBodyWorkerReference",
    "PostAtsCandidatesRequestBodyWorkerReferenceTypedDict",
    "PostAtsCandidatesRequestBodyWorkflow",
    "PostAtsCandidatesRequestBodyWorkflowTypedDict",
    "PostAtsCandidatesRequestBodyZohorecruit",
    "PostAtsCandidatesRequestBodyZohorecruitTypedDict",
    "PostAtsImportTrackedApplicationGlobals",
    "PostAtsImportTrackedApplicationGlobalsTypedDict",
    "PostAtsImportTrackedApplicationPositiveResponse",
    "PostAtsImportTrackedApplicationPositiveResponseData",
    "PostAtsImportTrackedApplicationPositiveResponseDataTypedDict",
    "PostAtsImportTrackedApplicationPositiveResponseErecruiterApplicationAndCandidateRemoteIds",
    "PostAtsImportTrackedApplicationPositiveResponseErecruiterApplicationAndCandidateRemoteIdsTypedDict",
    "PostAtsImportTrackedApplicationPositiveResponseErecruiterApplicationAndJobRemoteIds",
    "PostAtsImportTrackedApplicationPositiveResponseErecruiterApplicationAndJobRemoteIdsTypedDict",
    "PostAtsImportTrackedApplicationPositiveResponseErecruiterUnion",
    "PostAtsImportTrackedApplicationPositiveResponseErecruiterUnionTypedDict",
    "PostAtsImportTrackedApplicationPositiveResponseGreenhouseApplicationID",
    "PostAtsImportTrackedApplicationPositiveResponseGreenhouseApplicationIDTypedDict",
    "PostAtsImportTrackedApplicationPositiveResponseGreenhouseUnion",
    "PostAtsImportTrackedApplicationPositiveResponseGreenhouseUnionTypedDict",
    "PostAtsImportTrackedApplicationPositiveResponseOnlyfyApplicationID",
    "PostAtsImportTrackedApplicationPositiveResponseOnlyfyApplicationIDTypedDict",
    "PostAtsImportTrackedApplicationPositiveResponseOnlyfyUnion",
    "PostAtsImportTrackedApplicationPositiveResponseOnlyfyUnionTypedDict",
    "PostAtsImportTrackedApplicationPositiveResponseRecruiteePlacementID",
    "PostAtsImportTrackedApplicationPositiveResponseRecruiteePlacementIDTypedDict",
    "PostAtsImportTrackedApplicationPositiveResponseRecruiteeUnion",
    "PostAtsImportTrackedApplicationPositiveResponseRecruiteeUnionTypedDict",
    "PostAtsImportTrackedApplicationPositiveResponseSmartrecruitersCandidateAndJobRemoteIds",
    "PostAtsImportTrackedApplicationPositiveResponseSmartrecruitersCandidateAndJobRemoteIdsTypedDict",
    "PostAtsImportTrackedApplicationPositiveResponseSmartrecruitersUnion",
    "PostAtsImportTrackedApplicationPositiveResponseSmartrecruitersUnionTypedDict",
    "PostAtsImportTrackedApplicationPositiveResponseSuccessfactorsApplicationRemoteID",
    "PostAtsImportTrackedApplicationPositiveResponseSuccessfactorsApplicationRemoteIDTypedDict",
    "PostAtsImportTrackedApplicationPositiveResponseSuccessfactorsUnion",
    "PostAtsImportTrackedApplicationPositiveResponseSuccessfactorsUnionTypedDict",
    "PostAtsImportTrackedApplicationPositiveResponseTypedDict",
    "PostAtsImportTrackedApplicationPositiveResponseWarning",
    "PostAtsImportTrackedApplicationPositiveResponseWarningTypedDict",
    "PostAtsImportTrackedApplicationRequestBody",
    "PostAtsImportTrackedApplicationRequestBodyErecruiterApplicationAndCandidateRemoteIds",
    "PostAtsImportTrackedApplicationRequestBodyErecruiterApplicationAndCandidateRemoteIdsTypedDict",
    "PostAtsImportTrackedApplicationRequestBodyErecruiterApplicationAndJobRemoteIds",
    "PostAtsImportTrackedApplicationRequestBodyErecruiterApplicationAndJobRemoteIdsTypedDict",
    "PostAtsImportTrackedApplicationRequestBodyErecruiterUnion",
    "PostAtsImportTrackedApplicationRequestBodyErecruiterUnionTypedDict",
    "PostAtsImportTrackedApplicationRequestBodyGreenhouseApplicationID",
    "PostAtsImportTrackedApplicationRequestBodyGreenhouseApplicationIDTypedDict",
    "PostAtsImportTrackedApplicationRequestBodyGreenhouseUnion",
    "PostAtsImportTrackedApplicationRequestBodyGreenhouseUnionTypedDict",
    "PostAtsImportTrackedApplicationRequestBodyOnlyfyApplicationID",
    "PostAtsImportTrackedApplicationRequestBodyOnlyfyApplicationIDTypedDict",
    "PostAtsImportTrackedApplicationRequestBodyOnlyfyUnion",
    "PostAtsImportTrackedApplicationRequestBodyOnlyfyUnionTypedDict",
    "PostAtsImportTrackedApplicationRequestBodyRecruiteePlacementID",
    "PostAtsImportTrackedApplicationRequestBodyRecruiteePlacementIDTypedDict",
    "PostAtsImportTrackedApplicationRequestBodyRecruiteeUnion",
    "PostAtsImportTrackedApplicationRequestBodyRecruiteeUnionTypedDict",
    "PostAtsImportTrackedApplicationRequestBodySmartrecruitersCandidateAndJobRemoteIds",
    "PostAtsImportTrackedApplicationRequestBodySmartrecruitersCandidateAndJobRemoteIdsTypedDict",
    "PostAtsImportTrackedApplicationRequestBodySmartrecruitersUnion",
    "PostAtsImportTrackedApplicationRequestBodySmartrecruitersUnionTypedDict",
    "PostAtsImportTrackedApplicationRequestBodySuccessfactorsApplicationRemoteID",
    "PostAtsImportTrackedApplicationRequestBodySuccessfactorsApplicationRemoteIDTypedDict",
    "PostAtsImportTrackedApplicationRequestBodySuccessfactorsUnion",
    "PostAtsImportTrackedApplicationRequestBodySuccessfactorsUnionTypedDict",
    "PostAtsImportTrackedApplicationRequestBodyTypedDict",
    "PostAtsJobsJobIDApplicationsGlobals",
    "PostAtsJobsJobIDApplicationsGlobalsTypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer1",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer1TypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer2",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer2TypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer3",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer3TypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer4",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer4TypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer5",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer5TypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer6",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer6TypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer7",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer7TypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseCandidate",
    "PostAtsJobsJobIDApplicationsPositiveResponseCandidateTypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseCurrentStage",
    "PostAtsJobsJobIDApplicationsPositiveResponseCurrentStageTypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseData",
    "PostAtsJobsJobIDApplicationsPositiveResponseDataTypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseEmailAddress",
    "PostAtsJobsJobIDApplicationsPositiveResponseEmailAddressTypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseJob",
    "PostAtsJobsJobIDApplicationsPositiveResponseJobTypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseLocation",
    "PostAtsJobsJobIDApplicationsPositiveResponseLocationTypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseOutcome",
    "PostAtsJobsJobIDApplicationsPositiveResponsePhoneNumber",
    "PostAtsJobsJobIDApplicationsPositiveResponsePhoneNumberTypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionBoolean",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionBooleanTypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionDate",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionDateTypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionMultiSelect",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionMultiSelectTypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionNumber",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionNumberTypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionSingleSelect",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionSingleSelectTypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionText",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionTextTypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionUnknown",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionUnknownTypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer1",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer1TypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer2",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer2TypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer3",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer3TypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer4",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer4TypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer5",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer5TypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer6",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer6TypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer7",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer7TypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswerUnion",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswerUnionTypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseSocialMedia",
    "PostAtsJobsJobIDApplicationsPositiveResponseSocialMediaTypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseTag",
    "PostAtsJobsJobIDApplicationsPositiveResponseTagTypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseTypedDict",
    "PostAtsJobsJobIDApplicationsPositiveResponseWarning",
    "PostAtsJobsJobIDApplicationsPositiveResponseWarningTypedDict",
    "PostAtsJobsJobIDApplicationsRequest",
    "PostAtsJobsJobIDApplicationsRequestBody",
    "PostAtsJobsJobIDApplicationsRequestBodyAdditionalEmailAddress",
    "PostAtsJobsJobIDApplicationsRequestBodyAdditionalEmailAddressType",
    "PostAtsJobsJobIDApplicationsRequestBodyAdditionalEmailAddressTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyAdditionalPhoneNumber",
    "PostAtsJobsJobIDApplicationsRequestBodyAdditionalPhoneNumberType",
    "PostAtsJobsJobIDApplicationsRequestBodyAdditionalPhoneNumberTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyAnswer",
    "PostAtsJobsJobIDApplicationsRequestBodyAnswerTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyAnswerUnion",
    "PostAtsJobsJobIDApplicationsRequestBodyAnswerUnionTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyAttachment",
    "PostAtsJobsJobIDApplicationsRequestBodyAttachmentType",
    "PostAtsJobsJobIDApplicationsRequestBodyAttachmentTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyAvature",
    "PostAtsJobsJobIDApplicationsRequestBodyAvatureTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyBullhorn",
    "PostAtsJobsJobIDApplicationsRequestBodyBullhornTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyCandidate",
    "PostAtsJobsJobIDApplicationsRequestBodyCandidateData",
    "PostAtsJobsJobIDApplicationsRequestBodyCandidateDataTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyCandidateTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyContactData",
    "PostAtsJobsJobIDApplicationsRequestBodyContactDataTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyCountryCityReference",
    "PostAtsJobsJobIDApplicationsRequestBodyCountryCityReferenceTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyCountryRegionReference",
    "PostAtsJobsJobIDApplicationsRequestBodyCountryRegionReferenceTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyDegreeReference",
    "PostAtsJobsJobIDApplicationsRequestBodyDegreeReferenceTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyDvinci",
    "PostAtsJobsJobIDApplicationsRequestBodyDvinciTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyEducationDatum",
    "PostAtsJobsJobIDApplicationsRequestBodyEducationDatumTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyExperienceDatum",
    "PostAtsJobsJobIDApplicationsRequestBodyExperienceDatumTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyFieldOfStudyReference",
    "PostAtsJobsJobIDApplicationsRequestBodyFieldOfStudyReferenceTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyGdprConsent",
    "PostAtsJobsJobIDApplicationsRequestBodyGdprConsentTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyGender",
    "PostAtsJobsJobIDApplicationsRequestBodyGlobalPersonalInformationData",
    "PostAtsJobsJobIDApplicationsRequestBodyGlobalPersonalInformationDataTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyGreenhouse",
    "PostAtsJobsJobIDApplicationsRequestBodyGreenhouseTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyGuidecom",
    "PostAtsJobsJobIDApplicationsRequestBodyGuidecomTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyHrworks",
    "PostAtsJobsJobIDApplicationsRequestBodyHrworksTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyJobApplicationData",
    "PostAtsJobsJobIDApplicationsRequestBodyJobApplicationDataTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyJobAppliedToData",
    "PostAtsJobsJobIDApplicationsRequestBodyJobAppliedToDataTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyJobylon",
    "PostAtsJobsJobIDApplicationsRequestBodyJobylonApplication",
    "PostAtsJobsJobIDApplicationsRequestBodyJobylonApplicationTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyJobylonTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguage",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageAbility",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageAbilityData",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageAbilityDataTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageAbilityTypeReference",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageAbilityTypeReferenceTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageAbilityTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageDatum",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageDatumLanguageReference",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageDatumLanguageReferenceTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageDatumTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageProficiencyReference",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageProficiencyReferenceTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageReference",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageReferenceTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyLever",
    "PostAtsJobsJobIDApplicationsRequestBodyLeverTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyLocation",
    "PostAtsJobsJobIDApplicationsRequestBodyLocationData",
    "PostAtsJobsJobIDApplicationsRequestBodyLocationDataTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyLocationTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyNameDetailData",
    "PostAtsJobsJobIDApplicationsRequestBodyNameDetailDataTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyPeriod",
    "PostAtsJobsJobIDApplicationsRequestBodyPersonio",
    "PostAtsJobsJobIDApplicationsRequestBodyPersonioTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyPiloga",
    "PostAtsJobsJobIDApplicationsRequestBodyPilogaCandidate",
    "PostAtsJobsJobIDApplicationsRequestBodyPilogaCandidateTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyPilogaTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyPostHeaders",
    "PostAtsJobsJobIDApplicationsRequestBodyPostHeadersTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyRecruitee",
    "PostAtsJobsJobIDApplicationsRequestBodyRecruiteeCandidate",
    "PostAtsJobsJobIDApplicationsRequestBodyRecruiteeCandidateTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyRecruiteeTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyRemoteFields",
    "PostAtsJobsJobIDApplicationsRequestBodyRemoteFieldsTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyResumeData",
    "PostAtsJobsJobIDApplicationsRequestBodyResumeDataTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodySalaryExpectations",
    "PostAtsJobsJobIDApplicationsRequestBodySalaryExpectationsTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyScreeningQuestionAnswer",
    "PostAtsJobsJobIDApplicationsRequestBodyScreeningQuestionAnswerTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodySkillDatum",
    "PostAtsJobsJobIDApplicationsRequestBodySkillDatumTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodySmartrecruiters",
    "PostAtsJobsJobIDApplicationsRequestBodySmartrecruitersTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodySocialLink",
    "PostAtsJobsJobIDApplicationsRequestBodySocialLinkTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodySocialSuffixReference",
    "PostAtsJobsJobIDApplicationsRequestBodySocialSuffixReferenceTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodySource",
    "PostAtsJobsJobIDApplicationsRequestBodySourceTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodySourcedBy",
    "PostAtsJobsJobIDApplicationsRequestBodySourcedByTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyStep",
    "PostAtsJobsJobIDApplicationsRequestBodyStepTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodySuccessfactors",
    "PostAtsJobsJobIDApplicationsRequestBodySuccessfactorsTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyTalentadore",
    "PostAtsJobsJobIDApplicationsRequestBodyTalentadoreTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyTalentsoft",
    "PostAtsJobsJobIDApplicationsRequestBodyTalentsoftTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyTeamtailor",
    "PostAtsJobsJobIDApplicationsRequestBodyTeamtailorApplication",
    "PostAtsJobsJobIDApplicationsRequestBodyTeamtailorApplicationTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyTeamtailorTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyUmantis",
    "PostAtsJobsJobIDApplicationsRequestBodyUmantisTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyWorkable",
    "PostAtsJobsJobIDApplicationsRequestBodyWorkableTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyWorkday",
    "PostAtsJobsJobIDApplicationsRequestBodyWorkdayTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyWorkerReference",
    "PostAtsJobsJobIDApplicationsRequestBodyWorkerReferenceTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyWorkflow",
    "PostAtsJobsJobIDApplicationsRequestBodyWorkflowTypedDict",
    "PostAtsJobsJobIDApplicationsRequestBodyZohorecruit",
    "PostAtsJobsJobIDApplicationsRequestBodyZohorecruitTypedDict",
    "PostAtsJobsJobIDApplicationsRequestTypedDict",
    "PostConnectCreateLinkPositiveResponse",
    "PostConnectCreateLinkPositiveResponseData",
    "PostConnectCreateLinkPositiveResponseDataTypedDict",
    "PostConnectCreateLinkPositiveResponseTypedDict",
    "PostConnectCreateLinkRequestBody",
    "PostConnectCreateLinkRequestBodyIntegrationCategory",
    "PostConnectCreateLinkRequestBodyLanguage",
    "PostConnectCreateLinkRequestBodyLinkType",
    "PostConnectCreateLinkRequestBodyTypedDict",
    "PostForceSyncGlobals",
    "PostForceSyncGlobalsTypedDict",
    "PostForceSyncPositiveResponse",
    "PostForceSyncPositiveResponseData",
    "PostForceSyncPositiveResponseDataTypedDict",
    "PostForceSyncPositiveResponseType",
    "PostForceSyncPositiveResponseTypedDict",
    "PostForceSyncRequestBody",
    "PostForceSyncRequestBodyType",
    "PostForceSyncRequestBodyTypedDict",
    "PostHrisAbsencesGlobals",
    "PostHrisAbsencesGlobalsTypedDict",
    "PostHrisAbsencesPositiveResponse",
    "PostHrisAbsencesPositiveResponseData",
    "PostHrisAbsencesPositiveResponseDataTypedDict",
    "PostHrisAbsencesPositiveResponseStatus",
    "PostHrisAbsencesPositiveResponseTypedDict",
    "PostHrisAbsencesPositiveResponseUnit",
    "PostHrisAbsencesPositiveResponseWarning",
    "PostHrisAbsencesPositiveResponseWarningTypedDict",
    "PostHrisAbsencesRequestBody",
    "PostHrisAbsencesRequestBodyAdpworkforcenow",
    "PostHrisAbsencesRequestBodyAdpworkforcenowTypedDict",
    "PostHrisAbsencesRequestBodyRemoteFields",
    "PostHrisAbsencesRequestBodyRemoteFieldsTypedDict",
    "PostHrisAbsencesRequestBodyStatus",
    "PostHrisAbsencesRequestBodyTypedDict",
    "PostHrisAbsencesRequestBodyUnit",
    "PostHrisEmployeesEmployeeIDDocumentsGlobals",
    "PostHrisEmployeesEmployeeIDDocumentsGlobalsTypedDict",
    "PostHrisEmployeesEmployeeIDDocumentsPositiveResponse",
    "PostHrisEmployeesEmployeeIDDocumentsPositiveResponseData",
    "PostHrisEmployeesEmployeeIDDocumentsPositiveResponseDataTypedDict",
    "PostHrisEmployeesEmployeeIDDocumentsPositiveResponseTypedDict",
    "PostHrisEmployeesEmployeeIDDocumentsPositiveResponseWarning",
    "PostHrisEmployeesEmployeeIDDocumentsPositiveResponseWarningTypedDict",
    "PostHrisEmployeesEmployeeIDDocumentsRequest",
    "PostHrisEmployeesEmployeeIDDocumentsRequestBody",
    "PostHrisEmployeesEmployeeIDDocumentsRequestBodyTypedDict",
    "PostHrisEmployeesEmployeeIDDocumentsRequestTypedDict",
    "PostHrisEmployeesFormGlobals",
    "PostHrisEmployeesFormGlobalsTypedDict",
    "PostHrisEmployeesFormPositiveResponse",
    "PostHrisEmployeesFormPositiveResponseData",
    "PostHrisEmployeesFormPositiveResponseDataTypedDict",
    "PostHrisEmployeesFormPositiveResponseTypedDict",
    "PostHrisEmployeesFormPositiveResponseWarning",
    "PostHrisEmployeesFormPositiveResponseWarningTypedDict",
    "PostHrisEmployeesFormRequestBody",
    "PostHrisEmployeesFormRequestBodyTypedDict",
    "PostIntegrationsIntegrationIDRelinkPositiveResponse",
    "PostIntegrationsIntegrationIDRelinkPositiveResponseData",
    "PostIntegrationsIntegrationIDRelinkPositiveResponseDataTypedDict",
    "PostIntegrationsIntegrationIDRelinkPositiveResponseTypedDict",
    "PostIntegrationsIntegrationIDRelinkRequest",
    "PostIntegrationsIntegrationIDRelinkRequestBody",
    "PostIntegrationsIntegrationIDRelinkRequestBodyLanguage",
    "PostIntegrationsIntegrationIDRelinkRequestBodyLinkType",
    "PostIntegrationsIntegrationIDRelinkRequestBodyTypedDict",
    "PostIntegrationsIntegrationIDRelinkRequestTypedDict",
    "PostPassthroughToolAPIGlobals",
    "PostPassthroughToolAPIGlobalsTypedDict",
    "PostPassthroughToolAPIPositiveResponse",
    "PostPassthroughToolAPIPositiveResponseData",
    "PostPassthroughToolAPIPositiveResponseDataTypedDict",
    "PostPassthroughToolAPIPositiveResponseTypedDict",
    "PostPassthroughToolAPIPositiveResponseWarning",
    "PostPassthroughToolAPIPositiveResponseWarningTypedDict",
    "PostPassthroughToolAPIRequest",
    "PostPassthroughToolAPIRequestBody",
    "PostPassthroughToolAPIRequestBodyTypedDict",
    "PostPassthroughToolAPIRequestTypedDict",
    "PreconditionOptions",
    "PreconditionOptionsTypedDict",
    "Properties",
    "PropertiesArray",
    "PropertiesArrayTypedDict",
    "PropertiesCheckbox",
    "PropertiesCheckboxTypedDict",
    "PropertiesDate",
    "PropertiesDateTypedDict",
    "PropertiesFile",
    "PropertiesFileTypedDict",
    "PropertiesMultiSelect",
    "PropertiesMultiSelectTypedDict",
    "PropertiesNumber",
    "PropertiesNumberTypedDict",
    "PropertiesObject",
    "PropertiesObjectTypedDict",
    "PropertiesSingleSelect",
    "PropertiesSingleSelectTypedDict",
    "PropertiesText",
    "PropertiesTextTypedDict",
    "PropertiesTypedDict",
    "PutAssessmentOrdersAssessmentOrderIDResultGlobals",
    "PutAssessmentOrdersAssessmentOrderIDResultGlobalsTypedDict",
    "PutAssessmentOrdersAssessmentOrderIDResultPositiveResponse",
    "PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseData",
    "PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseDataTypedDict",
    "PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseTypedDict",
    "PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseWarning",
    "PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseWarningTypedDict",
    "PutAssessmentOrdersAssessmentOrderIDResultRequest",
    "PutAssessmentOrdersAssessmentOrderIDResultRequestBody",
    "PutAssessmentOrdersAssessmentOrderIDResultRequestBodyAttachment",
    "PutAssessmentOrdersAssessmentOrderIDResultRequestBodyAttachmentTypedDict",
    "PutAssessmentOrdersAssessmentOrderIDResultRequestBodyRemoteFields",
    "PutAssessmentOrdersAssessmentOrderIDResultRequestBodyRemoteFieldsTypedDict",
    "PutAssessmentOrdersAssessmentOrderIDResultRequestBodySmartrecruiters",
    "PutAssessmentOrdersAssessmentOrderIDResultRequestBodySmartrecruitersTypedDict",
    "PutAssessmentOrdersAssessmentOrderIDResultRequestBodyStatus",
    "PutAssessmentOrdersAssessmentOrderIDResultRequestBodyTypedDict",
    "PutAssessmentOrdersAssessmentOrderIDResultRequestTypedDict",
    "PutAssessmentPackagesGlobals",
    "PutAssessmentPackagesGlobalsTypedDict",
    "PutAssessmentPackagesPositiveResponse",
    "PutAssessmentPackagesPositiveResponseData",
    "PutAssessmentPackagesPositiveResponseDataTypedDict",
    "PutAssessmentPackagesPositiveResponseTypedDict",
    "PutAssessmentPackagesPositiveResponseWarning",
    "PutAssessmentPackagesPositiveResponseWarningTypedDict",
    "PutAssessmentPackagesRequestBody",
    "PutAssessmentPackagesRequestBodyPackage",
    "PutAssessmentPackagesRequestBodyPackageTypedDict",
    "PutAssessmentPackagesRequestBodyType",
    "PutAssessmentPackagesRequestBodyTypedDict",
    "PutAtsApplicationsApplicationIDStageGlobals",
    "PutAtsApplicationsApplicationIDStageGlobalsTypedDict",
    "PutAtsApplicationsApplicationIDStagePositiveResponse",
    "PutAtsApplicationsApplicationIDStagePositiveResponseData",
    "PutAtsApplicationsApplicationIDStagePositiveResponseDataTypedDict",
    "PutAtsApplicationsApplicationIDStagePositiveResponseTypedDict",
    "PutAtsApplicationsApplicationIDStagePositiveResponseWarning",
    "PutAtsApplicationsApplicationIDStagePositiveResponseWarningTypedDict",
    "PutAtsApplicationsApplicationIDStageRequest",
    "PutAtsApplicationsApplicationIDStageRequestBody",
    "PutAtsApplicationsApplicationIDStageRequestBodyGreenhouse",
    "PutAtsApplicationsApplicationIDStageRequestBodyGreenhouseTypedDict",
    "PutAtsApplicationsApplicationIDStageRequestBodyPostHeaders",
    "PutAtsApplicationsApplicationIDStageRequestBodyPostHeadersTypedDict",
    "PutAtsApplicationsApplicationIDStageRequestBodyRemoteFields",
    "PutAtsApplicationsApplicationIDStageRequestBodyRemoteFieldsTypedDict",
    "PutAtsApplicationsApplicationIDStageRequestBodyTypedDict",
    "PutAtsApplicationsApplicationIDStageRequestBodyWorkable",
    "PutAtsApplicationsApplicationIDStageRequestBodyWorkableTypedDict",
    "PutAtsApplicationsApplicationIDStageRequestTypedDict",
    "PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDPositiveResponse",
    "PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDPositiveResponseData",
    "PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDPositiveResponseDataTypedDict",
    "PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDPositiveResponseIntegrationField",
    "PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDPositiveResponseIntegrationFieldTypedDict",
    "PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDPositiveResponseType",
    "PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDPositiveResponseTypedDict",
    "PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDRequest",
    "PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDRequestBody",
    "PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDRequestBodyTypedDict",
    "PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDRequestTypedDict",
    "QaStatus",
    "RemoteWorkStatus",
    "ReviewCycle",
    "ReviewCycleTypedDict",
    "Reviewee",
    "RevieweeTypedDict",
    "Reviewer",
    "ReviewerTypedDict",
    "SalaryPeriod",
    "Schema1",
    "Schema1Array1",
    "Schema1Array1TypedDict",
    "Schema1Array2",
    "Schema1Array2TypedDict",
    "Schema1Checkbox",
    "Schema1CheckboxTypedDict",
    "Schema1Date",
    "Schema1DateTypedDict",
    "Schema1Entry1",
    "Schema1Entry1TypedDict",
    "Schema1Entry2",
    "Schema1Entry2TypedDict",
    "Schema1File",
    "Schema1FileRestrictions",
    "Schema1FileRestrictionsTypedDict",
    "Schema1FileTypedDict",
    "Schema1MultiSelect",
    "Schema1MultiSelectTypedDict",
    "Schema1Number",
    "Schema1NumberTypedDict",
    "Schema1Object",
    "Schema1ObjectTypedDict",
    "Schema1OptionsInline1",
    "Schema1OptionsInline1TypedDict",
    "Schema1OptionsInline2",
    "Schema1OptionsInline2TypedDict",
    "Schema1OptionsReferenced1",
    "Schema1OptionsReferenced1TypedDict",
    "Schema1OptionsReferenced2",
    "Schema1OptionsReferenced2TypedDict",
    "Schema1OptionsUnion1",
    "Schema1OptionsUnion1TypedDict",
    "Schema1OptionsUnion2",
    "Schema1OptionsUnion2TypedDict",
    "Schema1RemoteID1",
    "Schema1RemoteID1TypedDict",
    "Schema1RemoteID2",
    "Schema1RemoteID2TypedDict",
    "Schema1SingleSelect",
    "Schema1SingleSelectTypedDict",
    "Schema1Text",
    "Schema1TextTypedDict",
    "Schema1TypedDict",
    "Schema1UnifiedKey1",
    "Schema1UnifiedKey2",
    "Schema1UnifiedKey3",
    "Schema1UnifiedKey4",
    "Schema1UnifiedKey5",
    "Schema1UnifiedKey6",
    "Schema1UnifiedKey7",
    "Schema1UnifiedKey8",
    "Schema1Union1",
    "Schema1Union1TypedDict",
    "Schema1Union2",
    "Schema1Union2TypedDict",
    "Schema2Array1",
    "Schema2Array1TypedDict",
    "Schema2Array2",
    "Schema2Array2TypedDict",
    "Schema2Checkbox",
    "Schema2CheckboxTypedDict",
    "Schema2Date",
    "Schema2DateTypedDict",
    "Schema2Entry1",
    "Schema2Entry1TypedDict",
    "Schema2Entry2",
    "Schema2Entry2TypedDict",
    "Schema2File",
    "Schema2FileRestrictions",
    "Schema2FileRestrictionsTypedDict",
    "Schema2FileTypedDict",
    "Schema2MultiSelect",
    "Schema2MultiSelectTypedDict",
    "Schema2Number",
    "Schema2NumberTypedDict",
    "Schema2Object1",
    "Schema2Object1TypedDict",
    "Schema2Object2",
    "Schema2Object2TypedDict",
    "Schema2OptionsInline1",
    "Schema2OptionsInline1TypedDict",
    "Schema2OptionsInline2",
    "Schema2OptionsInline2TypedDict",
    "Schema2OptionsReferenced1",
    "Schema2OptionsReferenced1TypedDict",
    "Schema2OptionsReferenced2",
    "Schema2OptionsReferenced2TypedDict",
    "Schema2OptionsUnion1",
    "Schema2OptionsUnion1TypedDict",
    "Schema2OptionsUnion2",
    "Schema2OptionsUnion2TypedDict",
    "Schema2RemoteID1",
    "Schema2RemoteID1TypedDict",
    "Schema2RemoteID2",
    "Schema2RemoteID2TypedDict",
    "Schema2SingleSelect",
    "Schema2SingleSelectTypedDict",
    "Schema2Text",
    "Schema2TextTypedDict",
    "Schema2UnifiedKey1",
    "Schema2UnifiedKey2",
    "Schema2UnifiedKey3",
    "Schema2UnifiedKey4",
    "Schema2UnifiedKey5",
    "Schema2UnifiedKey6",
    "Schema2UnifiedKey7",
    "Schema2UnifiedKey8",
    "Schema2Union1",
    "Schema2Union1TypedDict",
    "Schema2Union2",
    "Schema2Union2TypedDict",
    "Schema4",
    "Schema4TypedDict",
    "ScopeConfig",
    "ScopeConfigSetting",
    "ScopeConfigTypedDict",
    "Score",
    "ScoreTypedDict",
    "ScreeningQuestion",
    "ScreeningQuestionTypedDict",
    "Security",
    "SecurityTypedDict",
    "Stage",
    "StageTypedDict",
    "State",
    "SummaryRating",
    "SummaryRatingNumeric",
    "SummaryRatingNumericTypedDict",
    "SummaryRatingSingleSelect",
    "SummaryRatingSingleSelectTypedDict",
    "SummaryRatingTypedDict",
    "SyncFinishedWebhookPayload",
    "SyncFinishedWebhookPayloadData",
    "SyncFinishedWebhookPayloadDataTypedDict",
    "SyncFinishedWebhookPayloadEndUser",
    "SyncFinishedWebhookPayloadEndUserTypedDict",
    "SyncFinishedWebhookPayloadIntegrationCategory",
    "SyncFinishedWebhookPayloadType",
    "SyncFinishedWebhookPayloadTypedDict",
    "TimeOffBalance",
    "TimeOffBalanceTypedDict",
    "User",
    "UserTypedDict",
    "Value",
    "ValueTypedDict",
    "ValueUnion",
    "ValueUnionTypedDict",
    "Visibility",
    "WebhookAssessmentOrderReceivedWebhookPayloadRequest",
    "WebhookAssessmentOrderReceivedWebhookPayloadRequestTypedDict",
    "WebhookConnectionFlowFailedWebhookPayloadRequest",
    "WebhookConnectionFlowFailedWebhookPayloadRequestTypedDict",
    "WebhookDataChangedWebhookPayloadRequest",
    "WebhookDataChangedWebhookPayloadRequestTypedDict",
    "WebhookInlineAssessmentOrderReceivedWebhookPayloadRequest",
    "WebhookInlineAssessmentOrderReceivedWebhookPayloadRequestTypedDict",
    "WebhookIntegrationCreatedWebhookPayloadRequest",
    "WebhookIntegrationCreatedWebhookPayloadRequestTypedDict",
    "WebhookIntegrationDeletedWebhookPayloadRequest",
    "WebhookIntegrationDeletedWebhookPayloadRequestTypedDict",
    "WebhookIntegrationStateChangedWebhookPayloadRequest",
    "WebhookIntegrationStateChangedWebhookPayloadRequestTypedDict",
    "WebhookSyncFinishedWebhookPayloadRequest",
    "WebhookSyncFinishedWebhookPayloadRequestTypedDict",
    "WorkLocation",
    "WorkLocationAddress",
    "WorkLocationAddressTypedDict",
    "WorkLocationTypedDict",
    "WriteAction",
    "WriteActionCoverageStatus",
    "WriteActionTypedDict",
]

_dynamic_imports: dict[str, str] = {
    "AssessmentOrderReceivedWebhookPayload": ".assessmentorderreceivedwebhookpayload",
    "AssessmentOrderReceivedWebhookPayloadApplication": ".assessmentorderreceivedwebhookpayload",
    "AssessmentOrderReceivedWebhookPayloadApplicationTypedDict": ".assessmentorderreceivedwebhookpayload",
    "AssessmentOrderReceivedWebhookPayloadCandidate": ".assessmentorderreceivedwebhookpayload",
    "AssessmentOrderReceivedWebhookPayloadCandidateTypedDict": ".assessmentorderreceivedwebhookpayload",
    "AssessmentOrderReceivedWebhookPayloadData": ".assessmentorderreceivedwebhookpayload",
    "AssessmentOrderReceivedWebhookPayloadDataTypedDict": ".assessmentorderreceivedwebhookpayload",
    "AssessmentOrderReceivedWebhookPayloadHiringTeam": ".assessmentorderreceivedwebhookpayload",
    "AssessmentOrderReceivedWebhookPayloadHiringTeamRole": ".assessmentorderreceivedwebhookpayload",
    "AssessmentOrderReceivedWebhookPayloadHiringTeamTypedDict": ".assessmentorderreceivedwebhookpayload",
    "AssessmentOrderReceivedWebhookPayloadJob": ".assessmentorderreceivedwebhookpayload",
    "AssessmentOrderReceivedWebhookPayloadJobTypedDict": ".assessmentorderreceivedwebhookpayload",
    "AssessmentOrderReceivedWebhookPayloadLocation": ".assessmentorderreceivedwebhookpayload",
    "AssessmentOrderReceivedWebhookPayloadLocationTypedDict": ".assessmentorderreceivedwebhookpayload",
    "AssessmentOrderReceivedWebhookPayloadStatus": ".assessmentorderreceivedwebhookpayload",
    "AssessmentOrderReceivedWebhookPayloadType": ".assessmentorderreceivedwebhookpayload",
    "AssessmentOrderReceivedWebhookPayloadTypedDict": ".assessmentorderreceivedwebhookpayload",
    "ConnectionFlowFailedWebhookPayload": ".connectionflowfailedwebhookpayload",
    "ConnectionFlowFailedWebhookPayloadData": ".connectionflowfailedwebhookpayload",
    "ConnectionFlowFailedWebhookPayloadDataTypedDict": ".connectionflowfailedwebhookpayload",
    "ConnectionFlowFailedWebhookPayloadEndUser": ".connectionflowfailedwebhookpayload",
    "ConnectionFlowFailedWebhookPayloadEndUserTypedDict": ".connectionflowfailedwebhookpayload",
    "ConnectionFlowFailedWebhookPayloadIntegrationCategory": ".connectionflowfailedwebhookpayload",
    "ConnectionFlowFailedWebhookPayloadType": ".connectionflowfailedwebhookpayload",
    "ConnectionFlowFailedWebhookPayloadTypedDict": ".connectionflowfailedwebhookpayload",
    "ChangedModel": ".datachangedwebhookpayload",
    "ChangedModelTypedDict": ".datachangedwebhookpayload",
    "DataChangedWebhookPayload": ".datachangedwebhookpayload",
    "DataChangedWebhookPayloadData": ".datachangedwebhookpayload",
    "DataChangedWebhookPayloadDataTypedDict": ".datachangedwebhookpayload",
    "DataChangedWebhookPayloadIntegrationCategory": ".datachangedwebhookpayload",
    "DataChangedWebhookPayloadType": ".datachangedwebhookpayload",
    "DataChangedWebhookPayloadTypedDict": ".datachangedwebhookpayload",
    "Name": ".datachangedwebhookpayload",
    "DeleteAtsCandidatesCandidateIDTagsGlobals": ".deleteatscandidatescandidateidtagsop",
    "DeleteAtsCandidatesCandidateIDTagsGlobalsTypedDict": ".deleteatscandidatescandidateidtagsop",
    "DeleteAtsCandidatesCandidateIDTagsRequest": ".deleteatscandidatescandidateidtagsop",
    "DeleteAtsCandidatesCandidateIDTagsRequestTypedDict": ".deleteatscandidatescandidateidtagsop",
    "DeleteAtsCandidatesCandidateIDTagsPositiveResponse": ".deleteatscandidatescandidateidtagspositiveresponse",
    "DeleteAtsCandidatesCandidateIDTagsPositiveResponseData": ".deleteatscandidatescandidateidtagspositiveresponse",
    "DeleteAtsCandidatesCandidateIDTagsPositiveResponseDataTypedDict": ".deleteatscandidatescandidateidtagspositiveresponse",
    "DeleteAtsCandidatesCandidateIDTagsPositiveResponseTypedDict": ".deleteatscandidatescandidateidtagspositiveresponse",
    "DeleteAtsCandidatesCandidateIDTagsPositiveResponseWarning": ".deleteatscandidatescandidateidtagspositiveresponse",
    "DeleteAtsCandidatesCandidateIDTagsPositiveResponseWarningTypedDict": ".deleteatscandidatescandidateidtagspositiveresponse",
    "DeleteAtsCandidatesCandidateIDTagsRequestBody": ".deleteatscandidatescandidateidtagsrequestbody",
    "DeleteAtsCandidatesCandidateIDTagsRequestBodyGreenhouse": ".deleteatscandidatescandidateidtagsrequestbody",
    "DeleteAtsCandidatesCandidateIDTagsRequestBodyGreenhouseTypedDict": ".deleteatscandidatescandidateidtagsrequestbody",
    "DeleteAtsCandidatesCandidateIDTagsRequestBodyPostHeaders": ".deleteatscandidatescandidateidtagsrequestbody",
    "DeleteAtsCandidatesCandidateIDTagsRequestBodyPostHeadersTypedDict": ".deleteatscandidatescandidateidtagsrequestbody",
    "DeleteAtsCandidatesCandidateIDTagsRequestBodyRemoteFields": ".deleteatscandidatescandidateidtagsrequestbody",
    "DeleteAtsCandidatesCandidateIDTagsRequestBodyRemoteFieldsTypedDict": ".deleteatscandidatescandidateidtagsrequestbody",
    "DeleteAtsCandidatesCandidateIDTagsRequestBodyTag": ".deleteatscandidatescandidateidtagsrequestbody",
    "DeleteAtsCandidatesCandidateIDTagsRequestBodyTagTypedDict": ".deleteatscandidatescandidateidtagsrequestbody",
    "DeleteAtsCandidatesCandidateIDTagsRequestBodyTypedDict": ".deleteatscandidatescandidateidtagsrequestbody",
    "DeleteAtsCandidatesCandidateIDTagsRequestBodyWorkable": ".deleteatscandidatescandidateidtagsrequestbody",
    "DeleteAtsCandidatesCandidateIDTagsRequestBodyWorkableTypedDict": ".deleteatscandidatescandidateidtagsrequestbody",
    "DeleteHrisAbsencesAbsenceIDGlobals": ".deletehrisabsencesabsenceidop",
    "DeleteHrisAbsencesAbsenceIDGlobalsTypedDict": ".deletehrisabsencesabsenceidop",
    "DeleteHrisAbsencesAbsenceIDRequest": ".deletehrisabsencesabsenceidop",
    "DeleteHrisAbsencesAbsenceIDRequestTypedDict": ".deletehrisabsencesabsenceidop",
    "DeleteHrisAbsencesAbsenceIDPositiveResponse": ".deletehrisabsencesabsenceidpositiveresponse",
    "DeleteHrisAbsencesAbsenceIDPositiveResponseData": ".deletehrisabsencesabsenceidpositiveresponse",
    "DeleteHrisAbsencesAbsenceIDPositiveResponseDataTypedDict": ".deletehrisabsencesabsenceidpositiveresponse",
    "DeleteHrisAbsencesAbsenceIDPositiveResponseStatus": ".deletehrisabsencesabsenceidpositiveresponse",
    "DeleteHrisAbsencesAbsenceIDPositiveResponseTypedDict": ".deletehrisabsencesabsenceidpositiveresponse",
    "DeleteHrisAbsencesAbsenceIDPositiveResponseUnit": ".deletehrisabsencesabsenceidpositiveresponse",
    "DeleteHrisAbsencesAbsenceIDPositiveResponseWarning": ".deletehrisabsencesabsenceidpositiveresponse",
    "DeleteHrisAbsencesAbsenceIDPositiveResponseWarningTypedDict": ".deletehrisabsencesabsenceidpositiveresponse",
    "DeleteHrisAbsencesAbsenceIDRequestBody": ".deletehrisabsencesabsenceidrequestbody",
    "DeleteHrisAbsencesAbsenceIDRequestBodyAdpworkforcenow": ".deletehrisabsencesabsenceidrequestbody",
    "DeleteHrisAbsencesAbsenceIDRequestBodyAdpworkforcenowTypedDict": ".deletehrisabsencesabsenceidrequestbody",
    "DeleteHrisAbsencesAbsenceIDRequestBodyRemoteFields": ".deletehrisabsencesabsenceidrequestbody",
    "DeleteHrisAbsencesAbsenceIDRequestBodyRemoteFieldsTypedDict": ".deletehrisabsencesabsenceidrequestbody",
    "DeleteHrisAbsencesAbsenceIDRequestBodyTypedDict": ".deletehrisabsencesabsenceidrequestbody",
    "DeleteIntegrationsIntegrationIDRequest": ".deleteintegrationsintegrationidop",
    "DeleteIntegrationsIntegrationIDRequestTypedDict": ".deleteintegrationsintegrationidop",
    "DeleteIntegrationsIntegrationIDPositiveResponse": ".deleteintegrationsintegrationidpositiveresponse",
    "DeleteIntegrationsIntegrationIDPositiveResponseData": ".deleteintegrationsintegrationidpositiveresponse",
    "DeleteIntegrationsIntegrationIDPositiveResponseDataTypedDict": ".deleteintegrationsintegrationidpositiveresponse",
    "DeleteIntegrationsIntegrationIDPositiveResponseTypedDict": ".deleteintegrationsintegrationidpositiveresponse",
    "DeleteIntegrationsIntegrationIDRequestBody": ".deleteintegrationsintegrationidrequestbody",
    "DeleteIntegrationsIntegrationIDRequestBodyTypedDict": ".deleteintegrationsintegrationidrequestbody",
    "GetAssessmentOrdersOpenGlobals": ".getassessmentordersopenop",
    "GetAssessmentOrdersOpenGlobalsTypedDict": ".getassessmentordersopenop",
    "GetAssessmentOrdersOpenRequest": ".getassessmentordersopenop",
    "GetAssessmentOrdersOpenRequestTypedDict": ".getassessmentordersopenop",
    "GetAssessmentOrdersOpenResponse": ".getassessmentordersopenop",
    "GetAssessmentOrdersOpenResponseTypedDict": ".getassessmentordersopenop",
    "GetAssessmentOrdersOpenPositiveResponse": ".getassessmentordersopenpositiveresponse",
    "GetAssessmentOrdersOpenPositiveResponseApplication": ".getassessmentordersopenpositiveresponse",
    "GetAssessmentOrdersOpenPositiveResponseApplicationTypedDict": ".getassessmentordersopenpositiveresponse",
    "GetAssessmentOrdersOpenPositiveResponseCandidate": ".getassessmentordersopenpositiveresponse",
    "GetAssessmentOrdersOpenPositiveResponseCandidateTypedDict": ".getassessmentordersopenpositiveresponse",
    "GetAssessmentOrdersOpenPositiveResponseData": ".getassessmentordersopenpositiveresponse",
    "GetAssessmentOrdersOpenPositiveResponseDataTypedDict": ".getassessmentordersopenpositiveresponse",
    "GetAssessmentOrdersOpenPositiveResponseHiringTeam": ".getassessmentordersopenpositiveresponse",
    "GetAssessmentOrdersOpenPositiveResponseHiringTeamRole": ".getassessmentordersopenpositiveresponse",
    "GetAssessmentOrdersOpenPositiveResponseHiringTeamTypedDict": ".getassessmentordersopenpositiveresponse",
    "GetAssessmentOrdersOpenPositiveResponseJob": ".getassessmentordersopenpositiveresponse",
    "GetAssessmentOrdersOpenPositiveResponseJobTypedDict": ".getassessmentordersopenpositiveresponse",
    "GetAssessmentOrdersOpenPositiveResponseLocation": ".getassessmentordersopenpositiveresponse",
    "GetAssessmentOrdersOpenPositiveResponseLocationTypedDict": ".getassessmentordersopenpositiveresponse",
    "GetAssessmentOrdersOpenPositiveResponseResult": ".getassessmentordersopenpositiveresponse",
    "GetAssessmentOrdersOpenPositiveResponseResultTypedDict": ".getassessmentordersopenpositiveresponse",
    "GetAssessmentOrdersOpenPositiveResponseTypedDict": ".getassessmentordersopenpositiveresponse",
    "GetAssessmentPackagesGlobals": ".getassessmentpackagesop",
    "GetAssessmentPackagesGlobalsTypedDict": ".getassessmentpackagesop",
    "GetAssessmentPackagesRequest": ".getassessmentpackagesop",
    "GetAssessmentPackagesRequestTypedDict": ".getassessmentpackagesop",
    "GetAssessmentPackagesPositiveResponse": ".getassessmentpackagespositiveresponse",
    "GetAssessmentPackagesPositiveResponseData": ".getassessmentpackagespositiveresponse",
    "GetAssessmentPackagesPositiveResponseDataTypedDict": ".getassessmentpackagespositiveresponse",
    "GetAssessmentPackagesPositiveResponsePackage": ".getassessmentpackagespositiveresponse",
    "GetAssessmentPackagesPositiveResponsePackageTypedDict": ".getassessmentpackagespositiveresponse",
    "GetAssessmentPackagesPositiveResponseType": ".getassessmentpackagespositiveresponse",
    "GetAssessmentPackagesPositiveResponseTypedDict": ".getassessmentpackagespositiveresponse",
    "GetAtsApplicationsApplicationIDAttachmentsGlobals": ".getatsapplicationsapplicationidattachmentsop",
    "GetAtsApplicationsApplicationIDAttachmentsGlobalsTypedDict": ".getatsapplicationsapplicationidattachmentsop",
    "GetAtsApplicationsApplicationIDAttachmentsRequest": ".getatsapplicationsapplicationidattachmentsop",
    "GetAtsApplicationsApplicationIDAttachmentsRequestTypedDict": ".getatsapplicationsapplicationidattachmentsop",
    "GetAtsApplicationsApplicationIDAttachmentsPositiveResponse": ".getatsapplicationsapplicationidattachmentspositiveresponse",
    "GetAtsApplicationsApplicationIDAttachmentsPositiveResponseData": ".getatsapplicationsapplicationidattachmentspositiveresponse",
    "GetAtsApplicationsApplicationIDAttachmentsPositiveResponseDataTypedDict": ".getatsapplicationsapplicationidattachmentspositiveresponse",
    "GetAtsApplicationsApplicationIDAttachmentsPositiveResponseResult": ".getatsapplicationsapplicationidattachmentspositiveresponse",
    "GetAtsApplicationsApplicationIDAttachmentsPositiveResponseResultTypedDict": ".getatsapplicationsapplicationidattachmentspositiveresponse",
    "GetAtsApplicationsApplicationIDAttachmentsPositiveResponseType": ".getatsapplicationsapplicationidattachmentspositiveresponse",
    "GetAtsApplicationsApplicationIDAttachmentsPositiveResponseTypedDict": ".getatsapplicationsapplicationidattachmentspositiveresponse",
    "GetAtsApplicationsApplicationIDAttachmentsPositiveResponseWarning": ".getatsapplicationsapplicationidattachmentspositiveresponse",
    "GetAtsApplicationsApplicationIDAttachmentsPositiveResponseWarningTypedDict": ".getatsapplicationsapplicationidattachmentspositiveresponse",
    "GetAtsApplicationsGlobals": ".getatsapplicationsop",
    "GetAtsApplicationsGlobalsTypedDict": ".getatsapplicationsop",
    "GetAtsApplicationsRequest": ".getatsapplicationsop",
    "GetAtsApplicationsRequestTypedDict": ".getatsapplicationsop",
    "GetAtsApplicationsResponse": ".getatsapplicationsop",
    "GetAtsApplicationsResponseTypedDict": ".getatsapplicationsop",
    "GetAtsApplicationsPositiveResponse": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseAnswer1": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseAnswer1TypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseAnswer2": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseAnswer2TypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseAnswer3": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseAnswer3TypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseAnswer4": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseAnswer4TypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseAnswer5": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseAnswer5TypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseAnswer6": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseAnswer6TypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseAnswer7": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseAnswer7TypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseCandidate": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseCandidateTypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseCurrentStage": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseCurrentStageTypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseData": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseDataTypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseEmailAddress": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseEmailAddressTypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseJob": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseJobTypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseLocation": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseLocationTypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseOutcome": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponsePhoneNumber": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponsePhoneNumberTypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseQuestionBoolean": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseQuestionBooleanTypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseQuestionDate": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseQuestionDateTypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseQuestionMultiSelect": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseQuestionMultiSelectTypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseQuestionNumber": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseQuestionNumberTypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseQuestionSingleSelect": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseQuestionSingleSelectTypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseQuestionText": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseQuestionTextTypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseQuestionUnknown": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseQuestionUnknownTypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseResult": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseResultTypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer1": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer1TypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer2": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer2TypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer3": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer3TypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer4": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer4TypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer5": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer5TypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer6": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer6TypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer7": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswer7TypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswerUnion": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseScreeningQuestionAnswerUnionTypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseSocialMedia": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseSocialMediaTypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseStatus": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseTag": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseTagTypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationsPositiveResponseTypedDict": ".getatsapplicationspositiveresponse",
    "Interview": ".getatsapplicationspositiveresponse",
    "InterviewTypedDict": ".getatsapplicationspositiveresponse",
    "Offer": ".getatsapplicationspositiveresponse",
    "OfferTypedDict": ".getatsapplicationspositiveresponse",
    "GetAtsApplicationStagesGlobals": ".getatsapplicationstagesop",
    "GetAtsApplicationStagesGlobalsTypedDict": ".getatsapplicationstagesop",
    "GetAtsApplicationStagesRequest": ".getatsapplicationstagesop",
    "GetAtsApplicationStagesRequestTypedDict": ".getatsapplicationstagesop",
    "GetAtsApplicationStagesResponse": ".getatsapplicationstagesop",
    "GetAtsApplicationStagesResponseTypedDict": ".getatsapplicationstagesop",
    "GetAtsApplicationStagesPositiveResponse": ".getatsapplicationstagespositiveresponse",
    "GetAtsApplicationStagesPositiveResponseData": ".getatsapplicationstagespositiveresponse",
    "GetAtsApplicationStagesPositiveResponseDataTypedDict": ".getatsapplicationstagespositiveresponse",
    "GetAtsApplicationStagesPositiveResponseResult": ".getatsapplicationstagespositiveresponse",
    "GetAtsApplicationStagesPositiveResponseResultTypedDict": ".getatsapplicationstagespositiveresponse",
    "GetAtsApplicationStagesPositiveResponseTypedDict": ".getatsapplicationstagespositiveresponse",
    "GetAtsCandidatesCandidateIDAttachmentsGlobals": ".getatscandidatescandidateidattachmentsop",
    "GetAtsCandidatesCandidateIDAttachmentsGlobalsTypedDict": ".getatscandidatescandidateidattachmentsop",
    "GetAtsCandidatesCandidateIDAttachmentsRequest": ".getatscandidatescandidateidattachmentsop",
    "GetAtsCandidatesCandidateIDAttachmentsRequestTypedDict": ".getatscandidatescandidateidattachmentsop",
    "GetAtsCandidatesCandidateIDAttachmentsPositiveResponse": ".getatscandidatescandidateidattachmentspositiveresponse",
    "GetAtsCandidatesCandidateIDAttachmentsPositiveResponseData": ".getatscandidatescandidateidattachmentspositiveresponse",
    "GetAtsCandidatesCandidateIDAttachmentsPositiveResponseDataTypedDict": ".getatscandidatescandidateidattachmentspositiveresponse",
    "GetAtsCandidatesCandidateIDAttachmentsPositiveResponseResult": ".getatscandidatescandidateidattachmentspositiveresponse",
    "GetAtsCandidatesCandidateIDAttachmentsPositiveResponseResultTypedDict": ".getatscandidatescandidateidattachmentspositiveresponse",
    "GetAtsCandidatesCandidateIDAttachmentsPositiveResponseType": ".getatscandidatescandidateidattachmentspositiveresponse",
    "GetAtsCandidatesCandidateIDAttachmentsPositiveResponseTypedDict": ".getatscandidatescandidateidattachmentspositiveresponse",
    "GetAtsCandidatesCandidateIDAttachmentsPositiveResponseWarning": ".getatscandidatescandidateidattachmentspositiveresponse",
    "GetAtsCandidatesCandidateIDAttachmentsPositiveResponseWarningTypedDict": ".getatscandidatescandidateidattachmentspositiveresponse",
    "GetAtsCandidatesGlobals": ".getatscandidatesop",
    "GetAtsCandidatesGlobalsTypedDict": ".getatscandidatesop",
    "GetAtsCandidatesRequest": ".getatscandidatesop",
    "GetAtsCandidatesRequestTypedDict": ".getatscandidatesop",
    "GetAtsCandidatesResponse": ".getatscandidatesop",
    "GetAtsCandidatesResponseTypedDict": ".getatscandidatesop",
    "GetAtsCandidatesPositiveResponse": ".getatscandidatespositiveresponse",
    "GetAtsCandidatesPositiveResponseApplication": ".getatscandidatespositiveresponse",
    "GetAtsCandidatesPositiveResponseApplicationTypedDict": ".getatscandidatespositiveresponse",
    "GetAtsCandidatesPositiveResponseCurrentStage": ".getatscandidatespositiveresponse",
    "GetAtsCandidatesPositiveResponseCurrentStageTypedDict": ".getatscandidatespositiveresponse",
    "GetAtsCandidatesPositiveResponseData": ".getatscandidatespositiveresponse",
    "GetAtsCandidatesPositiveResponseDataTypedDict": ".getatscandidatespositiveresponse",
    "GetAtsCandidatesPositiveResponseEmailAddress": ".getatscandidatespositiveresponse",
    "GetAtsCandidatesPositiveResponseEmailAddressTypedDict": ".getatscandidatespositiveresponse",
    "GetAtsCandidatesPositiveResponseJob": ".getatscandidatespositiveresponse",
    "GetAtsCandidatesPositiveResponseJobTypedDict": ".getatscandidatespositiveresponse",
    "GetAtsCandidatesPositiveResponseLocation": ".getatscandidatespositiveresponse",
    "GetAtsCandidatesPositiveResponseLocationTypedDict": ".getatscandidatespositiveresponse",
    "GetAtsCandidatesPositiveResponseOutcome": ".getatscandidatespositiveresponse",
    "GetAtsCandidatesPositiveResponsePhoneNumber": ".getatscandidatespositiveresponse",
    "GetAtsCandidatesPositiveResponsePhoneNumberTypedDict": ".getatscandidatespositiveresponse",
    "GetAtsCandidatesPositiveResponseResult": ".getatscandidatespositiveresponse",
    "GetAtsCandidatesPositiveResponseResultTypedDict": ".getatscandidatespositiveresponse",
    "GetAtsCandidatesPositiveResponseSocialMedia": ".getatscandidatespositiveresponse",
    "GetAtsCandidatesPositiveResponseSocialMediaTypedDict": ".getatscandidatespositiveresponse",
    "GetAtsCandidatesPositiveResponseTag": ".getatscandidatespositiveresponse",
    "GetAtsCandidatesPositiveResponseTagTypedDict": ".getatscandidatespositiveresponse",
    "GetAtsCandidatesPositiveResponseTypedDict": ".getatscandidatespositiveresponse",
    "GetAtsInterviewsGlobals": ".getatsinterviewsop",
    "GetAtsInterviewsGlobalsTypedDict": ".getatsinterviewsop",
    "GetAtsInterviewsRequest": ".getatsinterviewsop",
    "GetAtsInterviewsRequestTypedDict": ".getatsinterviewsop",
    "GetAtsInterviewsResponse": ".getatsinterviewsop",
    "GetAtsInterviewsResponseTypedDict": ".getatsinterviewsop",
    "GetAtsInterviewsPositiveResponse": ".getatsinterviewspositiveresponse",
    "GetAtsInterviewsPositiveResponseApplication": ".getatsinterviewspositiveresponse",
    "GetAtsInterviewsPositiveResponseApplicationTypedDict": ".getatsinterviewspositiveresponse",
    "GetAtsInterviewsPositiveResponseCandidate": ".getatsinterviewspositiveresponse",
    "GetAtsInterviewsPositiveResponseCandidateTypedDict": ".getatsinterviewspositiveresponse",
    "GetAtsInterviewsPositiveResponseData": ".getatsinterviewspositiveresponse",
    "GetAtsInterviewsPositiveResponseDataTypedDict": ".getatsinterviewspositiveresponse",
    "GetAtsInterviewsPositiveResponseEmailAddress": ".getatsinterviewspositiveresponse",
    "GetAtsInterviewsPositiveResponseEmailAddressTypedDict": ".getatsinterviewspositiveresponse",
    "GetAtsInterviewsPositiveResponseJob": ".getatsinterviewspositiveresponse",
    "GetAtsInterviewsPositiveResponseJobTypedDict": ".getatsinterviewspositiveresponse",
    "GetAtsInterviewsPositiveResponseLocation": ".getatsinterviewspositiveresponse",
    "GetAtsInterviewsPositiveResponseLocationTypedDict": ".getatsinterviewspositiveresponse",
    "GetAtsInterviewsPositiveResponseOutcome": ".getatsinterviewspositiveresponse",
    "GetAtsInterviewsPositiveResponseResult": ".getatsinterviewspositiveresponse",
    "GetAtsInterviewsPositiveResponseResultTypedDict": ".getatsinterviewspositiveresponse",
    "GetAtsInterviewsPositiveResponseTypedDict": ".getatsinterviewspositiveresponse",
    "User": ".getatsinterviewspositiveresponse",
    "UserTypedDict": ".getatsinterviewspositiveresponse",
    "GetAtsJobsGlobals": ".getatsjobsop",
    "GetAtsJobsGlobalsTypedDict": ".getatsjobsop",
    "GetAtsJobsRequest": ".getatsjobsop",
    "GetAtsJobsRequestTypedDict": ".getatsjobsop",
    "GetAtsJobsResponse": ".getatsjobsop",
    "GetAtsJobsResponseTypedDict": ".getatsjobsop",
    "DisplayType1": ".getatsjobspositiveresponse",
    "DisplayType2": ".getatsjobspositiveresponse",
    "DisplayType3": ".getatsjobspositiveresponse",
    "Format": ".getatsjobspositiveresponse",
    "FormatBoolean": ".getatsjobspositiveresponse",
    "FormatBooleanTypedDict": ".getatsjobspositiveresponse",
    "FormatDate": ".getatsjobspositiveresponse",
    "FormatDateTypedDict": ".getatsjobspositiveresponse",
    "FormatFile": ".getatsjobspositiveresponse",
    "FormatFileTypedDict": ".getatsjobspositiveresponse",
    "FormatInformation": ".getatsjobspositiveresponse",
    "FormatInformationTypedDict": ".getatsjobspositiveresponse",
    "FormatMultiSelect": ".getatsjobspositiveresponse",
    "FormatMultiSelectTypedDict": ".getatsjobspositiveresponse",
    "FormatNumber": ".getatsjobspositiveresponse",
    "FormatNumberTypedDict": ".getatsjobspositiveresponse",
    "FormatSingleSelect": ".getatsjobspositiveresponse",
    "FormatSingleSelectTypedDict": ".getatsjobspositiveresponse",
    "FormatText": ".getatsjobspositiveresponse",
    "FormatTextTypedDict": ".getatsjobspositiveresponse",
    "FormatTypedDict": ".getatsjobspositiveresponse",
    "FormatUnknown": ".getatsjobspositiveresponse",
    "FormatUnknownTypedDict": ".getatsjobspositiveresponse",
    "GetAtsJobsPositiveResponse": ".getatsjobspositiveresponse",
    "GetAtsJobsPositiveResponseCategory": ".getatsjobspositiveresponse",
    "GetAtsJobsPositiveResponseData": ".getatsjobspositiveresponse",
    "GetAtsJobsPositiveResponseDataTypedDict": ".getatsjobspositiveresponse",
    "GetAtsJobsPositiveResponseEmploymentType": ".getatsjobspositiveresponse",
    "GetAtsJobsPositiveResponseHiringTeam": ".getatsjobspositiveresponse",
    "GetAtsJobsPositiveResponseHiringTeamRole": ".getatsjobspositiveresponse",
    "GetAtsJobsPositiveResponseHiringTeamTypedDict": ".getatsjobspositiveresponse",
    "GetAtsJobsPositiveResponseLocation": ".getatsjobspositiveresponse",
    "GetAtsJobsPositiveResponseLocationTypedDict": ".getatsjobspositiveresponse",
    "GetAtsJobsPositiveResponseResult": ".getatsjobspositiveresponse",
    "GetAtsJobsPositiveResponseResultTypedDict": ".getatsjobspositiveresponse",
    "GetAtsJobsPositiveResponseStatus": ".getatsjobspositiveresponse",
    "GetAtsJobsPositiveResponseTypedDict": ".getatsjobspositiveresponse",
    "JobPosting": ".getatsjobspositiveresponse",
    "JobPostingStatus": ".getatsjobspositiveresponse",
    "JobPostingTypedDict": ".getatsjobspositiveresponse",
    "JobPostingVisibility": ".getatsjobspositiveresponse",
    "Option1": ".getatsjobspositiveresponse",
    "Option1TypedDict": ".getatsjobspositiveresponse",
    "Option2": ".getatsjobspositiveresponse",
    "Option2TypedDict": ".getatsjobspositiveresponse",
    "PreconditionOptions": ".getatsjobspositiveresponse",
    "PreconditionOptionsTypedDict": ".getatsjobspositiveresponse",
    "RemoteWorkStatus": ".getatsjobspositiveresponse",
    "SalaryPeriod": ".getatsjobspositiveresponse",
    "ScreeningQuestion": ".getatsjobspositiveresponse",
    "ScreeningQuestionTypedDict": ".getatsjobspositiveresponse",
    "Stage": ".getatsjobspositiveresponse",
    "StageTypedDict": ".getatsjobspositiveresponse",
    "Visibility": ".getatsjobspositiveresponse",
    "GetAtsOffersGlobals": ".getatsoffersop",
    "GetAtsOffersGlobalsTypedDict": ".getatsoffersop",
    "GetAtsOffersRequest": ".getatsoffersop",
    "GetAtsOffersRequestTypedDict": ".getatsoffersop",
    "GetAtsOffersResponse": ".getatsoffersop",
    "GetAtsOffersResponseTypedDict": ".getatsoffersop",
    "GetAtsOffersPositiveResponse": ".getatsofferspositiveresponse",
    "GetAtsOffersPositiveResponseApplication": ".getatsofferspositiveresponse",
    "GetAtsOffersPositiveResponseApplicationTypedDict": ".getatsofferspositiveresponse",
    "GetAtsOffersPositiveResponseCandidate": ".getatsofferspositiveresponse",
    "GetAtsOffersPositiveResponseCandidateTypedDict": ".getatsofferspositiveresponse",
    "GetAtsOffersPositiveResponseData": ".getatsofferspositiveresponse",
    "GetAtsOffersPositiveResponseDataTypedDict": ".getatsofferspositiveresponse",
    "GetAtsOffersPositiveResponseEmailAddress": ".getatsofferspositiveresponse",
    "GetAtsOffersPositiveResponseEmailAddressTypedDict": ".getatsofferspositiveresponse",
    "GetAtsOffersPositiveResponseJob": ".getatsofferspositiveresponse",
    "GetAtsOffersPositiveResponseJobTypedDict": ".getatsofferspositiveresponse",
    "GetAtsOffersPositiveResponseResult": ".getatsofferspositiveresponse",
    "GetAtsOffersPositiveResponseResultTypedDict": ".getatsofferspositiveresponse",
    "GetAtsOffersPositiveResponseStatus": ".getatsofferspositiveresponse",
    "GetAtsOffersPositiveResponseTypedDict": ".getatsofferspositiveresponse",
    "GetAtsRejectionReasonsGlobals": ".getatsrejectionreasonsop",
    "GetAtsRejectionReasonsGlobalsTypedDict": ".getatsrejectionreasonsop",
    "GetAtsRejectionReasonsRequest": ".getatsrejectionreasonsop",
    "GetAtsRejectionReasonsRequestTypedDict": ".getatsrejectionreasonsop",
    "GetAtsRejectionReasonsResponse": ".getatsrejectionreasonsop",
    "GetAtsRejectionReasonsResponseTypedDict": ".getatsrejectionreasonsop",
    "GetAtsRejectionReasonsPositiveResponse": ".getatsrejectionreasonspositiveresponse",
    "GetAtsRejectionReasonsPositiveResponseData": ".getatsrejectionreasonspositiveresponse",
    "GetAtsRejectionReasonsPositiveResponseDataTypedDict": ".getatsrejectionreasonspositiveresponse",
    "GetAtsRejectionReasonsPositiveResponseResult": ".getatsrejectionreasonspositiveresponse",
    "GetAtsRejectionReasonsPositiveResponseResultTypedDict": ".getatsrejectionreasonspositiveresponse",
    "GetAtsRejectionReasonsPositiveResponseTypedDict": ".getatsrejectionreasonspositiveresponse",
    "GetAtsTagsGlobals": ".getatstagsop",
    "GetAtsTagsGlobalsTypedDict": ".getatstagsop",
    "GetAtsTagsRequest": ".getatstagsop",
    "GetAtsTagsRequestTypedDict": ".getatstagsop",
    "GetAtsTagsResponse": ".getatstagsop",
    "GetAtsTagsResponseTypedDict": ".getatstagsop",
    "GetAtsTagsPositiveResponse": ".getatstagspositiveresponse",
    "GetAtsTagsPositiveResponseData": ".getatstagspositiveresponse",
    "GetAtsTagsPositiveResponseDataTypedDict": ".getatstagspositiveresponse",
    "GetAtsTagsPositiveResponseResult": ".getatstagspositiveresponse",
    "GetAtsTagsPositiveResponseResultTypedDict": ".getatstagspositiveresponse",
    "GetAtsTagsPositiveResponseTypedDict": ".getatstagspositiveresponse",
    "GetAtsUsersGlobals": ".getatsusersop",
    "GetAtsUsersGlobalsTypedDict": ".getatsusersop",
    "GetAtsUsersRequest": ".getatsusersop",
    "GetAtsUsersRequestTypedDict": ".getatsusersop",
    "GetAtsUsersResponse": ".getatsusersop",
    "GetAtsUsersResponseTypedDict": ".getatsusersop",
    "GetAtsUsersPositiveResponse": ".getatsuserspositiveresponse",
    "GetAtsUsersPositiveResponseData": ".getatsuserspositiveresponse",
    "GetAtsUsersPositiveResponseDataTypedDict": ".getatsuserspositiveresponse",
    "GetAtsUsersPositiveResponseResult": ".getatsuserspositiveresponse",
    "GetAtsUsersPositiveResponseResultTypedDict": ".getatsuserspositiveresponse",
    "GetAtsUsersPositiveResponseStatus": ".getatsuserspositiveresponse",
    "GetAtsUsersPositiveResponseTypedDict": ".getatsuserspositiveresponse",
    "GetCheckAPIKeyPositiveResponse": ".getcheckapikeypositiveresponse",
    "GetCheckAPIKeyPositiveResponseData": ".getcheckapikeypositiveresponse",
    "GetCheckAPIKeyPositiveResponseDataTypedDict": ".getcheckapikeypositiveresponse",
    "GetCheckAPIKeyPositiveResponseTypedDict": ".getcheckapikeypositiveresponse",
    "GetConnectIntegrationByTokenTokenRequest": ".getconnectintegrationbytokentokenop",
    "GetConnectIntegrationByTokenTokenRequestTypedDict": ".getconnectintegrationbytokentokenop",
    "GetConnectIntegrationByTokenTokenPositiveResponse": ".getconnectintegrationbytokentokenpositiveresponse",
    "GetConnectIntegrationByTokenTokenPositiveResponseData": ".getconnectintegrationbytokentokenpositiveresponse",
    "GetConnectIntegrationByTokenTokenPositiveResponseDataTypedDict": ".getconnectintegrationbytokentokenpositiveresponse",
    "GetConnectIntegrationByTokenTokenPositiveResponseSetupStatus": ".getconnectintegrationbytokentokenpositiveresponse",
    "GetConnectIntegrationByTokenTokenPositiveResponseTypedDict": ".getconnectintegrationbytokentokenpositiveresponse",
    "GetHrisAbsencesGlobals": ".gethrisabsencesop",
    "GetHrisAbsencesGlobalsTypedDict": ".gethrisabsencesop",
    "GetHrisAbsencesRequest": ".gethrisabsencesop",
    "GetHrisAbsencesRequestTypedDict": ".gethrisabsencesop",
    "GetHrisAbsencesResponse": ".gethrisabsencesop",
    "GetHrisAbsencesResponseTypedDict": ".gethrisabsencesop",
    "GetHrisAbsencesPositiveResponse": ".gethrisabsencespositiveresponse",
    "GetHrisAbsencesPositiveResponseData": ".gethrisabsencespositiveresponse",
    "GetHrisAbsencesPositiveResponseDataTypedDict": ".gethrisabsencespositiveresponse",
    "GetHrisAbsencesPositiveResponseResult": ".gethrisabsencespositiveresponse",
    "GetHrisAbsencesPositiveResponseResultTypedDict": ".gethrisabsencespositiveresponse",
    "GetHrisAbsencesPositiveResponseStatus": ".gethrisabsencespositiveresponse",
    "GetHrisAbsencesPositiveResponseType": ".gethrisabsencespositiveresponse",
    "GetHrisAbsencesPositiveResponseTypeTypedDict": ".gethrisabsencespositiveresponse",
    "GetHrisAbsencesPositiveResponseTypeUnit": ".gethrisabsencespositiveresponse",
    "GetHrisAbsencesPositiveResponseTypedDict": ".gethrisabsencespositiveresponse",
    "GetHrisAbsencesPositiveResponseUnit": ".gethrisabsencespositiveresponse",
    "GetHrisAbsenceTypesGlobals": ".gethrisabsencetypesop",
    "GetHrisAbsenceTypesGlobalsTypedDict": ".gethrisabsencetypesop",
    "GetHrisAbsenceTypesRequest": ".gethrisabsencetypesop",
    "GetHrisAbsenceTypesRequestTypedDict": ".gethrisabsencetypesop",
    "GetHrisAbsenceTypesResponse": ".gethrisabsencetypesop",
    "GetHrisAbsenceTypesResponseTypedDict": ".gethrisabsencetypesop",
    "GetHrisAbsenceTypesPositiveResponse": ".gethrisabsencetypespositiveresponse",
    "GetHrisAbsenceTypesPositiveResponseData": ".gethrisabsencetypespositiveresponse",
    "GetHrisAbsenceTypesPositiveResponseDataTypedDict": ".gethrisabsencetypespositiveresponse",
    "GetHrisAbsenceTypesPositiveResponseResult": ".gethrisabsencetypespositiveresponse",
    "GetHrisAbsenceTypesPositiveResponseResultTypedDict": ".gethrisabsencetypespositiveresponse",
    "GetHrisAbsenceTypesPositiveResponseTypedDict": ".gethrisabsencetypespositiveresponse",
    "GetHrisAbsenceTypesPositiveResponseUnit": ".gethrisabsencetypespositiveresponse",
    "GetHrisEmployeeDocumentCategoriesGlobals": ".gethrisemployeedocumentcategoriesop",
    "GetHrisEmployeeDocumentCategoriesGlobalsTypedDict": ".gethrisemployeedocumentcategoriesop",
    "GetHrisEmployeeDocumentCategoriesRequest": ".gethrisemployeedocumentcategoriesop",
    "GetHrisEmployeeDocumentCategoriesRequestTypedDict": ".gethrisemployeedocumentcategoriesop",
    "GetHrisEmployeeDocumentCategoriesResponse": ".gethrisemployeedocumentcategoriesop",
    "GetHrisEmployeeDocumentCategoriesResponseTypedDict": ".gethrisemployeedocumentcategoriesop",
    "GetHrisEmployeeDocumentCategoriesPositiveResponse": ".gethrisemployeedocumentcategoriespositiveresponse",
    "GetHrisEmployeeDocumentCategoriesPositiveResponseData": ".gethrisemployeedocumentcategoriespositiveresponse",
    "GetHrisEmployeeDocumentCategoriesPositiveResponseDataTypedDict": ".gethrisemployeedocumentcategoriespositiveresponse",
    "GetHrisEmployeeDocumentCategoriesPositiveResponseResult": ".gethrisemployeedocumentcategoriespositiveresponse",
    "GetHrisEmployeeDocumentCategoriesPositiveResponseResultTypedDict": ".gethrisemployeedocumentcategoriespositiveresponse",
    "GetHrisEmployeeDocumentCategoriesPositiveResponseTypedDict": ".gethrisemployeedocumentcategoriespositiveresponse",
    "GetHrisEmployeesFormGlobals": ".gethrisemployeesformop",
    "GetHrisEmployeesFormGlobalsTypedDict": ".gethrisemployeesformop",
    "GetHrisEmployeesFormRequest": ".gethrisemployeesformop",
    "GetHrisEmployeesFormRequestTypedDict": ".gethrisemployeesformop",
    "GetHrisEmployeesFormPositiveResponse": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseData": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseDataTypedDict": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseEntry1": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseEntry1TypedDict": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseEntry2": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseEntry2TypedDict": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseFileRestrictions": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseFileRestrictionsTypedDict": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseOptionsInline1": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseOptionsInline1TypedDict": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseOptionsInline2": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseOptionsInline2TypedDict": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseOptionsReferenced1": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseOptionsReferenced1TypedDict": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseOptionsReferenced2": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseOptionsReferenced2TypedDict": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseOptionsUnion1": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseOptionsUnion1TypedDict": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseOptionsUnion2": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseOptionsUnion2TypedDict": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseRemoteID1": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseRemoteID1TypedDict": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseRemoteID2": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseRemoteID2TypedDict": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseTypedDict": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseUnifiedKey1": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseUnifiedKey2": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseUnifiedKey3": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseUnifiedKey4": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseUnifiedKey5": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseUnifiedKey6": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseUnifiedKey7": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseUnifiedKey8": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseWarning": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesFormPositiveResponseWarningTypedDict": ".gethrisemployeesformpositiveresponse",
    "Properties": ".gethrisemployeesformpositiveresponse",
    "PropertiesArray": ".gethrisemployeesformpositiveresponse",
    "PropertiesArrayTypedDict": ".gethrisemployeesformpositiveresponse",
    "PropertiesCheckbox": ".gethrisemployeesformpositiveresponse",
    "PropertiesCheckboxTypedDict": ".gethrisemployeesformpositiveresponse",
    "PropertiesDate": ".gethrisemployeesformpositiveresponse",
    "PropertiesDateTypedDict": ".gethrisemployeesformpositiveresponse",
    "PropertiesFile": ".gethrisemployeesformpositiveresponse",
    "PropertiesFileTypedDict": ".gethrisemployeesformpositiveresponse",
    "PropertiesMultiSelect": ".gethrisemployeesformpositiveresponse",
    "PropertiesMultiSelectTypedDict": ".gethrisemployeesformpositiveresponse",
    "PropertiesNumber": ".gethrisemployeesformpositiveresponse",
    "PropertiesNumberTypedDict": ".gethrisemployeesformpositiveresponse",
    "PropertiesObject": ".gethrisemployeesformpositiveresponse",
    "PropertiesObjectTypedDict": ".gethrisemployeesformpositiveresponse",
    "PropertiesSingleSelect": ".gethrisemployeesformpositiveresponse",
    "PropertiesSingleSelectTypedDict": ".gethrisemployeesformpositiveresponse",
    "PropertiesText": ".gethrisemployeesformpositiveresponse",
    "PropertiesTextTypedDict": ".gethrisemployeesformpositiveresponse",
    "PropertiesTypedDict": ".gethrisemployeesformpositiveresponse",
    "GetHrisEmployeesGlobals": ".gethrisemployeesop",
    "GetHrisEmployeesGlobalsTypedDict": ".gethrisemployeesop",
    "GetHrisEmployeesRequest": ".gethrisemployeesop",
    "GetHrisEmployeesRequestTypedDict": ".gethrisemployeesop",
    "GetHrisEmployeesResponse": ".gethrisemployeesop",
    "GetHrisEmployeesResponseTypedDict": ".gethrisemployeesop",
    "BankAccount": ".gethrisemployeespositiveresponse",
    "BankAccountTypedDict": ".gethrisemployeespositiveresponse",
    "DomesticBankRouting": ".gethrisemployeespositiveresponse",
    "DomesticBankRoutingType": ".gethrisemployeespositiveresponse",
    "DomesticBankRoutingTypedDict": ".gethrisemployeespositiveresponse",
    "Employment": ".gethrisemployeespositiveresponse",
    "EmploymentEmploymentType": ".gethrisemployeespositiveresponse",
    "EmploymentStatus": ".gethrisemployeespositiveresponse",
    "EmploymentTypedDict": ".gethrisemployeespositiveresponse",
    "Ethnicity": ".gethrisemployeespositiveresponse",
    "GetHrisEmployeesPositiveResponse": ".gethrisemployeespositiveresponse",
    "GetHrisEmployeesPositiveResponseBalanceUnit": ".gethrisemployeespositiveresponse",
    "GetHrisEmployeesPositiveResponseData": ".gethrisemployeespositiveresponse",
    "GetHrisEmployeesPositiveResponseDataTypedDict": ".gethrisemployeespositiveresponse",
    "GetHrisEmployeesPositiveResponseEmploymentType": ".gethrisemployeespositiveresponse",
    "GetHrisEmployeesPositiveResponseGender": ".gethrisemployeespositiveresponse",
    "GetHrisEmployeesPositiveResponsePayFrequency": ".gethrisemployeespositiveresponse",
    "GetHrisEmployeesPositiveResponsePayPeriod": ".gethrisemployeespositiveresponse",
    "GetHrisEmployeesPositiveResponseResult": ".gethrisemployeespositiveresponse",
    "GetHrisEmployeesPositiveResponseResultTypedDict": ".gethrisemployeespositiveresponse",
    "GetHrisEmployeesPositiveResponseTypedDict": ".gethrisemployeespositiveresponse",
    "GetHrisEmployeesPositiveResponseUsedUnit": ".gethrisemployeespositiveresponse",
    "Group": ".gethrisemployeespositiveresponse",
    "GroupType": ".gethrisemployeespositiveresponse",
    "GroupTypedDict": ".gethrisemployeespositiveresponse",
    "HomeAddress": ".gethrisemployeespositiveresponse",
    "HomeAddressTypedDict": ".gethrisemployeespositiveresponse",
    "LegalEntity": ".gethrisemployeespositiveresponse",
    "LegalEntityAddress": ".gethrisemployeespositiveresponse",
    "LegalEntityAddressTypedDict": ".gethrisemployeespositiveresponse",
    "LegalEntityTypedDict": ".gethrisemployeespositiveresponse",
    "Manager": ".gethrisemployeespositiveresponse",
    "ManagerEmploymentStatus": ".gethrisemployeespositiveresponse",
    "ManagerTypedDict": ".gethrisemployeespositiveresponse",
    "MaritalStatus": ".gethrisemployeespositiveresponse",
    "TimeOffBalance": ".gethrisemployeespositiveresponse",
    "TimeOffBalanceTypedDict": ".gethrisemployeespositiveresponse",
    "WorkLocation": ".gethrisemployeespositiveresponse",
    "WorkLocationAddress": ".gethrisemployeespositiveresponse",
    "WorkLocationAddressTypedDict": ".gethrisemployeespositiveresponse",
    "WorkLocationTypedDict": ".gethrisemployeespositiveresponse",
    "GetHrisEmploymentsGlobals": ".gethrisemploymentsop",
    "GetHrisEmploymentsGlobalsTypedDict": ".gethrisemploymentsop",
    "GetHrisEmploymentsRequest": ".gethrisemploymentsop",
    "GetHrisEmploymentsRequestTypedDict": ".gethrisemploymentsop",
    "GetHrisEmploymentsResponse": ".gethrisemploymentsop",
    "GetHrisEmploymentsResponseTypedDict": ".gethrisemploymentsop",
    "GetHrisEmploymentsPositiveResponse": ".gethrisemploymentspositiveresponse",
    "GetHrisEmploymentsPositiveResponseData": ".gethrisemploymentspositiveresponse",
    "GetHrisEmploymentsPositiveResponseDataTypedDict": ".gethrisemploymentspositiveresponse",
    "GetHrisEmploymentsPositiveResponseEmploymentType": ".gethrisemploymentspositiveresponse",
    "GetHrisEmploymentsPositiveResponsePayFrequency": ".gethrisemploymentspositiveresponse",
    "GetHrisEmploymentsPositiveResponsePayPeriod": ".gethrisemploymentspositiveresponse",
    "GetHrisEmploymentsPositiveResponseResult": ".gethrisemploymentspositiveresponse",
    "GetHrisEmploymentsPositiveResponseResultTypedDict": ".gethrisemploymentspositiveresponse",
    "GetHrisEmploymentsPositiveResponseTypedDict": ".gethrisemploymentspositiveresponse",
    "GetHrisGroupsGlobals": ".gethrisgroupsop",
    "GetHrisGroupsGlobalsTypedDict": ".gethrisgroupsop",
    "GetHrisGroupsRequest": ".gethrisgroupsop",
    "GetHrisGroupsRequestTypedDict": ".gethrisgroupsop",
    "GetHrisGroupsResponse": ".gethrisgroupsop",
    "GetHrisGroupsResponseTypedDict": ".gethrisgroupsop",
    "GetHrisGroupsPositiveResponse": ".gethrisgroupspositiveresponse",
    "GetHrisGroupsPositiveResponseData": ".gethrisgroupspositiveresponse",
    "GetHrisGroupsPositiveResponseDataTypedDict": ".gethrisgroupspositiveresponse",
    "GetHrisGroupsPositiveResponseResult": ".gethrisgroupspositiveresponse",
    "GetHrisGroupsPositiveResponseResultTypedDict": ".gethrisgroupspositiveresponse",
    "GetHrisGroupsPositiveResponseType": ".gethrisgroupspositiveresponse",
    "GetHrisGroupsPositiveResponseTypedDict": ".gethrisgroupspositiveresponse",
    "GetHrisLegalEntitiesGlobals": ".gethrislegalentitiesop",
    "GetHrisLegalEntitiesGlobalsTypedDict": ".gethrislegalentitiesop",
    "GetHrisLegalEntitiesRequest": ".gethrislegalentitiesop",
    "GetHrisLegalEntitiesRequestTypedDict": ".gethrislegalentitiesop",
    "GetHrisLegalEntitiesResponse": ".gethrislegalentitiesop",
    "GetHrisLegalEntitiesResponseTypedDict": ".gethrislegalentitiesop",
    "GetHrisLegalEntitiesPositiveResponse": ".gethrislegalentitiespositiveresponse",
    "GetHrisLegalEntitiesPositiveResponseAddress": ".gethrislegalentitiespositiveresponse",
    "GetHrisLegalEntitiesPositiveResponseAddressTypedDict": ".gethrislegalentitiespositiveresponse",
    "GetHrisLegalEntitiesPositiveResponseData": ".gethrislegalentitiespositiveresponse",
    "GetHrisLegalEntitiesPositiveResponseDataTypedDict": ".gethrislegalentitiespositiveresponse",
    "GetHrisLegalEntitiesPositiveResponseResult": ".gethrislegalentitiespositiveresponse",
    "GetHrisLegalEntitiesPositiveResponseResultTypedDict": ".gethrislegalentitiespositiveresponse",
    "GetHrisLegalEntitiesPositiveResponseTypedDict": ".gethrislegalentitiespositiveresponse",
    "GetHrisLocationsGlobals": ".gethrislocationsop",
    "GetHrisLocationsGlobalsTypedDict": ".gethrislocationsop",
    "GetHrisLocationsRequest": ".gethrislocationsop",
    "GetHrisLocationsRequestTypedDict": ".gethrislocationsop",
    "GetHrisLocationsResponse": ".gethrislocationsop",
    "GetHrisLocationsResponseTypedDict": ".gethrislocationsop",
    "GetHrisLocationsPositiveResponse": ".gethrislocationspositiveresponse",
    "GetHrisLocationsPositiveResponseAddress": ".gethrislocationspositiveresponse",
    "GetHrisLocationsPositiveResponseAddressTypedDict": ".gethrislocationspositiveresponse",
    "GetHrisLocationsPositiveResponseData": ".gethrislocationspositiveresponse",
    "GetHrisLocationsPositiveResponseDataTypedDict": ".gethrislocationspositiveresponse",
    "GetHrisLocationsPositiveResponseResult": ".gethrislocationspositiveresponse",
    "GetHrisLocationsPositiveResponseResultTypedDict": ".gethrislocationspositiveresponse",
    "GetHrisLocationsPositiveResponseTypedDict": ".gethrislocationspositiveresponse",
    "GetHrisPerformanceReviewCyclesGlobals": ".gethrisperformancereviewcyclesop",
    "GetHrisPerformanceReviewCyclesGlobalsTypedDict": ".gethrisperformancereviewcyclesop",
    "GetHrisPerformanceReviewCyclesRequest": ".gethrisperformancereviewcyclesop",
    "GetHrisPerformanceReviewCyclesRequestTypedDict": ".gethrisperformancereviewcyclesop",
    "GetHrisPerformanceReviewCyclesResponse": ".gethrisperformancereviewcyclesop",
    "GetHrisPerformanceReviewCyclesResponseTypedDict": ".gethrisperformancereviewcyclesop",
    "GetHrisPerformanceReviewCyclesPositiveResponse": ".gethrisperformancereviewcyclespositiveresponse",
    "GetHrisPerformanceReviewCyclesPositiveResponseData": ".gethrisperformancereviewcyclespositiveresponse",
    "GetHrisPerformanceReviewCyclesPositiveResponseDataTypedDict": ".gethrisperformancereviewcyclespositiveresponse",
    "GetHrisPerformanceReviewCyclesPositiveResponseResult": ".gethrisperformancereviewcyclespositiveresponse",
    "GetHrisPerformanceReviewCyclesPositiveResponseResultTypedDict": ".gethrisperformancereviewcyclespositiveresponse",
    "GetHrisPerformanceReviewCyclesPositiveResponseTypedDict": ".gethrisperformancereviewcyclespositiveresponse",
    "GetHrisPerformanceReviewsGlobals": ".gethrisperformancereviewsop",
    "GetHrisPerformanceReviewsGlobalsTypedDict": ".gethrisperformancereviewsop",
    "GetHrisPerformanceReviewsRequest": ".gethrisperformancereviewsop",
    "GetHrisPerformanceReviewsRequestTypedDict": ".gethrisperformancereviewsop",
    "GetHrisPerformanceReviewsResponse": ".gethrisperformancereviewsop",
    "GetHrisPerformanceReviewsResponseTypedDict": ".gethrisperformancereviewsop",
    "GetHrisPerformanceReviewsPositiveResponse": ".gethrisperformancereviewspositiveresponse",
    "GetHrisPerformanceReviewsPositiveResponseData": ".gethrisperformancereviewspositiveresponse",
    "GetHrisPerformanceReviewsPositiveResponseDataTypedDict": ".gethrisperformancereviewspositiveresponse",
    "GetHrisPerformanceReviewsPositiveResponseResult": ".gethrisperformancereviewspositiveresponse",
    "GetHrisPerformanceReviewsPositiveResponseResultTypedDict": ".gethrisperformancereviewspositiveresponse",
    "GetHrisPerformanceReviewsPositiveResponseType": ".gethrisperformancereviewspositiveresponse",
    "GetHrisPerformanceReviewsPositiveResponseTypedDict": ".gethrisperformancereviewspositiveresponse",
    "ReviewCycle": ".gethrisperformancereviewspositiveresponse",
    "ReviewCycleTypedDict": ".gethrisperformancereviewspositiveresponse",
    "Reviewee": ".gethrisperformancereviewspositiveresponse",
    "RevieweeTypedDict": ".gethrisperformancereviewspositiveresponse",
    "Reviewer": ".gethrisperformancereviewspositiveresponse",
    "ReviewerTypedDict": ".gethrisperformancereviewspositiveresponse",
    "SummaryRating": ".gethrisperformancereviewspositiveresponse",
    "SummaryRatingNumeric": ".gethrisperformancereviewspositiveresponse",
    "SummaryRatingNumericTypedDict": ".gethrisperformancereviewspositiveresponse",
    "SummaryRatingSingleSelect": ".gethrisperformancereviewspositiveresponse",
    "SummaryRatingSingleSelectTypedDict": ".gethrisperformancereviewspositiveresponse",
    "SummaryRatingTypedDict": ".gethrisperformancereviewspositiveresponse",
    "GetHrisTimeOffBalancesGlobals": ".gethristimeoffbalancesop",
    "GetHrisTimeOffBalancesGlobalsTypedDict": ".gethristimeoffbalancesop",
    "GetHrisTimeOffBalancesRequest": ".gethristimeoffbalancesop",
    "GetHrisTimeOffBalancesRequestTypedDict": ".gethristimeoffbalancesop",
    "GetHrisTimeOffBalancesResponse": ".gethristimeoffbalancesop",
    "GetHrisTimeOffBalancesResponseTypedDict": ".gethristimeoffbalancesop",
    "GetHrisTimeOffBalancesPositiveResponse": ".gethristimeoffbalancespositiveresponse",
    "GetHrisTimeOffBalancesPositiveResponseBalanceUnit": ".gethristimeoffbalancespositiveresponse",
    "GetHrisTimeOffBalancesPositiveResponseData": ".gethristimeoffbalancespositiveresponse",
    "GetHrisTimeOffBalancesPositiveResponseDataTypedDict": ".gethristimeoffbalancespositiveresponse",
    "GetHrisTimeOffBalancesPositiveResponseResult": ".gethristimeoffbalancespositiveresponse",
    "GetHrisTimeOffBalancesPositiveResponseResultTypedDict": ".gethristimeoffbalancespositiveresponse",
    "GetHrisTimeOffBalancesPositiveResponseType": ".gethristimeoffbalancespositiveresponse",
    "GetHrisTimeOffBalancesPositiveResponseTypeTypedDict": ".gethristimeoffbalancespositiveresponse",
    "GetHrisTimeOffBalancesPositiveResponseTypedDict": ".gethristimeoffbalancespositiveresponse",
    "GetHrisTimeOffBalancesPositiveResponseUnit": ".gethristimeoffbalancespositiveresponse",
    "GetHrisTimeOffBalancesPositiveResponseUsedUnit": ".gethristimeoffbalancespositiveresponse",
    "GetHrisTimesheetsGlobals": ".gethristimesheetsop",
    "GetHrisTimesheetsGlobalsTypedDict": ".gethristimesheetsop",
    "GetHrisTimesheetsRequest": ".gethristimesheetsop",
    "GetHrisTimesheetsRequestTypedDict": ".gethristimesheetsop",
    "GetHrisTimesheetsResponse": ".gethristimesheetsop",
    "GetHrisTimesheetsResponseTypedDict": ".gethristimesheetsop",
    "Break": ".gethristimesheetspositiveresponse",
    "BreakTypedDict": ".gethristimesheetspositiveresponse",
    "GetHrisTimesheetsPositiveResponse": ".gethristimesheetspositiveresponse",
    "GetHrisTimesheetsPositiveResponseData": ".gethristimesheetspositiveresponse",
    "GetHrisTimesheetsPositiveResponseDataTypedDict": ".gethristimesheetspositiveresponse",
    "GetHrisTimesheetsPositiveResponseResult": ".gethristimesheetspositiveresponse",
    "GetHrisTimesheetsPositiveResponseResultTypedDict": ".gethristimesheetspositiveresponse",
    "GetHrisTimesheetsPositiveResponseTypedDict": ".gethristimesheetspositiveresponse",
    "GetIntegrationsIntegrationIDCustomFieldsRequest": ".getintegrationsintegrationidcustomfieldsop",
    "GetIntegrationsIntegrationIDCustomFieldsRequestTypedDict": ".getintegrationsintegrationidcustomfieldsop",
    "GetIntegrationsIntegrationIDCustomFieldsResponse": ".getintegrationsintegrationidcustomfieldsop",
    "GetIntegrationsIntegrationIDCustomFieldsResponseTypedDict": ".getintegrationsintegrationidcustomfieldsop",
    "GetIntegrationsIntegrationIDCustomFieldsPositiveResponse": ".getintegrationsintegrationidcustomfieldspositiveresponse",
    "GetIntegrationsIntegrationIDCustomFieldsPositiveResponseData": ".getintegrationsintegrationidcustomfieldspositiveresponse",
    "GetIntegrationsIntegrationIDCustomFieldsPositiveResponseDataTypedDict": ".getintegrationsintegrationidcustomfieldspositiveresponse",
    "GetIntegrationsIntegrationIDCustomFieldsPositiveResponseIntegrationField": ".getintegrationsintegrationidcustomfieldspositiveresponse",
    "GetIntegrationsIntegrationIDCustomFieldsPositiveResponseIntegrationFieldTypedDict": ".getintegrationsintegrationidcustomfieldspositiveresponse",
    "GetIntegrationsIntegrationIDCustomFieldsPositiveResponseResult": ".getintegrationsintegrationidcustomfieldspositiveresponse",
    "GetIntegrationsIntegrationIDCustomFieldsPositiveResponseResultTypedDict": ".getintegrationsintegrationidcustomfieldspositiveresponse",
    "GetIntegrationsIntegrationIDCustomFieldsPositiveResponseType": ".getintegrationsintegrationidcustomfieldspositiveresponse",
    "GetIntegrationsIntegrationIDCustomFieldsPositiveResponseTypedDict": ".getintegrationsintegrationidcustomfieldspositiveresponse",
    "GetIntegrationsIntegrationIDIntegrationFieldsRequest": ".getintegrationsintegrationidintegrationfieldsop",
    "GetIntegrationsIntegrationIDIntegrationFieldsRequestTypedDict": ".getintegrationsintegrationidintegrationfieldsop",
    "GetIntegrationsIntegrationIDIntegrationFieldsResponse": ".getintegrationsintegrationidintegrationfieldsop",
    "GetIntegrationsIntegrationIDIntegrationFieldsResponseTypedDict": ".getintegrationsintegrationidintegrationfieldsop",
    "GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponse": ".getintegrationsintegrationidintegrationfieldspositiveresponse",
    "GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseData": ".getintegrationsintegrationidintegrationfieldspositiveresponse",
    "GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseDataTypedDict": ".getintegrationsintegrationidintegrationfieldspositiveresponse",
    "GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseResult": ".getintegrationsintegrationidintegrationfieldspositiveresponse",
    "GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseResultTypedDict": ".getintegrationsintegrationidintegrationfieldspositiveresponse",
    "GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseType": ".getintegrationsintegrationidintegrationfieldspositiveresponse",
    "GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseTypedDict": ".getintegrationsintegrationidintegrationfieldspositiveresponse",
    "GetIntegrationsIntegrationIDRequest": ".getintegrationsintegrationidop",
    "GetIntegrationsIntegrationIDRequestTypedDict": ".getintegrationsintegrationidop",
    "FieldScopeConfigSetting": ".getintegrationsintegrationidpositiveresponse",
    "GetIntegrationsIntegrationIDPositiveResponse": ".getintegrationsintegrationidpositiveresponse",
    "GetIntegrationsIntegrationIDPositiveResponseCategory": ".getintegrationsintegrationidpositiveresponse",
    "GetIntegrationsIntegrationIDPositiveResponseCoverageStatus": ".getintegrationsintegrationidpositiveresponse",
    "GetIntegrationsIntegrationIDPositiveResponseData": ".getintegrationsintegrationidpositiveresponse",
    "GetIntegrationsIntegrationIDPositiveResponseDataTypedDict": ".getintegrationsintegrationidpositiveresponse",
    "GetIntegrationsIntegrationIDPositiveResponseEndUser": ".getintegrationsintegrationidpositiveresponse",
    "GetIntegrationsIntegrationIDPositiveResponseEndUserTypedDict": ".getintegrationsintegrationidpositiveresponse",
    "GetIntegrationsIntegrationIDPositiveResponseField": ".getintegrationsintegrationidpositiveresponse",
    "GetIntegrationsIntegrationIDPositiveResponseFieldCoverageStatus": ".getintegrationsintegrationidpositiveresponse",
    "GetIntegrationsIntegrationIDPositiveResponseFieldTypedDict": ".getintegrationsintegrationidpositiveresponse",
    "GetIntegrationsIntegrationIDPositiveResponseReadModel": ".getintegrationsintegrationidpositiveresponse",
    "GetIntegrationsIntegrationIDPositiveResponseReadModelTypedDict": ".getintegrationsintegrationidpositiveresponse",
    "GetIntegrationsIntegrationIDPositiveResponseSetupStatus": ".getintegrationsintegrationidpositiveresponse",
    "GetIntegrationsIntegrationIDPositiveResponseStatus": ".getintegrationsintegrationidpositiveresponse",
    "GetIntegrationsIntegrationIDPositiveResponseTool": ".getintegrationsintegrationidpositiveresponse",
    "GetIntegrationsIntegrationIDPositiveResponseToolTypedDict": ".getintegrationsintegrationidpositiveresponse",
    "GetIntegrationsIntegrationIDPositiveResponseTypedDict": ".getintegrationsintegrationidpositiveresponse",
    "ScopeConfig": ".getintegrationsintegrationidpositiveresponse",
    "ScopeConfigSetting": ".getintegrationsintegrationidpositiveresponse",
    "ScopeConfigTypedDict": ".getintegrationsintegrationidpositiveresponse",
    "GetToolsCategoryRequest": ".gettoolscategoryop",
    "GetToolsCategoryRequestTypedDict": ".gettoolscategoryop",
    "GetToolsCategoryParameterCategory": ".gettoolscategoryparametercategory",
    "Assets": ".gettoolscategorypositiveresponse",
    "AssetsTypedDict": ".gettoolscategorypositiveresponse",
    "Coverage": ".gettoolscategorypositiveresponse",
    "CoverageTypedDict": ".gettoolscategorypositiveresponse",
    "Feature": ".gettoolscategorypositiveresponse",
    "FeatureCoverageStatus": ".gettoolscategorypositiveresponse",
    "FeatureTypedDict": ".gettoolscategorypositiveresponse",
    "GetToolsCategoryPositiveResponse": ".gettoolscategorypositiveresponse",
    "GetToolsCategoryPositiveResponseData": ".gettoolscategorypositiveresponse",
    "GetToolsCategoryPositiveResponseDataTypedDict": ".gettoolscategorypositiveresponse",
    "GetToolsCategoryPositiveResponseField": ".gettoolscategorypositiveresponse",
    "GetToolsCategoryPositiveResponseFieldCoverageStatus": ".gettoolscategorypositiveresponse",
    "GetToolsCategoryPositiveResponseFieldTypedDict": ".gettoolscategorypositiveresponse",
    "GetToolsCategoryPositiveResponseReadModel": ".gettoolscategorypositiveresponse",
    "GetToolsCategoryPositiveResponseReadModelCoverageStatus": ".gettoolscategorypositiveresponse",
    "GetToolsCategoryPositiveResponseReadModelTypedDict": ".gettoolscategorypositiveresponse",
    "GetToolsCategoryPositiveResponseTool": ".gettoolscategorypositiveresponse",
    "GetToolsCategoryPositiveResponseToolTypedDict": ".gettoolscategorypositiveresponse",
    "GetToolsCategoryPositiveResponseTypedDict": ".gettoolscategorypositiveresponse",
    "WriteAction": ".gettoolscategorypositiveresponse",
    "WriteActionCoverageStatus": ".gettoolscategorypositiveresponse",
    "WriteActionTypedDict": ".gettoolscategorypositiveresponse",
    "InlineAssessmentOrderReceivedWebhookPayload": ".inlineassessmentorderreceivedwebhookpayload",
    "InlineAssessmentOrderReceivedWebhookPayloadApplication": ".inlineassessmentorderreceivedwebhookpayload",
    "InlineAssessmentOrderReceivedWebhookPayloadApplicationTypedDict": ".inlineassessmentorderreceivedwebhookpayload",
    "InlineAssessmentOrderReceivedWebhookPayloadCandidate": ".inlineassessmentorderreceivedwebhookpayload",
    "InlineAssessmentOrderReceivedWebhookPayloadCandidateTypedDict": ".inlineassessmentorderreceivedwebhookpayload",
    "InlineAssessmentOrderReceivedWebhookPayloadData": ".inlineassessmentorderreceivedwebhookpayload",
    "InlineAssessmentOrderReceivedWebhookPayloadDataTypedDict": ".inlineassessmentorderreceivedwebhookpayload",
    "InlineAssessmentOrderReceivedWebhookPayloadHiringTeam": ".inlineassessmentorderreceivedwebhookpayload",
    "InlineAssessmentOrderReceivedWebhookPayloadHiringTeamRole": ".inlineassessmentorderreceivedwebhookpayload",
    "InlineAssessmentOrderReceivedWebhookPayloadHiringTeamTypedDict": ".inlineassessmentorderreceivedwebhookpayload",
    "InlineAssessmentOrderReceivedWebhookPayloadJob": ".inlineassessmentorderreceivedwebhookpayload",
    "InlineAssessmentOrderReceivedWebhookPayloadJobTypedDict": ".inlineassessmentorderreceivedwebhookpayload",
    "InlineAssessmentOrderReceivedWebhookPayloadLocation": ".inlineassessmentorderreceivedwebhookpayload",
    "InlineAssessmentOrderReceivedWebhookPayloadLocationTypedDict": ".inlineassessmentorderreceivedwebhookpayload",
    "InlineAssessmentOrderReceivedWebhookPayloadStatus": ".inlineassessmentorderreceivedwebhookpayload",
    "InlineAssessmentOrderReceivedWebhookPayloadType": ".inlineassessmentorderreceivedwebhookpayload",
    "InlineAssessmentOrderReceivedWebhookPayloadTypedDict": ".inlineassessmentorderreceivedwebhookpayload",
    "IntegrationCreatedWebhookPayload": ".integrationcreatedwebhookpayload",
    "IntegrationCreatedWebhookPayloadCategory": ".integrationcreatedwebhookpayload",
    "IntegrationCreatedWebhookPayloadData": ".integrationcreatedwebhookpayload",
    "IntegrationCreatedWebhookPayloadDataTypedDict": ".integrationcreatedwebhookpayload",
    "IntegrationCreatedWebhookPayloadEndUser": ".integrationcreatedwebhookpayload",
    "IntegrationCreatedWebhookPayloadEndUserTypedDict": ".integrationcreatedwebhookpayload",
    "IntegrationCreatedWebhookPayloadType": ".integrationcreatedwebhookpayload",
    "IntegrationCreatedWebhookPayloadTypedDict": ".integrationcreatedwebhookpayload",
    "IntegrationDeletedWebhookPayload": ".integrationdeletedwebhookpayload",
    "IntegrationDeletedWebhookPayloadCategory": ".integrationdeletedwebhookpayload",
    "IntegrationDeletedWebhookPayloadData": ".integrationdeletedwebhookpayload",
    "IntegrationDeletedWebhookPayloadDataTypedDict": ".integrationdeletedwebhookpayload",
    "IntegrationDeletedWebhookPayloadEndUser": ".integrationdeletedwebhookpayload",
    "IntegrationDeletedWebhookPayloadEndUserTypedDict": ".integrationdeletedwebhookpayload",
    "IntegrationDeletedWebhookPayloadType": ".integrationdeletedwebhookpayload",
    "IntegrationDeletedWebhookPayloadTypedDict": ".integrationdeletedwebhookpayload",
    "IntegrationStateChangedWebhookPayload": ".integrationstatechangedwebhookpayload",
    "IntegrationStateChangedWebhookPayloadData": ".integrationstatechangedwebhookpayload",
    "IntegrationStateChangedWebhookPayloadDataTypedDict": ".integrationstatechangedwebhookpayload",
    "IntegrationStateChangedWebhookPayloadEndUser": ".integrationstatechangedwebhookpayload",
    "IntegrationStateChangedWebhookPayloadEndUserTypedDict": ".integrationstatechangedwebhookpayload",
    "IntegrationStateChangedWebhookPayloadIntegrationCategory": ".integrationstatechangedwebhookpayload",
    "IntegrationStateChangedWebhookPayloadType": ".integrationstatechangedwebhookpayload",
    "IntegrationStateChangedWebhookPayloadTypedDict": ".integrationstatechangedwebhookpayload",
    "QaStatus": ".integrationstatechangedwebhookpayload",
    "State": ".integrationstatechangedwebhookpayload",
    "KomboAtsErrorCode": ".komboatserror",
    "KomboAtsErrorError": ".komboatserror",
    "KomboAtsErrorErrorTypedDict": ".komboatserror",
    "KomboAtsErrorStatus": ".komboatserror",
    "KomboGeneralErrorCode": ".kombogeneralerror",
    "KomboGeneralErrorError": ".kombogeneralerror",
    "KomboGeneralErrorErrorTypedDict": ".kombogeneralerror",
    "KomboGeneralErrorStatus": ".kombogeneralerror",
    "KomboHrisErrorCode": ".kombohriserror",
    "KomboHrisErrorError": ".kombohriserror",
    "KomboHrisErrorErrorTypedDict": ".kombohriserror",
    "KomboHrisErrorStatus": ".kombohriserror",
    "PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDRequest": ".patchintegrationsintegrationidintegrationfieldsintegrationfieldidop",
    "PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDRequestTypedDict": ".patchintegrationsintegrationidintegrationfieldsintegrationfieldidop",
    "PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDPositiveResponse": ".patchintegrationsintegrationidintegrationfieldsintegrationfieldidpositiveresponse",
    "PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDPositiveResponseData": ".patchintegrationsintegrationidintegrationfieldsintegrationfieldidpositiveresponse",
    "PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDPositiveResponseDataTypedDict": ".patchintegrationsintegrationidintegrationfieldsintegrationfieldidpositiveresponse",
    "PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDPositiveResponseType": ".patchintegrationsintegrationidintegrationfieldsintegrationfieldidpositiveresponse",
    "PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDPositiveResponseTypedDict": ".patchintegrationsintegrationidintegrationfieldsintegrationfieldidpositiveresponse",
    "PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDRequestBody": ".patchintegrationsintegrationidintegrationfieldsintegrationfieldidrequestbody",
    "PatchIntegrationsIntegrationIDIntegrationFieldsIntegrationFieldIDRequestBodyTypedDict": ".patchintegrationsintegrationidintegrationfieldsintegrationfieldidrequestbody",
    "PostAtsApplicationsApplicationIDAttachmentsGlobals": ".postatsapplicationsapplicationidattachmentsop",
    "PostAtsApplicationsApplicationIDAttachmentsGlobalsTypedDict": ".postatsapplicationsapplicationidattachmentsop",
    "PostAtsApplicationsApplicationIDAttachmentsRequest": ".postatsapplicationsapplicationidattachmentsop",
    "PostAtsApplicationsApplicationIDAttachmentsRequestTypedDict": ".postatsapplicationsapplicationidattachmentsop",
    "PostAtsApplicationsApplicationIDAttachmentsPositiveResponse": ".postatsapplicationsapplicationidattachmentspositiveresponse",
    "PostAtsApplicationsApplicationIDAttachmentsPositiveResponseData": ".postatsapplicationsapplicationidattachmentspositiveresponse",
    "PostAtsApplicationsApplicationIDAttachmentsPositiveResponseDataTypedDict": ".postatsapplicationsapplicationidattachmentspositiveresponse",
    "PostAtsApplicationsApplicationIDAttachmentsPositiveResponseTypedDict": ".postatsapplicationsapplicationidattachmentspositiveresponse",
    "PostAtsApplicationsApplicationIDAttachmentsPositiveResponseWarning": ".postatsapplicationsapplicationidattachmentspositiveresponse",
    "PostAtsApplicationsApplicationIDAttachmentsPositiveResponseWarningTypedDict": ".postatsapplicationsapplicationidattachmentspositiveresponse",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBody": ".postatsapplicationsapplicationidattachmentsrequestbody",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyAttachment": ".postatsapplicationsapplicationidattachmentsrequestbody",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyAttachmentTypedDict": ".postatsapplicationsapplicationidattachmentsrequestbody",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyGreenhouse": ".postatsapplicationsapplicationidattachmentsrequestbody",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyGreenhouseTypedDict": ".postatsapplicationsapplicationidattachmentsrequestbody",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyOracle": ".postatsapplicationsapplicationidattachmentsrequestbody",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyOracleTypedDict": ".postatsapplicationsapplicationidattachmentsrequestbody",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyOverrideDocumentCategory": ".postatsapplicationsapplicationidattachmentsrequestbody",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyPostHeaders": ".postatsapplicationsapplicationidattachmentsrequestbody",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyPostHeadersTypedDict": ".postatsapplicationsapplicationidattachmentsrequestbody",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyRemoteFields": ".postatsapplicationsapplicationidattachmentsrequestbody",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyRemoteFieldsTypedDict": ".postatsapplicationsapplicationidattachmentsrequestbody",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyType": ".postatsapplicationsapplicationidattachmentsrequestbody",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyTypedDict": ".postatsapplicationsapplicationidattachmentsrequestbody",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyWorkable": ".postatsapplicationsapplicationidattachmentsrequestbody",
    "PostAtsApplicationsApplicationIDAttachmentsRequestBodyWorkableTypedDict": ".postatsapplicationsapplicationidattachmentsrequestbody",
    "PostAtsApplicationsApplicationIDNotesGlobals": ".postatsapplicationsapplicationidnotesop",
    "PostAtsApplicationsApplicationIDNotesGlobalsTypedDict": ".postatsapplicationsapplicationidnotesop",
    "PostAtsApplicationsApplicationIDNotesRequest": ".postatsapplicationsapplicationidnotesop",
    "PostAtsApplicationsApplicationIDNotesRequestTypedDict": ".postatsapplicationsapplicationidnotesop",
    "PostAtsApplicationsApplicationIDNotesPositiveResponse": ".postatsapplicationsapplicationidnotespositiveresponse",
    "PostAtsApplicationsApplicationIDNotesPositiveResponseData": ".postatsapplicationsapplicationidnotespositiveresponse",
    "PostAtsApplicationsApplicationIDNotesPositiveResponseDataTypedDict": ".postatsapplicationsapplicationidnotespositiveresponse",
    "PostAtsApplicationsApplicationIDNotesPositiveResponseTypedDict": ".postatsapplicationsapplicationidnotespositiveresponse",
    "PostAtsApplicationsApplicationIDNotesPositiveResponseWarning": ".postatsapplicationsapplicationidnotespositiveresponse",
    "PostAtsApplicationsApplicationIDNotesPositiveResponseWarningTypedDict": ".postatsapplicationsapplicationidnotespositiveresponse",
    "ContentType": ".postatsapplicationsapplicationidnotesrequestbody",
    "PostAtsApplicationsApplicationIDNotesRequestBody": ".postatsapplicationsapplicationidnotesrequestbody",
    "PostAtsApplicationsApplicationIDNotesRequestBodyBullhorn": ".postatsapplicationsapplicationidnotesrequestbody",
    "PostAtsApplicationsApplicationIDNotesRequestBodyBullhornTypedDict": ".postatsapplicationsapplicationidnotesrequestbody",
    "PostAtsApplicationsApplicationIDNotesRequestBodyGreenhouse": ".postatsapplicationsapplicationidnotesrequestbody",
    "PostAtsApplicationsApplicationIDNotesRequestBodyGreenhouseTypedDict": ".postatsapplicationsapplicationidnotesrequestbody",
    "PostAtsApplicationsApplicationIDNotesRequestBodyPostHeaders": ".postatsapplicationsapplicationidnotesrequestbody",
    "PostAtsApplicationsApplicationIDNotesRequestBodyPostHeadersTypedDict": ".postatsapplicationsapplicationidnotesrequestbody",
    "PostAtsApplicationsApplicationIDNotesRequestBodyRecruitee": ".postatsapplicationsapplicationidnotesrequestbody",
    "PostAtsApplicationsApplicationIDNotesRequestBodyRecruiteeTypedDict": ".postatsapplicationsapplicationidnotesrequestbody",
    "PostAtsApplicationsApplicationIDNotesRequestBodyRemoteFields": ".postatsapplicationsapplicationidnotesrequestbody",
    "PostAtsApplicationsApplicationIDNotesRequestBodyRemoteFieldsTypedDict": ".postatsapplicationsapplicationidnotesrequestbody",
    "PostAtsApplicationsApplicationIDNotesRequestBodyTeamtailor": ".postatsapplicationsapplicationidnotesrequestbody",
    "PostAtsApplicationsApplicationIDNotesRequestBodyTeamtailorTypedDict": ".postatsapplicationsapplicationidnotesrequestbody",
    "PostAtsApplicationsApplicationIDNotesRequestBodyTypedDict": ".postatsapplicationsapplicationidnotesrequestbody",
    "PostAtsApplicationsApplicationIDNotesRequestBodyWorkable": ".postatsapplicationsapplicationidnotesrequestbody",
    "PostAtsApplicationsApplicationIDNotesRequestBodyWorkableTypedDict": ".postatsapplicationsapplicationidnotesrequestbody",
    "PostAtsApplicationsApplicationIDRejectGlobals": ".postatsapplicationsapplicationidrejectop",
    "PostAtsApplicationsApplicationIDRejectGlobalsTypedDict": ".postatsapplicationsapplicationidrejectop",
    "PostAtsApplicationsApplicationIDRejectRequest": ".postatsapplicationsapplicationidrejectop",
    "PostAtsApplicationsApplicationIDRejectRequestTypedDict": ".postatsapplicationsapplicationidrejectop",
    "PostAtsApplicationsApplicationIDRejectPositiveResponse": ".postatsapplicationsapplicationidrejectpositiveresponse",
    "PostAtsApplicationsApplicationIDRejectPositiveResponseData": ".postatsapplicationsapplicationidrejectpositiveresponse",
    "PostAtsApplicationsApplicationIDRejectPositiveResponseDataTypedDict": ".postatsapplicationsapplicationidrejectpositiveresponse",
    "PostAtsApplicationsApplicationIDRejectPositiveResponseTypedDict": ".postatsapplicationsapplicationidrejectpositiveresponse",
    "PostAtsApplicationsApplicationIDRejectPositiveResponseWarning": ".postatsapplicationsapplicationidrejectpositiveresponse",
    "PostAtsApplicationsApplicationIDRejectPositiveResponseWarningTypedDict": ".postatsapplicationsapplicationidrejectpositiveresponse",
    "PostAtsApplicationsApplicationIDRejectRequestBody": ".postatsapplicationsapplicationidrejectrequestbody",
    "PostAtsApplicationsApplicationIDRejectRequestBodyGreenhouse": ".postatsapplicationsapplicationidrejectrequestbody",
    "PostAtsApplicationsApplicationIDRejectRequestBodyGreenhouseTypedDict": ".postatsapplicationsapplicationidrejectrequestbody",
    "PostAtsApplicationsApplicationIDRejectRequestBodyPostHeaders": ".postatsapplicationsapplicationidrejectrequestbody",
    "PostAtsApplicationsApplicationIDRejectRequestBodyPostHeadersTypedDict": ".postatsapplicationsapplicationidrejectrequestbody",
    "PostAtsApplicationsApplicationIDRejectRequestBodyRemoteFields": ".postatsapplicationsapplicationidrejectrequestbody",
    "PostAtsApplicationsApplicationIDRejectRequestBodyRemoteFieldsTypedDict": ".postatsapplicationsapplicationidrejectrequestbody",
    "PostAtsApplicationsApplicationIDRejectRequestBodyTypedDict": ".postatsapplicationsapplicationidrejectrequestbody",
    "PostAtsApplicationsApplicationIDRejectRequestBodyWorkable": ".postatsapplicationsapplicationidrejectrequestbody",
    "PostAtsApplicationsApplicationIDRejectRequestBodyWorkableTypedDict": ".postatsapplicationsapplicationidrejectrequestbody",
    "PostAtsApplicationsApplicationIDResultLinksGlobals": ".postatsapplicationsapplicationidresultlinksop",
    "PostAtsApplicationsApplicationIDResultLinksGlobalsTypedDict": ".postatsapplicationsapplicationidresultlinksop",
    "PostAtsApplicationsApplicationIDResultLinksRequest": ".postatsapplicationsapplicationidresultlinksop",
    "PostAtsApplicationsApplicationIDResultLinksRequestTypedDict": ".postatsapplicationsapplicationidresultlinksop",
    "PostAtsApplicationsApplicationIDResultLinksPositiveResponse": ".postatsapplicationsapplicationidresultlinkspositiveresponse",
    "PostAtsApplicationsApplicationIDResultLinksPositiveResponseData": ".postatsapplicationsapplicationidresultlinkspositiveresponse",
    "PostAtsApplicationsApplicationIDResultLinksPositiveResponseDataTypedDict": ".postatsapplicationsapplicationidresultlinkspositiveresponse",
    "PostAtsApplicationsApplicationIDResultLinksPositiveResponseTypedDict": ".postatsapplicationsapplicationidresultlinkspositiveresponse",
    "PostAtsApplicationsApplicationIDResultLinksPositiveResponseWarning": ".postatsapplicationsapplicationidresultlinkspositiveresponse",
    "PostAtsApplicationsApplicationIDResultLinksPositiveResponseWarningTypedDict": ".postatsapplicationsapplicationidresultlinkspositiveresponse",
    "PostAtsApplicationsApplicationIDResultLinksRequestBody": ".postatsapplicationsapplicationidresultlinksrequestbody",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyAttribute": ".postatsapplicationsapplicationidresultlinksrequestbody",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyAttributeTypedDict": ".postatsapplicationsapplicationidresultlinksrequestbody",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyDetails": ".postatsapplicationsapplicationidresultlinksrequestbody",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyDetailsTypedDict": ".postatsapplicationsapplicationidresultlinksrequestbody",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyGreenhouse": ".postatsapplicationsapplicationidresultlinksrequestbody",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyGreenhouseTypedDict": ".postatsapplicationsapplicationidresultlinksrequestbody",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyIcims": ".postatsapplicationsapplicationidresultlinksrequestbody",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyIcimsTypedDict": ".postatsapplicationsapplicationidresultlinksrequestbody",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyOracle": ".postatsapplicationsapplicationidresultlinksrequestbody",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyOracleTypedDict": ".postatsapplicationsapplicationidresultlinksrequestbody",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyOverrideDocumentCategory": ".postatsapplicationsapplicationidresultlinksrequestbody",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyPostHeaders": ".postatsapplicationsapplicationidresultlinksrequestbody",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyPostHeadersTypedDict": ".postatsapplicationsapplicationidresultlinksrequestbody",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyRemoteFields": ".postatsapplicationsapplicationidresultlinksrequestbody",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyRemoteFieldsTypedDict": ".postatsapplicationsapplicationidresultlinksrequestbody",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyTypedDict": ".postatsapplicationsapplicationidresultlinksrequestbody",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyWorkable": ".postatsapplicationsapplicationidresultlinksrequestbody",
    "PostAtsApplicationsApplicationIDResultLinksRequestBodyWorkableTypedDict": ".postatsapplicationsapplicationidresultlinksrequestbody",
    "PostAtsCandidatesCandidateIDAttachmentsGlobals": ".postatscandidatescandidateidattachmentsop",
    "PostAtsCandidatesCandidateIDAttachmentsGlobalsTypedDict": ".postatscandidatescandidateidattachmentsop",
    "PostAtsCandidatesCandidateIDAttachmentsRequest": ".postatscandidatescandidateidattachmentsop",
    "PostAtsCandidatesCandidateIDAttachmentsRequestTypedDict": ".postatscandidatescandidateidattachmentsop",
    "PostAtsCandidatesCandidateIDAttachmentsPositiveResponse": ".postatscandidatescandidateidattachmentspositiveresponse",
    "PostAtsCandidatesCandidateIDAttachmentsPositiveResponseData": ".postatscandidatescandidateidattachmentspositiveresponse",
    "PostAtsCandidatesCandidateIDAttachmentsPositiveResponseDataTypedDict": ".postatscandidatescandidateidattachmentspositiveresponse",
    "PostAtsCandidatesCandidateIDAttachmentsPositiveResponseTypedDict": ".postatscandidatescandidateidattachmentspositiveresponse",
    "PostAtsCandidatesCandidateIDAttachmentsPositiveResponseWarning": ".postatscandidatescandidateidattachmentspositiveresponse",
    "PostAtsCandidatesCandidateIDAttachmentsPositiveResponseWarningTypedDict": ".postatscandidatescandidateidattachmentspositiveresponse",
    "PostAtsCandidatesCandidateIDAttachmentsRequestBody": ".postatscandidatescandidateidattachmentsrequestbody",
    "PostAtsCandidatesCandidateIDAttachmentsRequestBodyAttachment": ".postatscandidatescandidateidattachmentsrequestbody",
    "PostAtsCandidatesCandidateIDAttachmentsRequestBodyAttachmentTypedDict": ".postatscandidatescandidateidattachmentsrequestbody",
    "PostAtsCandidatesCandidateIDAttachmentsRequestBodyGreenhouse": ".postatscandidatescandidateidattachmentsrequestbody",
    "PostAtsCandidatesCandidateIDAttachmentsRequestBodyGreenhouseTypedDict": ".postatscandidatescandidateidattachmentsrequestbody",
    "PostAtsCandidatesCandidateIDAttachmentsRequestBodyPostHeaders": ".postatscandidatescandidateidattachmentsrequestbody",
    "PostAtsCandidatesCandidateIDAttachmentsRequestBodyPostHeadersTypedDict": ".postatscandidatescandidateidattachmentsrequestbody",
    "PostAtsCandidatesCandidateIDAttachmentsRequestBodyRemoteFields": ".postatscandidatescandidateidattachmentsrequestbody",
    "PostAtsCandidatesCandidateIDAttachmentsRequestBodyRemoteFieldsTypedDict": ".postatscandidatescandidateidattachmentsrequestbody",
    "PostAtsCandidatesCandidateIDAttachmentsRequestBodyType": ".postatscandidatescandidateidattachmentsrequestbody",
    "PostAtsCandidatesCandidateIDAttachmentsRequestBodyTypedDict": ".postatscandidatescandidateidattachmentsrequestbody",
    "PostAtsCandidatesCandidateIDAttachmentsRequestBodyWorkable": ".postatscandidatescandidateidattachmentsrequestbody",
    "PostAtsCandidatesCandidateIDAttachmentsRequestBodyWorkableTypedDict": ".postatscandidatescandidateidattachmentsrequestbody",
    "PostAtsCandidatesCandidateIDResultLinksGlobals": ".postatscandidatescandidateidresultlinksop",
    "PostAtsCandidatesCandidateIDResultLinksGlobalsTypedDict": ".postatscandidatescandidateidresultlinksop",
    "PostAtsCandidatesCandidateIDResultLinksRequest": ".postatscandidatescandidateidresultlinksop",
    "PostAtsCandidatesCandidateIDResultLinksRequestTypedDict": ".postatscandidatescandidateidresultlinksop",
    "PostAtsCandidatesCandidateIDResultLinksPositiveResponse": ".postatscandidatescandidateidresultlinkspositiveresponse",
    "PostAtsCandidatesCandidateIDResultLinksPositiveResponseData": ".postatscandidatescandidateidresultlinkspositiveresponse",
    "PostAtsCandidatesCandidateIDResultLinksPositiveResponseDataTypedDict": ".postatscandidatescandidateidresultlinkspositiveresponse",
    "PostAtsCandidatesCandidateIDResultLinksPositiveResponseTypedDict": ".postatscandidatescandidateidresultlinkspositiveresponse",
    "PostAtsCandidatesCandidateIDResultLinksPositiveResponseWarning": ".postatscandidatescandidateidresultlinkspositiveresponse",
    "PostAtsCandidatesCandidateIDResultLinksPositiveResponseWarningTypedDict": ".postatscandidatescandidateidresultlinkspositiveresponse",
    "PostAtsCandidatesCandidateIDResultLinksRequestBody": ".postatscandidatescandidateidresultlinksrequestbody",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyAttribute": ".postatscandidatescandidateidresultlinksrequestbody",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyAttributeTypedDict": ".postatscandidatescandidateidresultlinksrequestbody",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyDetails": ".postatscandidatescandidateidresultlinksrequestbody",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyDetailsTypedDict": ".postatscandidatescandidateidresultlinksrequestbody",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyGreenhouse": ".postatscandidatescandidateidresultlinksrequestbody",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyGreenhouseTypedDict": ".postatscandidatescandidateidresultlinksrequestbody",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyIcims": ".postatscandidatescandidateidresultlinksrequestbody",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyIcimsTypedDict": ".postatscandidatescandidateidresultlinksrequestbody",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyOracle": ".postatscandidatescandidateidresultlinksrequestbody",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyOracleTypedDict": ".postatscandidatescandidateidresultlinksrequestbody",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyOverrideDocumentCategory": ".postatscandidatescandidateidresultlinksrequestbody",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyPostHeaders": ".postatscandidatescandidateidresultlinksrequestbody",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyPostHeadersTypedDict": ".postatscandidatescandidateidresultlinksrequestbody",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyRemoteFields": ".postatscandidatescandidateidresultlinksrequestbody",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyRemoteFieldsTypedDict": ".postatscandidatescandidateidresultlinksrequestbody",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyTypedDict": ".postatscandidatescandidateidresultlinksrequestbody",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyWorkable": ".postatscandidatescandidateidresultlinksrequestbody",
    "PostAtsCandidatesCandidateIDResultLinksRequestBodyWorkableTypedDict": ".postatscandidatescandidateidresultlinksrequestbody",
    "PostAtsCandidatesCandidateIDTagsGlobals": ".postatscandidatescandidateidtagsop",
    "PostAtsCandidatesCandidateIDTagsGlobalsTypedDict": ".postatscandidatescandidateidtagsop",
    "PostAtsCandidatesCandidateIDTagsRequest": ".postatscandidatescandidateidtagsop",
    "PostAtsCandidatesCandidateIDTagsRequestTypedDict": ".postatscandidatescandidateidtagsop",
    "PostAtsCandidatesCandidateIDTagsPositiveResponse": ".postatscandidatescandidateidtagspositiveresponse",
    "PostAtsCandidatesCandidateIDTagsPositiveResponseData": ".postatscandidatescandidateidtagspositiveresponse",
    "PostAtsCandidatesCandidateIDTagsPositiveResponseDataTypedDict": ".postatscandidatescandidateidtagspositiveresponse",
    "PostAtsCandidatesCandidateIDTagsPositiveResponseTypedDict": ".postatscandidatescandidateidtagspositiveresponse",
    "PostAtsCandidatesCandidateIDTagsPositiveResponseWarning": ".postatscandidatescandidateidtagspositiveresponse",
    "PostAtsCandidatesCandidateIDTagsPositiveResponseWarningTypedDict": ".postatscandidatescandidateidtagspositiveresponse",
    "PostAtsCandidatesCandidateIDTagsRequestBody": ".postatscandidatescandidateidtagsrequestbody",
    "PostAtsCandidatesCandidateIDTagsRequestBodyGreenhouse": ".postatscandidatescandidateidtagsrequestbody",
    "PostAtsCandidatesCandidateIDTagsRequestBodyGreenhouseTypedDict": ".postatscandidatescandidateidtagsrequestbody",
    "PostAtsCandidatesCandidateIDTagsRequestBodyPostHeaders": ".postatscandidatescandidateidtagsrequestbody",
    "PostAtsCandidatesCandidateIDTagsRequestBodyPostHeadersTypedDict": ".postatscandidatescandidateidtagsrequestbody",
    "PostAtsCandidatesCandidateIDTagsRequestBodyRemoteFields": ".postatscandidatescandidateidtagsrequestbody",
    "PostAtsCandidatesCandidateIDTagsRequestBodyRemoteFieldsTypedDict": ".postatscandidatescandidateidtagsrequestbody",
    "PostAtsCandidatesCandidateIDTagsRequestBodyTag": ".postatscandidatescandidateidtagsrequestbody",
    "PostAtsCandidatesCandidateIDTagsRequestBodyTagTypedDict": ".postatscandidatescandidateidtagsrequestbody",
    "PostAtsCandidatesCandidateIDTagsRequestBodyTypedDict": ".postatscandidatescandidateidtagsrequestbody",
    "PostAtsCandidatesCandidateIDTagsRequestBodyWorkable": ".postatscandidatescandidateidtagsrequestbody",
    "PostAtsCandidatesCandidateIDTagsRequestBodyWorkableTypedDict": ".postatscandidatescandidateidtagsrequestbody",
    "PostAtsCandidatesGlobals": ".postatscandidatesop",
    "PostAtsCandidatesGlobalsTypedDict": ".postatscandidatesop",
    "PostAtsCandidatesPositiveResponse": ".postatscandidatespositiveresponse",
    "PostAtsCandidatesPositiveResponseApplication": ".postatscandidatespositiveresponse",
    "PostAtsCandidatesPositiveResponseApplicationTypedDict": ".postatscandidatespositiveresponse",
    "PostAtsCandidatesPositiveResponseCurrentStage": ".postatscandidatespositiveresponse",
    "PostAtsCandidatesPositiveResponseCurrentStageTypedDict": ".postatscandidatespositiveresponse",
    "PostAtsCandidatesPositiveResponseData": ".postatscandidatespositiveresponse",
    "PostAtsCandidatesPositiveResponseDataTypedDict": ".postatscandidatespositiveresponse",
    "PostAtsCandidatesPositiveResponseEmailAddress": ".postatscandidatespositiveresponse",
    "PostAtsCandidatesPositiveResponseEmailAddressTypedDict": ".postatscandidatespositiveresponse",
    "PostAtsCandidatesPositiveResponseJob": ".postatscandidatespositiveresponse",
    "PostAtsCandidatesPositiveResponseJobTypedDict": ".postatscandidatespositiveresponse",
    "PostAtsCandidatesPositiveResponseLocation": ".postatscandidatespositiveresponse",
    "PostAtsCandidatesPositiveResponseLocationTypedDict": ".postatscandidatespositiveresponse",
    "PostAtsCandidatesPositiveResponseOutcome": ".postatscandidatespositiveresponse",
    "PostAtsCandidatesPositiveResponsePhoneNumber": ".postatscandidatespositiveresponse",
    "PostAtsCandidatesPositiveResponsePhoneNumberTypedDict": ".postatscandidatespositiveresponse",
    "PostAtsCandidatesPositiveResponseSocialMedia": ".postatscandidatespositiveresponse",
    "PostAtsCandidatesPositiveResponseSocialMediaTypedDict": ".postatscandidatespositiveresponse",
    "PostAtsCandidatesPositiveResponseTag": ".postatscandidatespositiveresponse",
    "PostAtsCandidatesPositiveResponseTagTypedDict": ".postatscandidatespositiveresponse",
    "PostAtsCandidatesPositiveResponseTypedDict": ".postatscandidatespositiveresponse",
    "PostAtsCandidatesPositiveResponseWarning": ".postatscandidatespositiveresponse",
    "PostAtsCandidatesPositiveResponseWarningTypedDict": ".postatscandidatespositiveresponse",
    "PostAtsCandidatesRequestBody": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyAdditionalEmailAddress": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyAdditionalEmailAddressType": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyAdditionalEmailAddressTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyAdditionalPhoneNumber": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyAdditionalPhoneNumberType": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyAdditionalPhoneNumberTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyAnswer": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyAnswerTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyAnswerUnion": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyAnswerUnionTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyApplication": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyApplicationTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyAttachment": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyAttachmentType": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyAttachmentTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyAvature": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyAvatureTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyBullhorn": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyBullhornTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyCandidate": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyCandidateData": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyCandidateDataTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyCandidateTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyContactData": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyContactDataTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyCountryCityReference": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyCountryCityReferenceTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyCountryRegionReference": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyCountryRegionReferenceTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyDegreeReference": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyDegreeReferenceTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyDvinci": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyDvinciTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyEducationDatum": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyEducationDatumTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyExperienceDatum": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyExperienceDatumTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyFieldOfStudyReference": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyFieldOfStudyReferenceTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyGdprConsent": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyGdprConsentTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyGender": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyGlobalPersonalInformationData": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyGlobalPersonalInformationDataTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyGreenhouse": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyGreenhouseTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyGuidecom": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyGuidecomTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyHrworks": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyHrworksTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyJobApplicationData": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyJobApplicationDataTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyJobAppliedToData": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyJobAppliedToDataTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyJobylon": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyJobylonApplication": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyJobylonApplicationTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyJobylonTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyLanguage": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyLanguageAbility": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyLanguageAbilityData": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyLanguageAbilityDataTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyLanguageAbilityTypeReference": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyLanguageAbilityTypeReferenceTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyLanguageAbilityTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyLanguageDatum": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyLanguageDatumLanguageReference": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyLanguageDatumLanguageReferenceTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyLanguageDatumTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyLanguageProficiencyReference": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyLanguageProficiencyReferenceTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyLanguageReference": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyLanguageReferenceTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyLanguageTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyLever": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyLeverTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyLocation": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyLocationData": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyLocationDataTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyLocationTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyNameDetailData": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyNameDetailDataTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyPeriod": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyPersonio": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyPersonioTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyPiloga": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyPilogaCandidate": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyPilogaCandidateTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyPilogaTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyPostHeaders": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyPostHeadersTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyRecruitee": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyRecruiteeCandidate": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyRecruiteeCandidateTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyRecruiteeTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyRemoteFields": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyRemoteFieldsTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyResumeData": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyResumeDataTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodySalaryExpectations": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodySalaryExpectationsTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyScreeningQuestionAnswer": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyScreeningQuestionAnswerTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodySkillDatum": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodySkillDatumTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodySmartrecruiters": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodySmartrecruitersTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodySocialLink": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodySocialLinkTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodySocialSuffixReference": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodySocialSuffixReferenceTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodySource": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodySourceTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodySourcedBy": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodySourcedByTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyStep": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyStepTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodySuccessfactors": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodySuccessfactorsTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyTalentadore": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyTalentadoreTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyTalentsoft": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyTalentsoftTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyTeamtailor": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyTeamtailorApplication": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyTeamtailorApplicationTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyTeamtailorTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyUmantis": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyUmantisTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyWorkable": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyWorkableTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyWorkday": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyWorkdayTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyWorkerReference": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyWorkerReferenceTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyWorkflow": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyWorkflowTypedDict": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyZohorecruit": ".postatscandidatesrequestbody",
    "PostAtsCandidatesRequestBodyZohorecruitTypedDict": ".postatscandidatesrequestbody",
    "PostAtsImportTrackedApplicationGlobals": ".postatsimporttrackedapplicationop",
    "PostAtsImportTrackedApplicationGlobalsTypedDict": ".postatsimporttrackedapplicationop",
    "ImportedID": ".postatsimporttrackedapplicationpositiveresponse",
    "ImportedIDTypedDict": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponse": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseData": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseDataTypedDict": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseErecruiterApplicationAndCandidateRemoteIds": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseErecruiterApplicationAndCandidateRemoteIdsTypedDict": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseErecruiterApplicationAndJobRemoteIds": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseErecruiterApplicationAndJobRemoteIdsTypedDict": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseErecruiterUnion": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseErecruiterUnionTypedDict": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseGreenhouseApplicationID": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseGreenhouseApplicationIDTypedDict": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseGreenhouseUnion": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseGreenhouseUnionTypedDict": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseOnlyfyApplicationID": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseOnlyfyApplicationIDTypedDict": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseOnlyfyUnion": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseOnlyfyUnionTypedDict": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseRecruiteePlacementID": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseRecruiteePlacementIDTypedDict": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseRecruiteeUnion": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseRecruiteeUnionTypedDict": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseSmartrecruitersCandidateAndJobRemoteIds": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseSmartrecruitersCandidateAndJobRemoteIdsTypedDict": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseSmartrecruitersUnion": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseSmartrecruitersUnionTypedDict": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseSuccessfactorsApplicationRemoteID": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseSuccessfactorsApplicationRemoteIDTypedDict": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseSuccessfactorsUnion": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseSuccessfactorsUnionTypedDict": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseTypedDict": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseWarning": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationPositiveResponseWarningTypedDict": ".postatsimporttrackedapplicationpositiveresponse",
    "PostAtsImportTrackedApplicationRequestBody": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsImportTrackedApplicationRequestBodyErecruiterApplicationAndCandidateRemoteIds": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsImportTrackedApplicationRequestBodyErecruiterApplicationAndCandidateRemoteIdsTypedDict": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsImportTrackedApplicationRequestBodyErecruiterApplicationAndJobRemoteIds": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsImportTrackedApplicationRequestBodyErecruiterApplicationAndJobRemoteIdsTypedDict": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsImportTrackedApplicationRequestBodyErecruiterUnion": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsImportTrackedApplicationRequestBodyErecruiterUnionTypedDict": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsImportTrackedApplicationRequestBodyGreenhouseApplicationID": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsImportTrackedApplicationRequestBodyGreenhouseApplicationIDTypedDict": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsImportTrackedApplicationRequestBodyGreenhouseUnion": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsImportTrackedApplicationRequestBodyGreenhouseUnionTypedDict": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsImportTrackedApplicationRequestBodyOnlyfyApplicationID": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsImportTrackedApplicationRequestBodyOnlyfyApplicationIDTypedDict": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsImportTrackedApplicationRequestBodyOnlyfyUnion": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsImportTrackedApplicationRequestBodyOnlyfyUnionTypedDict": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsImportTrackedApplicationRequestBodyRecruiteePlacementID": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsImportTrackedApplicationRequestBodyRecruiteePlacementIDTypedDict": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsImportTrackedApplicationRequestBodyRecruiteeUnion": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsImportTrackedApplicationRequestBodyRecruiteeUnionTypedDict": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsImportTrackedApplicationRequestBodySmartrecruitersCandidateAndJobRemoteIds": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsImportTrackedApplicationRequestBodySmartrecruitersCandidateAndJobRemoteIdsTypedDict": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsImportTrackedApplicationRequestBodySmartrecruitersUnion": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsImportTrackedApplicationRequestBodySmartrecruitersUnionTypedDict": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsImportTrackedApplicationRequestBodySuccessfactorsApplicationRemoteID": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsImportTrackedApplicationRequestBodySuccessfactorsApplicationRemoteIDTypedDict": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsImportTrackedApplicationRequestBodySuccessfactorsUnion": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsImportTrackedApplicationRequestBodySuccessfactorsUnionTypedDict": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsImportTrackedApplicationRequestBodyTypedDict": ".postatsimporttrackedapplicationrequestbody",
    "PostAtsJobsJobIDApplicationsGlobals": ".postatsjobsjobidapplicationsop",
    "PostAtsJobsJobIDApplicationsGlobalsTypedDict": ".postatsjobsjobidapplicationsop",
    "PostAtsJobsJobIDApplicationsRequest": ".postatsjobsjobidapplicationsop",
    "PostAtsJobsJobIDApplicationsRequestTypedDict": ".postatsjobsjobidapplicationsop",
    "PostAtsJobsJobIDApplicationsPositiveResponse": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer1": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer1TypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer2": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer2TypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer3": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer3TypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer4": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer4TypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer5": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer5TypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer6": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer6TypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer7": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseAnswer7TypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseCandidate": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseCandidateTypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseCurrentStage": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseCurrentStageTypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseData": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseDataTypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseEmailAddress": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseEmailAddressTypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseJob": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseJobTypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseLocation": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseLocationTypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseOutcome": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponsePhoneNumber": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponsePhoneNumberTypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionBoolean": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionBooleanTypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionDate": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionDateTypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionMultiSelect": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionMultiSelectTypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionNumber": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionNumberTypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionSingleSelect": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionSingleSelectTypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionText": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionTextTypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionUnknown": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseQuestionUnknownTypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer1": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer1TypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer2": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer2TypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer3": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer3TypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer4": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer4TypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer5": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer5TypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer6": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer6TypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer7": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswer7TypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswerUnion": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseScreeningQuestionAnswerUnionTypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseSocialMedia": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseSocialMediaTypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseTag": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseTagTypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseTypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseWarning": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsPositiveResponseWarningTypedDict": ".postatsjobsjobidapplicationspositiveresponse",
    "PostAtsJobsJobIDApplicationsRequestBody": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyAdditionalEmailAddress": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyAdditionalEmailAddressType": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyAdditionalEmailAddressTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyAdditionalPhoneNumber": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyAdditionalPhoneNumberType": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyAdditionalPhoneNumberTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyAnswer": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyAnswerTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyAnswerUnion": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyAnswerUnionTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyAttachment": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyAttachmentType": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyAttachmentTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyAvature": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyAvatureTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyBullhorn": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyBullhornTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyCandidate": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyCandidateData": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyCandidateDataTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyCandidateTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyContactData": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyContactDataTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyCountryCityReference": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyCountryCityReferenceTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyCountryRegionReference": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyCountryRegionReferenceTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyDegreeReference": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyDegreeReferenceTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyDvinci": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyDvinciTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyEducationDatum": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyEducationDatumTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyExperienceDatum": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyExperienceDatumTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyFieldOfStudyReference": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyFieldOfStudyReferenceTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyGdprConsent": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyGdprConsentTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyGender": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyGlobalPersonalInformationData": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyGlobalPersonalInformationDataTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyGreenhouse": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyGreenhouseTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyGuidecom": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyGuidecomTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyHrworks": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyHrworksTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyJobApplicationData": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyJobApplicationDataTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyJobAppliedToData": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyJobAppliedToDataTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyJobylon": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyJobylonApplication": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyJobylonApplicationTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyJobylonTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguage": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageAbility": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageAbilityData": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageAbilityDataTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageAbilityTypeReference": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageAbilityTypeReferenceTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageAbilityTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageDatum": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageDatumLanguageReference": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageDatumLanguageReferenceTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageDatumTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageProficiencyReference": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageProficiencyReferenceTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageReference": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageReferenceTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyLanguageTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyLever": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyLeverTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyLocation": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyLocationData": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyLocationDataTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyLocationTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyNameDetailData": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyNameDetailDataTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyPeriod": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyPersonio": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyPersonioTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyPiloga": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyPilogaCandidate": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyPilogaCandidateTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyPilogaTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyPostHeaders": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyPostHeadersTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyRecruitee": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyRecruiteeCandidate": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyRecruiteeCandidateTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyRecruiteeTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyRemoteFields": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyRemoteFieldsTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyResumeData": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyResumeDataTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodySalaryExpectations": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodySalaryExpectationsTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyScreeningQuestionAnswer": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyScreeningQuestionAnswerTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodySkillDatum": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodySkillDatumTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodySmartrecruiters": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodySmartrecruitersTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodySocialLink": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodySocialLinkTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodySocialSuffixReference": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodySocialSuffixReferenceTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodySource": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodySourceTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodySourcedBy": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodySourcedByTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyStep": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyStepTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodySuccessfactors": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodySuccessfactorsTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyTalentadore": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyTalentadoreTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyTalentsoft": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyTalentsoftTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyTeamtailor": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyTeamtailorApplication": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyTeamtailorApplicationTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyTeamtailorTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyUmantis": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyUmantisTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyWorkable": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyWorkableTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyWorkday": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyWorkdayTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyWorkerReference": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyWorkerReferenceTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyWorkflow": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyWorkflowTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyZohorecruit": ".postatsjobsjobidapplicationsrequestbody",
    "PostAtsJobsJobIDApplicationsRequestBodyZohorecruitTypedDict": ".postatsjobsjobidapplicationsrequestbody",
    "PostConnectCreateLinkPositiveResponse": ".postconnectcreatelinkpositiveresponse",
    "PostConnectCreateLinkPositiveResponseData": ".postconnectcreatelinkpositiveresponse",
    "PostConnectCreateLinkPositiveResponseDataTypedDict": ".postconnectcreatelinkpositiveresponse",
    "PostConnectCreateLinkPositiveResponseTypedDict": ".postconnectcreatelinkpositiveresponse",
    "IntegrationTool": ".postconnectcreatelinkrequestbody",
    "PostConnectCreateLinkRequestBody": ".postconnectcreatelinkrequestbody",
    "PostConnectCreateLinkRequestBodyIntegrationCategory": ".postconnectcreatelinkrequestbody",
    "PostConnectCreateLinkRequestBodyLanguage": ".postconnectcreatelinkrequestbody",
    "PostConnectCreateLinkRequestBodyLinkType": ".postconnectcreatelinkrequestbody",
    "PostConnectCreateLinkRequestBodyTypedDict": ".postconnectcreatelinkrequestbody",
    "PostForceSyncGlobals": ".postforcesyncop",
    "PostForceSyncGlobalsTypedDict": ".postforcesyncop",
    "PostForceSyncPositiveResponse": ".postforcesyncpositiveresponse",
    "PostForceSyncPositiveResponseData": ".postforcesyncpositiveresponse",
    "PostForceSyncPositiveResponseDataTypedDict": ".postforcesyncpositiveresponse",
    "PostForceSyncPositiveResponseType": ".postforcesyncpositiveresponse",
    "PostForceSyncPositiveResponseTypedDict": ".postforcesyncpositiveresponse",
    "PostForceSyncRequestBody": ".postforcesyncrequestbody",
    "PostForceSyncRequestBodyType": ".postforcesyncrequestbody",
    "PostForceSyncRequestBodyTypedDict": ".postforcesyncrequestbody",
    "PostHrisAbsencesGlobals": ".posthrisabsencesop",
    "PostHrisAbsencesGlobalsTypedDict": ".posthrisabsencesop",
    "PostHrisAbsencesPositiveResponse": ".posthrisabsencespositiveresponse",
    "PostHrisAbsencesPositiveResponseData": ".posthrisabsencespositiveresponse",
    "PostHrisAbsencesPositiveResponseDataTypedDict": ".posthrisabsencespositiveresponse",
    "PostHrisAbsencesPositiveResponseStatus": ".posthrisabsencespositiveresponse",
    "PostHrisAbsencesPositiveResponseTypedDict": ".posthrisabsencespositiveresponse",
    "PostHrisAbsencesPositiveResponseUnit": ".posthrisabsencespositiveresponse",
    "PostHrisAbsencesPositiveResponseWarning": ".posthrisabsencespositiveresponse",
    "PostHrisAbsencesPositiveResponseWarningTypedDict": ".posthrisabsencespositiveresponse",
    "PostHrisAbsencesRequestBody": ".posthrisabsencesrequestbody",
    "PostHrisAbsencesRequestBodyAdpworkforcenow": ".posthrisabsencesrequestbody",
    "PostHrisAbsencesRequestBodyAdpworkforcenowTypedDict": ".posthrisabsencesrequestbody",
    "PostHrisAbsencesRequestBodyRemoteFields": ".posthrisabsencesrequestbody",
    "PostHrisAbsencesRequestBodyRemoteFieldsTypedDict": ".posthrisabsencesrequestbody",
    "PostHrisAbsencesRequestBodyStatus": ".posthrisabsencesrequestbody",
    "PostHrisAbsencesRequestBodyTypedDict": ".posthrisabsencesrequestbody",
    "PostHrisAbsencesRequestBodyUnit": ".posthrisabsencesrequestbody",
    "PostHrisEmployeesEmployeeIDDocumentsGlobals": ".posthrisemployeesemployeeiddocumentsop",
    "PostHrisEmployeesEmployeeIDDocumentsGlobalsTypedDict": ".posthrisemployeesemployeeiddocumentsop",
    "PostHrisEmployeesEmployeeIDDocumentsRequest": ".posthrisemployeesemployeeiddocumentsop",
    "PostHrisEmployeesEmployeeIDDocumentsRequestTypedDict": ".posthrisemployeesemployeeiddocumentsop",
    "PostHrisEmployeesEmployeeIDDocumentsPositiveResponse": ".posthrisemployeesemployeeiddocumentspositiveresponse",
    "PostHrisEmployeesEmployeeIDDocumentsPositiveResponseData": ".posthrisemployeesemployeeiddocumentspositiveresponse",
    "PostHrisEmployeesEmployeeIDDocumentsPositiveResponseDataTypedDict": ".posthrisemployeesemployeeiddocumentspositiveresponse",
    "PostHrisEmployeesEmployeeIDDocumentsPositiveResponseTypedDict": ".posthrisemployeesemployeeiddocumentspositiveresponse",
    "PostHrisEmployeesEmployeeIDDocumentsPositiveResponseWarning": ".posthrisemployeesemployeeiddocumentspositiveresponse",
    "PostHrisEmployeesEmployeeIDDocumentsPositiveResponseWarningTypedDict": ".posthrisemployeesemployeeiddocumentspositiveresponse",
    "Document": ".posthrisemployeesemployeeiddocumentsrequestbody",
    "DocumentTypedDict": ".posthrisemployeesemployeeiddocumentsrequestbody",
    "PostHrisEmployeesEmployeeIDDocumentsRequestBody": ".posthrisemployeesemployeeiddocumentsrequestbody",
    "PostHrisEmployeesEmployeeIDDocumentsRequestBodyTypedDict": ".posthrisemployeesemployeeiddocumentsrequestbody",
    "PostHrisEmployeesFormGlobals": ".posthrisemployeesformop",
    "PostHrisEmployeesFormGlobalsTypedDict": ".posthrisemployeesformop",
    "PostHrisEmployeesFormPositiveResponse": ".posthrisemployeesformpositiveresponse",
    "PostHrisEmployeesFormPositiveResponseData": ".posthrisemployeesformpositiveresponse",
    "PostHrisEmployeesFormPositiveResponseDataTypedDict": ".posthrisemployeesformpositiveresponse",
    "PostHrisEmployeesFormPositiveResponseTypedDict": ".posthrisemployeesformpositiveresponse",
    "PostHrisEmployeesFormPositiveResponseWarning": ".posthrisemployeesformpositiveresponse",
    "PostHrisEmployeesFormPositiveResponseWarningTypedDict": ".posthrisemployeesformpositiveresponse",
    "PostHrisEmployeesFormRequestBody": ".posthrisemployeesformrequestbody",
    "PostHrisEmployeesFormRequestBodyTypedDict": ".posthrisemployeesformrequestbody",
    "PostIntegrationsIntegrationIDRelinkRequest": ".postintegrationsintegrationidrelinkop",
    "PostIntegrationsIntegrationIDRelinkRequestTypedDict": ".postintegrationsintegrationidrelinkop",
    "PostIntegrationsIntegrationIDRelinkPositiveResponse": ".postintegrationsintegrationidrelinkpositiveresponse",
    "PostIntegrationsIntegrationIDRelinkPositiveResponseData": ".postintegrationsintegrationidrelinkpositiveresponse",
    "PostIntegrationsIntegrationIDRelinkPositiveResponseDataTypedDict": ".postintegrationsintegrationidrelinkpositiveresponse",
    "PostIntegrationsIntegrationIDRelinkPositiveResponseTypedDict": ".postintegrationsintegrationidrelinkpositiveresponse",
    "PostIntegrationsIntegrationIDRelinkRequestBody": ".postintegrationsintegrationidrelinkrequestbody",
    "PostIntegrationsIntegrationIDRelinkRequestBodyLanguage": ".postintegrationsintegrationidrelinkrequestbody",
    "PostIntegrationsIntegrationIDRelinkRequestBodyLinkType": ".postintegrationsintegrationidrelinkrequestbody",
    "PostIntegrationsIntegrationIDRelinkRequestBodyTypedDict": ".postintegrationsintegrationidrelinkrequestbody",
    "PostPassthroughToolAPIGlobals": ".postpassthroughtoolapiop",
    "PostPassthroughToolAPIGlobalsTypedDict": ".postpassthroughtoolapiop",
    "PostPassthroughToolAPIRequest": ".postpassthroughtoolapiop",
    "PostPassthroughToolAPIRequestTypedDict": ".postpassthroughtoolapiop",
    "Headers": ".postpassthroughtoolapipositiveresponse",
    "HeadersTypedDict": ".postpassthroughtoolapipositiveresponse",
    "PostPassthroughToolAPIPositiveResponse": ".postpassthroughtoolapipositiveresponse",
    "PostPassthroughToolAPIPositiveResponseData": ".postpassthroughtoolapipositiveresponse",
    "PostPassthroughToolAPIPositiveResponseDataTypedDict": ".postpassthroughtoolapipositiveresponse",
    "PostPassthroughToolAPIPositiveResponseTypedDict": ".postpassthroughtoolapipositiveresponse",
    "PostPassthroughToolAPIPositiveResponseWarning": ".postpassthroughtoolapipositiveresponse",
    "PostPassthroughToolAPIPositiveResponseWarningTypedDict": ".postpassthroughtoolapipositiveresponse",
    "Method": ".postpassthroughtoolapirequestbody",
    "MultipartFormDatum": ".postpassthroughtoolapirequestbody",
    "MultipartFormDatumTypedDict": ".postpassthroughtoolapirequestbody",
    "PostPassthroughToolAPIRequestBody": ".postpassthroughtoolapirequestbody",
    "PostPassthroughToolAPIRequestBodyTypedDict": ".postpassthroughtoolapirequestbody",
    "Value": ".postpassthroughtoolapirequestbody",
    "ValueTypedDict": ".postpassthroughtoolapirequestbody",
    "ValueUnion": ".postpassthroughtoolapirequestbody",
    "ValueUnionTypedDict": ".postpassthroughtoolapirequestbody",
    "PutAssessmentOrdersAssessmentOrderIDResultGlobals": ".putassessmentordersassessmentorderidresultop",
    "PutAssessmentOrdersAssessmentOrderIDResultGlobalsTypedDict": ".putassessmentordersassessmentorderidresultop",
    "PutAssessmentOrdersAssessmentOrderIDResultRequest": ".putassessmentordersassessmentorderidresultop",
    "PutAssessmentOrdersAssessmentOrderIDResultRequestTypedDict": ".putassessmentordersassessmentorderidresultop",
    "PutAssessmentOrdersAssessmentOrderIDResultPositiveResponse": ".putassessmentordersassessmentorderidresultpositiveresponse",
    "PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseData": ".putassessmentordersassessmentorderidresultpositiveresponse",
    "PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseDataTypedDict": ".putassessmentordersassessmentorderidresultpositiveresponse",
    "PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseTypedDict": ".putassessmentordersassessmentorderidresultpositiveresponse",
    "PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseWarning": ".putassessmentordersassessmentorderidresultpositiveresponse",
    "PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseWarningTypedDict": ".putassessmentordersassessmentorderidresultpositiveresponse",
    "Attribute": ".putassessmentordersassessmentorderidresultrequestbody",
    "AttributeStatus": ".putassessmentordersassessmentorderidresultrequestbody",
    "AttributeSubResult": ".putassessmentordersassessmentorderidresultrequestbody",
    "AttributeSubResultTypedDict": ".putassessmentordersassessmentorderidresultrequestbody",
    "AttributeText": ".putassessmentordersassessmentorderidresultrequestbody",
    "AttributeTextTypedDict": ".putassessmentordersassessmentorderidresultrequestbody",
    "AttributeTypedDict": ".putassessmentordersassessmentorderidresultrequestbody",
    "PutAssessmentOrdersAssessmentOrderIDResultRequestBody": ".putassessmentordersassessmentorderidresultrequestbody",
    "PutAssessmentOrdersAssessmentOrderIDResultRequestBodyAttachment": ".putassessmentordersassessmentorderidresultrequestbody",
    "PutAssessmentOrdersAssessmentOrderIDResultRequestBodyAttachmentTypedDict": ".putassessmentordersassessmentorderidresultrequestbody",
    "PutAssessmentOrdersAssessmentOrderIDResultRequestBodyRemoteFields": ".putassessmentordersassessmentorderidresultrequestbody",
    "PutAssessmentOrdersAssessmentOrderIDResultRequestBodyRemoteFieldsTypedDict": ".putassessmentordersassessmentorderidresultrequestbody",
    "PutAssessmentOrdersAssessmentOrderIDResultRequestBodySmartrecruiters": ".putassessmentordersassessmentorderidresultrequestbody",
    "PutAssessmentOrdersAssessmentOrderIDResultRequestBodySmartrecruitersTypedDict": ".putassessmentordersassessmentorderidresultrequestbody",
    "PutAssessmentOrdersAssessmentOrderIDResultRequestBodyStatus": ".putassessmentordersassessmentorderidresultrequestbody",
    "PutAssessmentOrdersAssessmentOrderIDResultRequestBodyTypedDict": ".putassessmentordersassessmentorderidresultrequestbody",
    "Score": ".putassessmentordersassessmentorderidresultrequestbody",
    "ScoreTypedDict": ".putassessmentordersassessmentorderidresultrequestbody",
    "PutAssessmentPackagesGlobals": ".putassessmentpackagesop",
    "PutAssessmentPackagesGlobalsTypedDict": ".putassessmentpackagesop",
    "PutAssessmentPackagesPositiveResponse": ".putassessmentpackagespositiveresponse",
    "PutAssessmentPackagesPositiveResponseData": ".putassessmentpackagespositiveresponse",
    "PutAssessmentPackagesPositiveResponseDataTypedDict": ".putassessmentpackagespositiveresponse",
    "PutAssessmentPackagesPositiveResponseTypedDict": ".putassessmentpackagespositiveresponse",
    "PutAssessmentPackagesPositiveResponseWarning": ".putassessmentpackagespositiveresponse",
    "PutAssessmentPackagesPositiveResponseWarningTypedDict": ".putassessmentpackagespositiveresponse",
    "PutAssessmentPackagesRequestBody": ".putassessmentpackagesrequestbody",
    "PutAssessmentPackagesRequestBodyPackage": ".putassessmentpackagesrequestbody",
    "PutAssessmentPackagesRequestBodyPackageTypedDict": ".putassessmentpackagesrequestbody",
    "PutAssessmentPackagesRequestBodyType": ".putassessmentpackagesrequestbody",
    "PutAssessmentPackagesRequestBodyTypedDict": ".putassessmentpackagesrequestbody",
    "PutAtsApplicationsApplicationIDStageGlobals": ".putatsapplicationsapplicationidstageop",
    "PutAtsApplicationsApplicationIDStageGlobalsTypedDict": ".putatsapplicationsapplicationidstageop",
    "PutAtsApplicationsApplicationIDStageRequest": ".putatsapplicationsapplicationidstageop",
    "PutAtsApplicationsApplicationIDStageRequestTypedDict": ".putatsapplicationsapplicationidstageop",
    "PutAtsApplicationsApplicationIDStagePositiveResponse": ".putatsapplicationsapplicationidstagepositiveresponse",
    "PutAtsApplicationsApplicationIDStagePositiveResponseData": ".putatsapplicationsapplicationidstagepositiveresponse",
    "PutAtsApplicationsApplicationIDStagePositiveResponseDataTypedDict": ".putatsapplicationsapplicationidstagepositiveresponse",
    "PutAtsApplicationsApplicationIDStagePositiveResponseTypedDict": ".putatsapplicationsapplicationidstagepositiveresponse",
    "PutAtsApplicationsApplicationIDStagePositiveResponseWarning": ".putatsapplicationsapplicationidstagepositiveresponse",
    "PutAtsApplicationsApplicationIDStagePositiveResponseWarningTypedDict": ".putatsapplicationsapplicationidstagepositiveresponse",
    "PutAtsApplicationsApplicationIDStageRequestBody": ".putatsapplicationsapplicationidstagerequestbody",
    "PutAtsApplicationsApplicationIDStageRequestBodyGreenhouse": ".putatsapplicationsapplicationidstagerequestbody",
    "PutAtsApplicationsApplicationIDStageRequestBodyGreenhouseTypedDict": ".putatsapplicationsapplicationidstagerequestbody",
    "PutAtsApplicationsApplicationIDStageRequestBodyPostHeaders": ".putatsapplicationsapplicationidstagerequestbody",
    "PutAtsApplicationsApplicationIDStageRequestBodyPostHeadersTypedDict": ".putatsapplicationsapplicationidstagerequestbody",
    "PutAtsApplicationsApplicationIDStageRequestBodyRemoteFields": ".putatsapplicationsapplicationidstagerequestbody",
    "PutAtsApplicationsApplicationIDStageRequestBodyRemoteFieldsTypedDict": ".putatsapplicationsapplicationidstagerequestbody",
    "PutAtsApplicationsApplicationIDStageRequestBodyTypedDict": ".putatsapplicationsapplicationidstagerequestbody",
    "PutAtsApplicationsApplicationIDStageRequestBodyWorkable": ".putatsapplicationsapplicationidstagerequestbody",
    "PutAtsApplicationsApplicationIDStageRequestBodyWorkableTypedDict": ".putatsapplicationsapplicationidstagerequestbody",
    "PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDRequest": ".putintegrationsintegrationidcustomfieldscustomfieldidop",
    "PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDRequestTypedDict": ".putintegrationsintegrationidcustomfieldscustomfieldidop",
    "PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDPositiveResponse": ".putintegrationsintegrationidcustomfieldscustomfieldidpositiveresponse",
    "PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDPositiveResponseData": ".putintegrationsintegrationidcustomfieldscustomfieldidpositiveresponse",
    "PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDPositiveResponseDataTypedDict": ".putintegrationsintegrationidcustomfieldscustomfieldidpositiveresponse",
    "PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDPositiveResponseIntegrationField": ".putintegrationsintegrationidcustomfieldscustomfieldidpositiveresponse",
    "PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDPositiveResponseIntegrationFieldTypedDict": ".putintegrationsintegrationidcustomfieldscustomfieldidpositiveresponse",
    "PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDPositiveResponseType": ".putintegrationsintegrationidcustomfieldscustomfieldidpositiveresponse",
    "PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDPositiveResponseTypedDict": ".putintegrationsintegrationidcustomfieldscustomfieldidpositiveresponse",
    "PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDRequestBody": ".putintegrationsintegrationidcustomfieldscustomfieldidrequestbody",
    "PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDRequestBodyTypedDict": ".putintegrationsintegrationidcustomfieldscustomfieldidrequestbody",
    "Schema1": ".schema1",
    "Schema1TypedDict": ".schema1",
    "Schema1Array1": ".schema1_union_1",
    "Schema1Array1TypedDict": ".schema1_union_1",
    "Schema1Checkbox": ".schema1_union_1",
    "Schema1CheckboxTypedDict": ".schema1_union_1",
    "Schema1Date": ".schema1_union_1",
    "Schema1DateTypedDict": ".schema1_union_1",
    "Schema1Entry1": ".schema1_union_1",
    "Schema1Entry1TypedDict": ".schema1_union_1",
    "Schema1Entry2": ".schema1_union_1",
    "Schema1Entry2TypedDict": ".schema1_union_1",
    "Schema1File": ".schema1_union_1",
    "Schema1FileRestrictions": ".schema1_union_1",
    "Schema1FileRestrictionsTypedDict": ".schema1_union_1",
    "Schema1FileTypedDict": ".schema1_union_1",
    "Schema1MultiSelect": ".schema1_union_1",
    "Schema1MultiSelectTypedDict": ".schema1_union_1",
    "Schema1Number": ".schema1_union_1",
    "Schema1NumberTypedDict": ".schema1_union_1",
    "Schema1Object": ".schema1_union_1",
    "Schema1ObjectTypedDict": ".schema1_union_1",
    "Schema1OptionsInline1": ".schema1_union_1",
    "Schema1OptionsInline1TypedDict": ".schema1_union_1",
    "Schema1OptionsInline2": ".schema1_union_1",
    "Schema1OptionsInline2TypedDict": ".schema1_union_1",
    "Schema1OptionsReferenced1": ".schema1_union_1",
    "Schema1OptionsReferenced1TypedDict": ".schema1_union_1",
    "Schema1OptionsReferenced2": ".schema1_union_1",
    "Schema1OptionsReferenced2TypedDict": ".schema1_union_1",
    "Schema1OptionsUnion1": ".schema1_union_1",
    "Schema1OptionsUnion1TypedDict": ".schema1_union_1",
    "Schema1OptionsUnion2": ".schema1_union_1",
    "Schema1OptionsUnion2TypedDict": ".schema1_union_1",
    "Schema1RemoteID1": ".schema1_union_1",
    "Schema1RemoteID1TypedDict": ".schema1_union_1",
    "Schema1RemoteID2": ".schema1_union_1",
    "Schema1RemoteID2TypedDict": ".schema1_union_1",
    "Schema1SingleSelect": ".schema1_union_1",
    "Schema1SingleSelectTypedDict": ".schema1_union_1",
    "Schema1Text": ".schema1_union_1",
    "Schema1TextTypedDict": ".schema1_union_1",
    "Schema1UnifiedKey1": ".schema1_union_1",
    "Schema1UnifiedKey2": ".schema1_union_1",
    "Schema1UnifiedKey3": ".schema1_union_1",
    "Schema1UnifiedKey4": ".schema1_union_1",
    "Schema1UnifiedKey5": ".schema1_union_1",
    "Schema1UnifiedKey6": ".schema1_union_1",
    "Schema1UnifiedKey7": ".schema1_union_1",
    "Schema1UnifiedKey8": ".schema1_union_1",
    "Schema1Union1": ".schema1_union_1",
    "Schema1Union1TypedDict": ".schema1_union_1",
    "Schema4": ".schema4",
    "Schema4TypedDict": ".schema4",
    "Security": ".security",
    "SecurityTypedDict": ".security",
    "SyncFinishedWebhookPayload": ".syncfinishedwebhookpayload",
    "SyncFinishedWebhookPayloadData": ".syncfinishedwebhookpayload",
    "SyncFinishedWebhookPayloadDataTypedDict": ".syncfinishedwebhookpayload",
    "SyncFinishedWebhookPayloadEndUser": ".syncfinishedwebhookpayload",
    "SyncFinishedWebhookPayloadEndUserTypedDict": ".syncfinishedwebhookpayload",
    "SyncFinishedWebhookPayloadIntegrationCategory": ".syncfinishedwebhookpayload",
    "SyncFinishedWebhookPayloadType": ".syncfinishedwebhookpayload",
    "SyncFinishedWebhookPayloadTypedDict": ".syncfinishedwebhookpayload",
    "WebhookAssessmentOrderReceivedWebhookPayloadRequest": ".webhookassessmentorderreceivedwebhookpayloadop",
    "WebhookAssessmentOrderReceivedWebhookPayloadRequestTypedDict": ".webhookassessmentorderreceivedwebhookpayloadop",
    "WebhookConnectionFlowFailedWebhookPayloadRequest": ".webhookconnectionflowfailedwebhookpayloadop",
    "WebhookConnectionFlowFailedWebhookPayloadRequestTypedDict": ".webhookconnectionflowfailedwebhookpayloadop",
    "WebhookDataChangedWebhookPayloadRequest": ".webhookdatachangedwebhookpayloadop",
    "WebhookDataChangedWebhookPayloadRequestTypedDict": ".webhookdatachangedwebhookpayloadop",
    "WebhookInlineAssessmentOrderReceivedWebhookPayloadRequest": ".webhookinlineassessmentorderreceivedwebhookpayloadop",
    "WebhookInlineAssessmentOrderReceivedWebhookPayloadRequestTypedDict": ".webhookinlineassessmentorderreceivedwebhookpayloadop",
    "WebhookIntegrationCreatedWebhookPayloadRequest": ".webhookintegrationcreatedwebhookpayloadop",
    "WebhookIntegrationCreatedWebhookPayloadRequestTypedDict": ".webhookintegrationcreatedwebhookpayloadop",
    "WebhookIntegrationDeletedWebhookPayloadRequest": ".webhookintegrationdeletedwebhookpayloadop",
    "WebhookIntegrationDeletedWebhookPayloadRequestTypedDict": ".webhookintegrationdeletedwebhookpayloadop",
    "WebhookIntegrationStateChangedWebhookPayloadRequest": ".webhookintegrationstatechangedwebhookpayloadop",
    "WebhookIntegrationStateChangedWebhookPayloadRequestTypedDict": ".webhookintegrationstatechangedwebhookpayloadop",
    "WebhookSyncFinishedWebhookPayloadRequest": ".webhooksyncfinishedwebhookpayloadop",
    "WebhookSyncFinishedWebhookPayloadRequestTypedDict": ".webhooksyncfinishedwebhookpayloadop",
}


def dynamic_import(modname, retries=3):
    for attempt in range(retries):
        try:
            return import_module(modname, __package__)
        except KeyError:
            # Clear any half-initialized module and retry
            sys.modules.pop(modname, None)
            if attempt == retries - 1:
                break
    raise KeyError(f"Failed to import module '{modname}' after {retries} attempts")


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = dynamic_import(module_name)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = builtins.list(_dynamic_imports.keys())
    return builtins.sorted(lazy_attrs)
